/* Function erfc vectorized with SSE4.
   Copyright (C) 2021-2024 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   https://www.gnu.org/licenses/.  */

/*
 * ALGORITHM DESCRIPTION:
 *
 *   Approximation formula:
 *   erfc(x)~erfc(x0)-2/sqrt(pi)*exp(-x0^2)*D*[1+(x0*D)*p1(x0*D)+D^2*p3(x0*D)+D^4*p5(x0*D)+D^6*p7(x0*D)]
 *     D = x - x0
 *     erfc(x0) and 2/sqrt(pi)*exp(-x0^2)/(2*x0) are tabulated
 *
 *
 */

/* Offsets for data table __svml_derfc_data_internal
 */
#define _erfc_tbl			0
#define _AbsMask			55808
#define _MaxThreshold			55824
#define _SgnMask			55840
#define _TwoM128			55856
#define _SRound				55872
#define _poly1_0			55888
#define _poly1_1			55904
#define _poly3_0			55920
#define _poly3_1			55936
#define _poly5_0			55952
#define _poly5_1			55968
#define _poly1_2			55984
#define _poly3_2			56000
#define _poly5_2			56016
#define _poly1_3			56032
#define _poly3_3			56048
#define _poly5_3			56064
#define _poly1_4			56080
#define _poly3_4			56096
#define _poly1_5			56112
#define _poly3_5			56128
#define _poly3_6			56144
#define _poly1_6			56160
#define _poly1_7			56176
#define _UF_Threshold			56192
#define _TwoP128			56208

#include <sysdep.h>

	.section .text.sse4, "ax", @progbits
ENTRY(_ZGVbN2v_erfc_sse4)
	subq	$72, %rsp
	cfi_def_cfa_offset(80)
	movaps	%xmm0, %xmm4
	movups	_AbsMask+__svml_derfc_data_internal(%rip), %xmm2

	/* vector gather: erfc_h(x0), (erfc_l(x0), 2/sqrt(pi)*exp(-x0^2)) */
	lea	__svml_derfc_data_internal(%rip), %rcx
	andps	%xmm4, %xmm2

	/*
	 * erfc(27.25) underflows to 0
	 * can compute all results in the main path
	 */
	minpd	_MaxThreshold+__svml_derfc_data_internal(%rip), %xmm2
	movups	_SRound+__svml_derfc_data_internal(%rip), %xmm6
	movaps	%xmm6, %xmm8
	addpd	%xmm2, %xmm8
	movups	_TwoM128+__svml_derfc_data_internal(%rip), %xmm0
	movaps	%xmm8, %xmm1
	maxpd	%xmm0, %xmm2
	subpd	%xmm6, %xmm1
	subpd	%xmm1, %xmm2
	mulpd	%xmm2, %xmm1

	/* Start polynomial evaluation */
	movups	_poly1_0+__svml_derfc_data_internal(%rip), %xmm13

	/* Diff^2 */
	movaps	%xmm2, %xmm15
	mulpd	%xmm1, %xmm13
	mulpd	%xmm2, %xmm15
	addpd	_poly1_1+__svml_derfc_data_internal(%rip), %xmm13
	movups	_poly3_0+__svml_derfc_data_internal(%rip), %xmm11

	/* T^2 */
	movaps	%xmm1, %xmm14
	mulpd	%xmm1, %xmm11
	mulpd	%xmm1, %xmm13
	addpd	_poly3_1+__svml_derfc_data_internal(%rip), %xmm11
	addpd	_poly1_2+__svml_derfc_data_internal(%rip), %xmm13
	mulpd	%xmm1, %xmm14
	mulpd	%xmm1, %xmm11
	mulpd	%xmm1, %xmm13
	addpd	_poly3_2+__svml_derfc_data_internal(%rip), %xmm11
	addpd	_poly1_3+__svml_derfc_data_internal(%rip), %xmm13
	mulpd	%xmm1, %xmm11
	mulpd	%xmm1, %xmm13
	addpd	_poly3_3+__svml_derfc_data_internal(%rip), %xmm11
	addpd	_poly1_4+__svml_derfc_data_internal(%rip), %xmm13
	mulpd	%xmm1, %xmm11
	mulpd	%xmm1, %xmm13
	addpd	_poly3_4+__svml_derfc_data_internal(%rip), %xmm11
	addpd	_poly1_5+__svml_derfc_data_internal(%rip), %xmm13
	mulpd	%xmm1, %xmm11
	mulpd	%xmm1, %xmm13
	addpd	_poly3_5+__svml_derfc_data_internal(%rip), %xmm11
	addpd	_poly1_6+__svml_derfc_data_internal(%rip), %xmm13
	mulpd	%xmm1, %xmm11
	mulpd	%xmm1, %xmm13
	movups	_poly5_0+__svml_derfc_data_internal(%rip), %xmm12
	psllq	$4, %xmm8
	mulpd	%xmm1, %xmm12
	addpd	_poly1_7+__svml_derfc_data_internal(%rip), %xmm13
	addpd	_poly5_1+__svml_derfc_data_internal(%rip), %xmm12
	movd	%xmm8, %eax
	mulpd	%xmm13, %xmm14
	mulpd	%xmm1, %xmm12
	addpd	_poly5_2+__svml_derfc_data_internal(%rip), %xmm12
	mulpd	%xmm1, %xmm12
	addpd	_poly5_3+__svml_derfc_data_internal(%rip), %xmm12

	/* P5 = P5 + D2*P07 */
	mulpd	%xmm15, %xmm12
	addpd	_poly3_6+__svml_derfc_data_internal(%rip), %xmm12
	addpd	%xmm11, %xmm12
	mulpd	%xmm12, %xmm15
	pshufd	$2, %xmm8, %xmm9
	movd	%xmm9, %edx
	movups	_TwoP128+__svml_derfc_data_internal(%rip), %xmm5
	movups	_SgnMask+__svml_derfc_data_internal(%rip), %xmm7
	movaps	%xmm5, %xmm3
	movslq	%eax, %rax
	andps	%xmm4, %xmm7
	movslq	%edx, %rdx
	orps	%xmm7, %xmm3
	subpd	%xmm1, %xmm15
	subpd	%xmm5, %xmm3
	addpd	%xmm14, %xmm15
	movups	(%rcx, %rax), %xmm5

	/* Special arguments (for flags only) */
	movaps	%xmm4, %xmm1
	movups	(%rcx, %rdx), %xmm10
	movaps	%xmm5, %xmm6
	unpckhpd %xmm10, %xmm5

	/* 2^(-128) with sign of input */
	orps	%xmm7, %xmm0

	/* EXP_X0H *= Diff */
	mulpd	%xmm2, %xmm5
	cmpltpd	_UF_Threshold+__svml_derfc_data_internal(%rip), %xmm1

	/* EXP_x0H*Diff*(1+P1) */
	mulpd	%xmm5, %xmm15

	/* combine and get argument value range mask */
	movmskpd %xmm1, %edx
	unpcklpd %xmm10, %xmm6
	addpd	%xmm15, %xmm5

	/* erfc(|_VARG1|) = erfc_h(x0) - P1 */
	subpd	%xmm5, %xmm6
	addpd	%xmm6, %xmm3
	notl	%edx
	mulpd	%xmm3, %xmm0
	andl	$3, %edx

	/* Go to special inputs processing branch */
	jne	L(SPECIAL_VALUES_BRANCH)
	# LOE rbx rbp r12 r13 r14 r15 edx xmm0 xmm4

	/* Restore registers
	 * and exit the function
	 */

L(EXIT):
	addq	$72, %rsp
	cfi_def_cfa_offset(8)
	ret
	cfi_def_cfa_offset(80)

	/* Branch to process
	 * special inputs
	 */

L(SPECIAL_VALUES_BRANCH):
	movups	%xmm4, 32(%rsp)
	movups	%xmm0, 48(%rsp)
	# LOE rbx rbp r12 r13 r14 r15 edx xmm0

	xorl	%eax, %eax
	movq	%r12, 16(%rsp)
	cfi_offset(12, -64)
	movl	%eax, %r12d
	movq	%r13, 8(%rsp)
	cfi_offset(13, -72)
	movl	%edx, %r13d
	movq	%r14, (%rsp)
	cfi_offset(14, -80)
	# LOE rbx rbp r15 r12d r13d

	/* Range mask
	 * bits check
	 */

L(RANGEMASK_CHECK):
	btl	%r12d, %r13d

	/* Call scalar math function */
	jc	L(SCALAR_MATH_CALL)
	# LOE rbx rbp r15 r12d r13d

	/* Special inputs
	 * processing loop
	 */

L(SPECIAL_VALUES_LOOP):
	incl	%r12d
	cmpl	$2, %r12d

	/* Check bits in range mask */
	jl	L(RANGEMASK_CHECK)
	# LOE rbx rbp r15 r12d r13d

	movq	16(%rsp), %r12
	cfi_restore(12)
	movq	8(%rsp), %r13
	cfi_restore(13)
	movq	(%rsp), %r14
	cfi_restore(14)
	movups	48(%rsp), %xmm0

	/* Go to exit */
	jmp	L(EXIT)
	cfi_offset(12, -64)
	cfi_offset(13, -72)
	cfi_offset(14, -80)
	# LOE rbx rbp r12 r13 r14 r15 xmm0

	/* Scalar math function call
	 * to process special input
	 */

L(SCALAR_MATH_CALL):
	movl	%r12d, %r14d
	movsd	32(%rsp, %r14, 8), %xmm0
	call	erfc@PLT
	# LOE rbx rbp r14 r15 r12d r13d xmm0

	movsd	%xmm0, 48(%rsp, %r14, 8)

	/* Process special inputs in loop */
	jmp	L(SPECIAL_VALUES_LOOP)
	# LOE rbx rbp r15 r12d r13d
END(_ZGVbN2v_erfc_sse4)

	.section .rodata, "a"
	.align	16

#ifdef __svml_derfc_data_internal_typedef
typedef unsigned int VUINT32;
typedef struct {
	__declspec(align(16)) VUINT32 _erfc_tbl[3488*2][2];
	__declspec(align(16)) VUINT32 _AbsMask[2][2];
	__declspec(align(16)) VUINT32 _MaxThreshold[2][2];
	__declspec(align(16)) VUINT32 _SgnMask[2][2];
	__declspec(align(16)) VUINT32 _TwoM128[2][2];
	__declspec(align(16)) VUINT32 _SRound[2][2];
	__declspec(align(16)) VUINT32 _poly1_0[2][2];
	__declspec(align(16)) VUINT32 _poly1_1[2][2];
	__declspec(align(16)) VUINT32 _poly3_0[2][2];
	__declspec(align(16)) VUINT32 _poly3_1[2][2];
	__declspec(align(16)) VUINT32 _poly5_0[2][2];
	__declspec(align(16)) VUINT32 _poly5_1[2][2];
	__declspec(align(16)) VUINT32 _poly1_2[2][2];
	__declspec(align(16)) VUINT32 _poly3_2[2][2];
	__declspec(align(16)) VUINT32 _poly5_2[2][2];
	__declspec(align(16)) VUINT32 _poly1_3[2][2];
	__declspec(align(16)) VUINT32 _poly3_3[2][2];
	__declspec(align(16)) VUINT32 _poly5_3[2][2];
	__declspec(align(16)) VUINT32 _poly1_4[2][2];
	__declspec(align(16)) VUINT32 _poly3_4[2][2];
	__declspec(align(16)) VUINT32 _poly1_5[2][2];
	__declspec(align(16)) VUINT32 _poly3_5[2][2];
	__declspec(align(16)) VUINT32 _poly3_6[2][2];
	__declspec(align(16)) VUINT32 _poly1_6[2][2];
	__declspec(align(16)) VUINT32 _poly1_7[2][2];
	__declspec(align(16)) VUINT32 _UF_Threshold[2][2];
	__declspec(align(16)) VUINT32 _TwoP128[2][2];
} __svml_derfc_data_internal;
#endif
__svml_derfc_data_internal:
	/* _erfc_tbl */
	.quad	0x47f0000000000000, 0x47f20dd750429b6d
	.quad	0x47efb7c9030853b3, 0x47f20d8f1975c85d
	.quad	0x47ef6f9447be0743, 0x47f20cb67bd452c7
	.quad	0x47ef27640f9853d9, 0x47f20b4d8bac36c1
	.quad	0x47eedf3a9ba22dad, 0x47f209546ad13ccf
	.quad	0x47ee971a2c4436ae, 0x47f206cb4897b148
	.quad	0x47ee4f05010eca8c, 0x47f203b261cd0053
	.quad	0x47ee06fd58842c7e, 0x47f2000a00ae3804
	.quad	0x47edbf056fe2df35, 0x47f1fbd27cdc72d3
	.quad	0x47ed771f82f02f4e, 0x47f1f70c3b4f2cc8
	.quad	0x47ed2f4dcbc2f894, 0x47f1f1b7ae44867f
	.quad	0x47ece792828eae5c, 0x47f1ebd5552f795b
	.quad	0x47ec9fefdd6eaf19, 0x47f1e565bca400d4
	.quad	0x47ec58681031eb6a, 0x47f1de697e413d29
	.quad	0x47ec10fd4c26e896, 0x47f1d6e14099944a
	.quad	0x47ebc9b1bfe82687, 0x47f1cecdb718d61c
	.quad	0x47eb82879728f11e, 0x47f1c62fa1e869b6
	.quad	0x47eb3b80fa82a4bb, 0x47f1bd07cdd189ac
	.quad	0x47eaf4a00f426daa, 0x47f1b357141d95d5
	.quad	0x47eaade6f7378a0e, 0x47f1a91e5a748165
	.quad	0x47ea6757d08215d8, 0x47f19e5e92b964ab
	.quad	0x47ea20f4b5626818, 0x47f19318bae53a04
	.quad	0x47e9dabfbc090901, 0x47f1874ddcdfce24
	.quad	0x47e994baf66747ad, 0x47f17aff0e56ec10
	.quad	0x47e94ee8720076b6, 0x47f16e2d7093cd8c
	.quad	0x47e9094a37bbd66e, 0x47f160da304ed92f
	.quad	0x47e8c3e24bb73372, 0x47f153068581b781
	.quad	0x47e87eb2ad1a4032, 0x47f144b3b337c90c
	.quad	0x47e839bd55eaafc8, 0x47f135e3075d076b
	.quad	0x47e7f5043ae11862, 0x47f12695da8b5bde
	.quad	0x47e7b0894b3ea35c, 0x47f116cd8fd67618
	.quad	0x47e76c4e70a390e7, 0x47f1068b94962e5e
	.quad	0x47e728558ee694fc, 0x47f0f5d1602f7e41
	.quad	0x47e6e4a083ed132f, 0x47f0e4a073dc1b91
	.quad	0x47e6a13127843ec1, 0x47f0d2fa5a70c168
	.quad	0x47e65e094b3b2413, 0x47f0c0e0a8223359
	.quad	0x47e61b2aba3da093, 0x47f0ae54fa490723
	.quad	0x47e5d89739304dcf, 0x47f09b58f724416b
	.quad	0x47e59650860d6469, 0x47f087ee4d9ad247
	.quad	0x47e5545858029b39, 0x47f07416b4fbfe7c
	.quad	0x47e512b05f5006e1, 0x47f05fd3ecbec298
	.quad	0x47e4d15a4527fdc7, 0x47f04b27bc403d30
	.quad	0x47e49057ab900447, 0x47f03613f2812daf
	.quad	0x47e44faa2d42c4a0, 0x47f0209a65e29545
	.quad	0x47e40f535d93160e, 0x47f00abcf3e187a9
	.quad	0x47e3cf54c8501620, 0x47efe8fb01a47307
	.quad	0x47e38faff1aa574a, 0x47efbbbbef34b4b2
	.quad	0x47e35066561a275d, 0x47ef8dc092d58ff8
	.quad	0x47e311796a46f064, 0x47ef5f0cdaf15313
	.quad	0x47e2d2ea9aefb636, 0x47ef2fa4c16c0019
	.quad	0x47e294bb4cd4b2bd, 0x47eeff8c4b1375db
	.quad	0x47e256ecdca212cc, 0x47eecec7870ebca8
	.quad	0x47e219809edbd524, 0x47ee9d5a8e4c934e
	.quad	0x47e1dc77dfcacd02, 0x47ee6b4982f158b9
	.quad	0x47e19fd3e36ac96a, 0x47ee38988fc46e72
	.quad	0x47e16395e559e218, 0x47ee054be79d3042
	.quad	0x47e127bf18c8eadc, 0x47edd167c4cf9d2a
	.quad	0x47e0ec50a86d0dd4, 0x47ed9cf06898cdaf
	.quad	0x47e0b14bb6728cd8, 0x47ed67ea1a8b5368
	.quad	0x47e076b15c70aa28, 0x47ed325927fb9d89
	.quad	0x47e03c82ab5eb831, 0x47ecfc41e36c7df9
	.quad	0x47e002c0ab8a5018, 0x47ecc5a8a3fbea40
	.quad	0x47df92d8b91d5cc7, 0x47ec8e91c4d01368
	.quad	0x47df210d6a9a6a31, 0x47ec5701a484ef9d
	.quad	0x47deb02147ce245c, 0x47ec1efca49a5011
	.quad	0x47de40161b701275, 0x47ebe68728e29d5e
	.quad	0x47ddd0ed9ea4bdd6, 0x47ebada596f25436
	.quad	0x47dd62a978f7c957, 0x47eb745c55905bf8
	.quad	0x47dcf54b4058455f, 0x47eb3aafcc27502e
	.quad	0x47dc88d479173cce, 0x47eb00a46237d5be
	.quad	0x47dc1d4695e87644, 0x47eac63e7ecc1411
	.quad	0x47dbb2a2f7e56520, 0x47ea8b8287ec6a09
	.quad	0x47db48eaee924501, 0x47ea5074e2157620
	.quad	0x47dae01fb7e55a66, 0x47ea1519efaf889e
	.quad	0x47da78428050527e, 0x47e9d97610879642
	.quad	0x47da115462cbbc17, 0x47e99d8da149c13f
	.quad	0x47d9ab5668e4930a, 0x47e96164fafd8de3
	.quad	0x47d946498acbd766, 0x47e925007283d7aa
	.quad	0x47d8e22eaf68291e, 0x47e8e86458169af8
	.quad	0x47d87f06ac6960c4, 0x47e8ab94f6caa71d
	.quad	0x47d81cd2465e1d96, 0x47e86e9694134b9e
	.quad	0x47d7bb9230cb40b4, 0x47e8316d6f48133d
	.quad	0x47d75b470e454d35, 0x47e7f41dc12c9e89
	.quad	0x47d6fbf1708ba47c, 0x47e7b6abbb7aaf19
	.quad	0x47d69d91d8a595da, 0x47e7791b886e7403
	.quad	0x47d64028b7013867, 0x47e73b714a552763
	.quad	0x47d5e3b66b9405a9, 0x47e6fdb11b1e0c34
	.quad	0x47d5883b45fd2b63, 0x47e6bfdf0beddaf5
	.quad	0x47d52db785a98aca, 0x47e681ff24b4ab04
	.quad	0x47d4d42b59f95afa, 0x47e6441563c665d4
	.quad	0x47d47b96e267647a, 0x47e60625bd75d07b
	.quad	0x47d423fa2eb1cb59, 0x47e5c8341bb23767
	.quad	0x47d3cd553f045d45, 0x47e58a445da7c74c
	.quad	0x47d377a8042458d1, 0x47e54c5a57629db0
	.quad	0x47d322f25f9da2fd, 0x47e50e79d1749ac9
	.quad	0x47d2cf3423f15fdf, 0x47e4d0a6889dfd9f
	.quad	0x47d27c6d14c5e341, 0x47e492e42d78d2c5
	.quad	0x47d22a9ce717edcb, 0x47e4553664273d24
	.quad	0x47d1d9c3416d2b4b, 0x47e417a0c4049fd0
	.quad	0x47d189dfbc07e690, 0x47e3da26d759aef5
	.quad	0x47d13af1e11be721, 0x47e39ccc1b136d5a
	.quad	0x47d0ecf92d046d22, 0x47e35f93fe7d1b3d
	.quad	0x47d09ff50e7b3f93, 0x47e32281e2fd1a92
	.quad	0x47d053e4e6d0c10b, 0x47e2e5991bd4cbfc
	.quad	0x47d008c80a24ff10, 0x47e2a8dcede3673b
	.quad	0x47cf7d3b7f436013, 0x47e26c508f6bd0ff
	.quad	0x47ceeaca836a27cc, 0x47e22ff727dd6f7b
	.quad	0x47ce5a3b7c9b56da, 0x47e1f3d3cf9ffe5a
	.quad	0x47cdcb8cae2d747f, 0x47e1b7e98fe26217
	.quad	0x47cd3ebc436b0f26, 0x47e17c3b626c7a12
	.quad	0x47ccb3c8500ea349, 0x47e140cc3173f007
	.quad	0x47cc2aaed0bfcfee, 0x47e1059ed7740313
	.quad	0x47cba36dab91c0e9, 0x47e0cab61f084b93
	.quad	0x47cb1e02b082b720, 0x47e09014c2ca74da
	.quad	0x47ca9a6b99fc973b, 0x47e055bd6d32e8d7
	.quad	0x47ca18a60d56673e, 0x47e01bb2b87c6968
	.quad	0x47c998af9b56a3ae, 0x47dfc3ee5d1524b0
	.quad	0x47c91a85c0b65519, 0x47df511a91a67d2a
	.quad	0x47c89e25e6a4cef9, 0x47dedeeee0959518
	.quad	0x47c8238d634c0127, 0x47de6d6ffaa65a25
	.quad	0x47c7aab97a554544, 0x47ddfca26f5bbf88
	.quad	0x47c733a75d6e91b8, 0x47dd8c8aace11e63
	.quad	0x47c6be542ccffc2f, 0x47dd1d2cfff91594
	.quad	0x47c64abcf7c175b4, 0x47dcae8d93f1d7b7
	.quad	0x47c5d8debd20aace, 0x47dc40b0729ed548
	.quad	0x47c568b66be6f268, 0x47dbd3998457afdb
	.quad	0x47c4fa40e3af3674, 0x47db674c8ffc6283
	.quad	0x47c48d7af53bc19f, 0x47dafbcd3afe8ab6
	.quad	0x47c4226162fbddd5, 0x47da911f096fbc26
	.quad	0x47c3b8f0e1912f70, 0x47da27455e14c93c
	.quad	0x47c351261854b991, 0x47d9be437a7de946
	.quad	0x47c2eafda1db784a, 0x47d9561c7f23a47b
	.quad	0x47c286740c7a7dab, 0x47d8eed36b886d93
	.quad	0x47c22385daca7f47, 0x47d8886b1e5ecfd1
	.quad	0x47c1c22f842ac1f2, 0x47d822e655b417e7
	.quad	0x47c1626d75435220, 0x47d7be47af1f5d89
	.quad	0x47c1043c1086777d, 0x47d75a91a7f4d2ed
	.quad	0x47c0a797aeb152f2, 0x47d6f7c69d7d3ef8
	.quad	0x47c04c7c9f4b9690, 0x47d695e8cd31867e
	.quad	0x47bfe5ce524c8ee5, 0x47d634fa54fa285f
	.quad	0x47bf35a715b2f3e1, 0x47d5d4fd33729015
	.quad	0x47be887bf681f218, 0x47d575f3483021c3
	.quad	0x47bdde4553ef94de, 0x47d517de540ce2a3
	.quad	0x47bd36fb7fa50177, 0x47d4babff975a04c
	.quad	0x47bc9296beb09cf1, 0x47d45e99bcbb7915
	.quad	0x47bbf10f4a759889, 0x47d4036d0468a7a2
	.quad	0x47bb525d5198cb1c, 0x47d3a93b1998736c
	.quad	0x47bab678f8eabedb, 0x47d35005285227f1
	.quad	0x47ba1d5a5c4edb96, 0x47d2f7cc3fe6f423
	.quad	0x47b986f98f9f96c8, 0x47d2a09153529381
	.quad	0x47b8f34e9f8f93a6, 0x47d24a55399ea239
	.quad	0x47b8625192879e39, 0x47d1f518ae487dc8
	.quad	0x47b7d3fa69816db5, 0x47d1a0dc51a9934d
	.quad	0x47b7484120df1b01, 0x47d14da0a961fd14
	.quad	0x47b6bf1db13f3983, 0x47d0fb6620c550af
	.quad	0x47b63888104d811a, 0x47d0aa2d09497f2b
	.quad	0x47b5b478318ff939, 0x47d059f59af7a906
	.quad	0x47b532e6073095f2, 0x47d00abff4dec7a3
	.quad	0x47b4b3c982c338c7, 0x47cf79183b101c5b
	.quad	0x47b4371a960807f8, 0x47cedeb406d9c825
	.quad	0x47b3bcd133aa0ffc, 0x47ce4652fadcb6b2
	.quad	0x47b344e54ffa23b9, 0x47cdaff4969c0b04
	.quad	0x47b2cf4ee1a5f0fc, 0x47cd1b982c501370
	.quad	0x47b25c05e26b3f99, 0x47cc893ce1dcbef7
	.quad	0x47b1eb024fc75285, 0x47cbf8e1b1ca2279
	.quad	0x47b17c3c2ba26319, 0x47cb6a856c3ed54f
	.quad	0x47b10fab7cf72f94, 0x47cade26b7fbed95
	.quad	0x47b0a548507696c0, 0x47ca53c4135a6526
	.quad	0x47b03d0ab9273b94, 0x47c9cb5bd549b111
	.quad	0x47afadd5a20258d3, 0x47c944ec2e4f5630
	.quad	0x47aee5c1730b147c, 0x47c8c07329874652
	.quad	0x47ae21c938a45a83, 0x47c83deeada4d25a
	.quad	0x47ad61dd57628999, 0x47c7bd5c7df3fe9c
	.quad	0x47aca5ee4649e31f, 0x47c73eba3b5b07b7
	.quad	0x47abedec8fddb340, 0x47c6c205655be720
	.quad	0x47ab39c8d3276d8a, 0x47c6473b5b15a7a1
	.quad	0x47aa8973c4b5c03e, 0x47c5ce595c455b0a
	.quad	0x47a9dcde2f93a207, 0x47c5575c8a468362
	.quad	0x47a933f8f6375f2c, 0x47c4e241e912c305
	.quad	0x47a88eb51369acb9, 0x47c46f066040a832
	.quad	0x47a7ed039b24c96b, 0x47c3fda6bc016994
	.quad	0x47a74ed5bb6bb581, 0x47c38e1fae1d6a9d
	.quad	0x47a6b41cbd198bc8, 0x47c3206dceef5f87
	.quad	0x47a61cca04a90795, 0x47c2b48d9e5dea1c
	.quad	0x47a588cf12f4446b, 0x47c24a7b84d38971
	.quad	0x47a4f81d85ecc55b, 0x47c1e233d434b813
	.quad	0x47a46aa7194bd324, 0x47c17bb2c8d41535
	.quad	0x47a3e05da73b4159, 0x47c116f48a6476cc
	.quad	0x47a3593328f6abbe, 0x47c0b3f52ce8c383
	.quad	0x47a2d519b7653e1e, 0x47c052b0b1a174ea
	.quad	0x47a254038bac19d6, 0x47bfe6460fef4680
	.quad	0x47a1d5e2ffb96d40, 0x47bf2a901ccafb37
	.quad	0x47a15aaa8ec85205, 0x47be723726b824a9
	.quad	0x47a0e24cd5dd8846, 0x47bdbd32ac4c99b0
	.quad	0x47a06cbc943d255a, 0x47bd0b7a0f921e7c
	.quad	0x479ff3d957b29b39, 0x47bc5d0497c09e74
	.quad	0x479f13a043742333, 0x47bbb1c972f23e50
	.quad	0x479e38b43cbd0f0f, 0x47bb09bfb7d11a84
	.quad	0x479d62fbdc2e756b, 0x47ba64de673e8837
	.quad	0x479c925e02b41668, 0x47b9c31c6df3b1b8
	.quad	0x479bc6c1da1f3121, 0x47b92470a61b6965
	.quad	0x479b000ed5b4a626, 0x47b888d1d8e510a3
	.quad	0x479a3e2cb2ae9edb, 0x47b7f036c0107294
	.quad	0x4799810378b1f299, 0x47b75a96077274ba
	.quad	0x4798c87b7a37834f, 0x47b6c7e64e7281cb
	.quad	0x4798147d54e9cc33, 0x47b6381e2980956b
	.quad	0x479764f1f1f6ddea, 0x47b5ab342383d178
	.quad	0x4796b9c28657041a, 0x47b5211ebf41880b
	.quad	0x479612d893085125, 0x47b499d478bca735
	.quad	0x4795701de53f4d2e, 0x47b4154bc68d75c3
	.quad	0x4794d17c968d062b, 0x47b3937b1b31925a
	.quad	0x479436df0cfabf1d, 0x47b31458e6542847
	.quad	0x4793a02ffb1b7cee, 0x47b297db960e4f63
	.quad	0x47930d5a6013afc5, 0x47b21df9981f8e53
	.quad	0x47927e49879737d3, 0x47b1a6a95b1e786f
	.quad	0x4791f2e909de04d2, 0x47b131e14fa1625d
	.quad	0x47916b24cb8f8f92, 0x47b0bf97e95f2a64
	.quad	0x4790e6e8fda56cf7, 0x47b04fc3a0481321
	.quad	0x479066221d4539d8, 0x47afc4b5e32d6259
	.quad	0x478fd179e7243e3c, 0x47aeeea8c1b1db94
	.quad	0x478edd4d2aec5adb, 0x47ae1d4cf1e2450a
	.quad	0x478def98c6c79efa, 0x47ad508f9a1ea64f
	.quad	0x478d0838121f2418, 0x47ac885df3451a07
	.quad	0x478c2706fa45005e, 0x47abc4a54a84e834
	.quad	0x478b4be201caa4b4, 0x47ab055303221015
	.quad	0x478a76a63fc95c79, 0x47aa4a549829587e
	.quad	0x4789a7315f1d6a55, 0x47a993979e14fffe
	.quad	0x4788dd619d943ca1, 0x47a8e109c4622913
	.quad	0x47881915cb0e3323, 0x47a83298d717210e
	.quad	0x47875a2d48946eb1, 0x47a78832c03aa2b1
	.quad	0x4786a08807632262, 0x47a6e1c5893c380b
	.quad	0x4785ec0687e8dcb2, 0x47a63f3f5c4de13b
	.quad	0x47853c89d8bb3ddb, 0x47a5a08e85af27e0
	.quad	0x478491f395818f54, 0x47a505a174e9c929
	.quad	0x4783ec25e5d5af12, 0x47a46e66be002240
	.quad	0x47834b037c1bbfc5, 0x47a3dacd1a8d8cce
	.quad	0x4782ae6f94510dd8, 0x47a34ac36ad8dafe
	.quad	0x4782164df2d29765, 0x47a2be38b6d92415
	.quad	0x47818282e31ba3e8, 0x47a2351c2f2d1449
	.quad	0x4780f2f3367cd6aa, 0x47a1af5d2e04f3f6
	.quad	0x4780678442cc256f, 0x47a12ceb37ff9bc3
	.quad	0x477fc037c21c3622, 0x47a0adb5fcfa8c75
	.quad	0x477eb940d8319831, 0x47a031ad58d56279
	.quad	0x477db9f17e61c310, 0x479f7182a851bca2
	.quad	0x477cc218694238a2, 0x479e85c449e377f3
	.quad	0x477bd18548996419, 0x479da0005e5f28df
	.quad	0x477ae808c479c371, 0x479cc0180af00a8b
	.quad	0x477a05747a543aa7, 0x479be5ecd2fcb5f9
	.quad	0x4779299afa0246a6, 0x479b1160991ff737
	.quad	0x4778544fc2c8c1da, 0x479a4255a00b9f03
	.quad	0x477785674053e8b9, 0x479978ae8b55ce1b
	.quad	0x4776bcb6c7ad4854, 0x4798b44e6031383e
	.quad	0x4775fa14942c3d54, 0x4797f5188610ddc8
	.quad	0x47753d57c461a5a7, 0x47973af0c737bb45
	.quad	0x4774865856ff632a, 0x479685bb5134ef13
	.quad	0x4773d4ef27bc49a6, 0x4795d55cb54cd53a
	.quad	0x477328f5ec350e67, 0x479529b9e8cf9a1e
	.quad	0x4772824730cacbb4, 0x479482b8455dc491
	.quad	0x4771e0be557fa673, 0x4793e03d891b37de
	.quad	0x477144378ad22027, 0x4793422fd6d12e2b
	.quad	0x4770ac8fce979b96, 0x4792a875b5ffab56
	.quad	0x477019a4e8d69649, 0x479212f612dee7fb
	.quad	0x476f16aad1422a55, 0x479181983e5133dd
	.quad	0x476e030141df7d25, 0x4790f443edc5ce49
	.quad	0x476cf80d4afc3019, 0x47906ae13b0d3255
	.quad	0x476bf5908f50b4a0, 0x478fcab1483ea7fc
	.quad	0x476afb4e269693df, 0x478ec72615a894c4
	.quad	0x476a090a974cfebe, 0x478dcaf3691fc448
	.quad	0x47691e8bd0830a74, 0x478cd5ec93c12432
	.quad	0x47683b9923a85f7b, 0x478be7e5ac24963b
	.quad	0x47675ffb3e6519a0, 0x478b00b38d6b3575
	.quad	0x47668b7c2479902d, 0x478a202bd6372dce
	.quad	0x4765bde729a6b60f, 0x47894624e78e0faf
	.quad	0x4764f708eb9fba63, 0x47887275e3a6869e
	.quad	0x476436af4c058acb, 0x4787a4f6aca256cb
	.quad	0x47637ca96a6cd1d4, 0x4786dd7fe3358230
	.quad	0x4762c8c79e6f04a3, 0x47861beae53b72b7
	.quad	0x47621adb71c70c75, 0x47856011cc3b036d
	.quad	0x476172b79a7a1181, 0x4784a9cf6bda3f4c
	.quad	0x4760d02ff50ce651, 0x4783f8ff5042a88e
	.quad	0x476033197ec68c0e, 0x47834d7dbc76d7e5
	.quad	0x475f3694a0008381, 0x4782a727a89a3f14
	.quad	0x475e11332d0714c5, 0x478205dac02bd6b9
	.quad	0x475cf5bf1fed1e70, 0x4781697560347b26
	.quad	0x475be3eb08ae7c20, 0x4780d1d69569b82d
	.quad	0x475adb6b810af9e2, 0x47803ede1a45bfee
	.quad	0x4759dbf721b98dfa, 0x477f60d8aa2a88f2
	.quad	0x4758e54677bb0151, 0x477e4cc4abf7d065
	.quad	0x4757f713f9cc9784, 0x477d4143a9dfe965
	.quad	0x4757111bfdfb3ce0, 0x477c3e1a5f5c077c
	.quad	0x4756331caf57b5db, 0x477b430ecf4a83a8
	.quad	0x47555cd603cc4150, 0x477a4fe83fb9db25
	.quad	0x47548e09b21414bf, 0x4779646f35a76624
	.quad	0x4753c67b27d50fe7, 0x4778806d70b2fc36
	.quad	0x475305ef7fdbfb95, 0x4777a3ade6c8b3e5
	.quad	0x47524c2d787b9e37, 0x4776cdfcbfc1e263
	.quad	0x475198fd6a0ee7bd, 0x4775ff2750fe7820
	.quad	0x4750ec293d9e6d85, 0x477536fc18f7ce5c
	.quad	0x4750457c63a96690, 0x4774754abacdf1dc
	.quad	0x474f49879624a021, 0x4773b9e3f9d06e3f
	.quad	0x474e139bb05eb49e, 0x47730499b503957f
	.quad	0x474ce8d4b7fd6c70, 0x4772553ee2a336bf
	.quad	0x474bc8d516fda8ba, 0x4771aba78ba3af89
	.quad	0x474ab341ee553e25, 0x477107a8c7323a6e
	.quad	0x4749a7c305336484, 0x47706918b6355624
	.quad	0x4748a602b88919c0, 0x476f9f9cfd9c3035
	.quad	0x4747adadead962ed, 0x476e77448fb66bb9
	.quad	0x4746be73f45149fb, 0x476d58da68fd1170
	.quad	0x4745d80693276a6d, 0x476c4412bf4b8f0b
	.quad	0x4744fa19dc42d409, 0x476b38a3af2e55b4
	.quad	0x474424642c28ff75, 0x476a3645330550ff
	.quad	0x4743569e18328604, 0x47693cb11a30d765
	.quad	0x47429082600643fd, 0x47684ba3004a50d0
	.quad	0x4741d1cddf5a82de, 0x476762d84469c18f
	.quad	0x47411a3f7ffbbfea, 0x4766821000795a03
	.quad	0x474069982c189a9e, 0x4765a90b00981d93
	.quad	0x473f7f3581a4dc2c, 0x4764d78bba8ca5fd
	.quad	0x473e381802242163, 0x47640d564548fad7
	.quad	0x473cfd6511405b2d, 0x47634a305080681f
	.quad	0x473bcead7f01492f, 0x47628de11c5031eb
	.quad	0x473aab859b20ac9e, 0x4761d83170fbf6fb
	.quad	0x473993851cc9779a, 0x476128eb96be8798
	.quad	0x473886470ad946a7, 0x47607fdb4dafea5f
	.quad	0x47378369a4a2cbd6, 0x475fb99b8b8279e1
	.quad	0x47368a8e4b2fc8c2, 0x475e7f232d9e2630
	.quad	0x47359b596b012aaa, 0x475d4fed7195d7e8
	.quad	0x4734b572664bd2dc, 0x475c2b9cf7f893bf
	.quad	0x4733d8837fb08d1d, 0x475b11d702b3deb2
	.quad	0x47330439c56dadf6, 0x475a024365f771bd
	.quad	0x47323844fd08cb93, 0x4758fc8c794b03b5
	.quad	0x473174578f6efd5d, 0x4758005f08d6f1ef
	.quad	0x4730b826758a086b, 0x47570d6a46e07dda
	.quad	0x473003692548d98b, 0x4756235fbd7a4345
	.quad	0x472eabb2fe335196, 0x475541f340697987
	.quad	0x472d5e6777a83c2a, 0x475468dadf4080ab
	.quad	0x472c1e6cb6239574, 0x475397ced7af2b15
	.quad	0x472aeb4423e690e7, 0x4752ce898809244e
	.quad	0x4729c47374a0974e, 0x47520cc76202c5fb
	.quad	0x4728a98484a1e8d3, 0x47515246dda49d47
	.quad	0x47279a0538dd4fc7, 0x47509ec86c75d497
	.quad	0x472695875fb574a0, 0x474fe41cd9bb4eee
	.quad	0x47259ba0929261c5, 0x474e97ba3b77f306
	.quad	0x4724abea183bc470, 0x474d57f524723822
	.quad	0x4723c600c7f477c5, 0x474c245d4b99847a
	.quad	0x4722e984ed53e777, 0x474afc85e0f82e12
	.quad	0x4722161a2cd9d894, 0x4749e005769dbc1d
	.quad	0x47214b67693928cf, 0x4748ce75e9f6f8a0
	.quad	0x47208916a9561720, 0x4747c7744d9378f7
	.quad	0x471f9da9fde95755, 0x4746caa0d3582fe9
	.quad	0x471e38a4dc27b11b, 0x4745d79eb71e893b
	.quad	0x471ce283a9e3e330, 0x4744ee1429bf7cc0
	.quad	0x471b9ab1a96e3b3e, 0x47440daa3c89f5b6
	.quad	0x471a609f7584d32b, 0x4743360ccd23db3a
	.quad	0x471933c2d52c56c9, 0x474266ea71d4f71a
	.quad	0x4718139690c0d187, 0x47419ff4663ae9df
	.quad	0x4716ff9a4837fa43, 0x4740e0de78654d1e
	.quad	0x4715f7524a8e81a2, 0x4740295ef6591848
	.quad	0x4714fa476e59f668, 0x473ef25d37f49fe1
	.quad	0x47140806eb78e353, 0x473da01102b5f851
	.quad	0x4713202235dada50, 0x473c5b5412dcafad
	.quad	0x4712422ed95a3235, 0x473b23a5a23e4210
	.quad	0x47116dc656a14df6, 0x4739f8893d8fd1c1
	.quad	0x4710a2860115569c, 0x4738d986a4187285
	.quad	0x470fc01dbb80c841, 0x4737c629a822bc9e
	.quad	0x470e4c0b066a4970, 0x4736be02102b3520
	.quad	0x470ce823f4cc4bad, 0x4735c0a378c90bca
	.quad	0x470b93bf40d5eccb, 0x4734cda5374ea275
	.quad	0x470a4e3a125adc76, 0x4733e4a23d1f4703
	.quad	0x470916f7c5f2f764, 0x47330538fbb77ecd
	.quad	0x4707ed61b5d3db0a, 0x47322f0b496539be
	.quad	0x4706d0e7045988cb, 0x473161be46ad3b50
	.quad	0x4705c0fc68335b0c, 0x47309cfa445b00ff
	.quad	0x4704bd1bfa2aba3d, 0x472fc0d55470cf51
	.quad	0x4703c4c504792bf8, 0x472e577bbcd49935
	.quad	0x4702d77bd3a382bc, 0x472cfd4a5adec5c0
	.quad	0x4701f4c988d02149, 0x472bb1a9657ce465
	.quad	0x47011c3bed8e716a, 0x472a740684026555
	.quad	0x47004d654905dad0, 0x472943d4a1d1ed39
	.quad	0x46ff0fb86d056745, 0x4728208bc334a6a5
	.quad	0x46fd9676faafa27f, 0x472709a8db59f25c
	.quad	0x46fc2e43d417197b, 0x4725feada379d8b7
	.quad	0x46fad664518e771b, 0x4724ff207314a102
	.quad	0x46f98e25420092da, 0x47240a8c1949f75e
	.quad	0x46f854daa4a49b0f, 0x4723207fb7420eb9
	.quad	0x46f729df6503422a, 0x4722408e9ba3327f
	.quad	0x46f60c95193c542d, 0x47216a501f0e42ca
	.quad	0x46f4fc63c27c71ae, 0x47209d5f819c9e29
	.quad	0x46f3f8b98f93052a, 0x471fb2b792b40a22
	.quad	0x46f3010aa198de78, 0x471e3bcf436a1a95
	.quad	0x46f214d0d2983650, 0x471cd55277c18d05
	.quad	0x46f1338b7e273194, 0x471b7e94604479dc
	.quad	0x46f05cbf4be650ab, 0x471a36eec00926dd
	.quad	0x46ef1febf7a916aa, 0x4718fdc1b2dcf7b9
	.quad	0x46ed997c68d65936, 0x4717d2737527c3f9
	.quad	0x46ec2556a4e7a90f, 0x4716b4702d7d5849
	.quad	0x46eac2aa7516ade4, 0x4715a329b7d30748
	.quad	0x46e970b05888fda2, 0x47149e17724f4d41
	.quad	0x46e82ea92dbc1a27, 0x4713a4b60ba9aa4e
	.quad	0x46e6fbdddeff308f, 0x4712b6875310f785
	.quad	0x46e5d79f11e27f6b, 0x4711d312098e9dba
	.quad	0x46e4c144d984e1b8, 0x4710f9e1b4dd36df
	.quad	0x46e3b82e6ba892a4, 0x47102a8673a94692
	.quad	0x46e2bbc1d878d272, 0x470ec929a665b449
	.quad	0x46e1cb6bc4eaa678, 0x470d4f4b4c8e09ed
	.quad	0x46e0e69f27a37df3, 0x470be6abbb10a5aa
	.quad	0x46e00cd508511266, 0x470a8e8cc1fadef6
	.quad	0x46de7b1882bccac5, 0x47094637d5bacfdb
	.quad	0x46dcf09287e48bb9, 0x47080cfdc72220cf
	.quad	0x46db792bbc489b04, 0x4706e2367dc27f95
	.quad	0x46da140206ab9450, 0x4705c540b4936fd2
	.quad	0x46d8c03d2d39119b, 0x4704b581b8d170fc
	.quad	0x46d77d0e6e5bed21, 0x4703b2652b06c2b2
	.quad	0x46d649b01d73110a, 0x4702bb5cc22e5db6
	.quad	0x46d525654343aad2, 0x4701cfe010e2052d
	.quad	0x46d40f79420887c7, 0x4700ef6c4c84a0fe
	.quad	0x46d3073f7cff4a85, 0x47001984165a5f36
	.quad	0x46d20c1303550f0e, 0x46fe9b5e8d00ce77
	.quad	0x46d11d563e54f40e, 0x46fd16f5716c6c1a
	.quad	0x46d03a72a2bbdc06, 0x46fba4f035d60e03
	.quad	0x46cec5b0ca2b20f5, 0x46fa447b7b03f045
	.quad	0x46cd2bfc6210880a, 0x46f8f4ccca7fc90d
	.quad	0x46cba6c1c6e87c40, 0x46f7b5223dac7336
	.quad	0x46ca35068e9c89cf, 0x46f684c227fcacef
	.quad	0x46c8d5dbaa383b98, 0x46f562fac4329b48
	.quad	0x46c7885ce9f67cdb, 0x46f44f21e49054f2
	.quad	0x46c64bb0863504dd, 0x46f34894a5e24657
	.quad	0x46c51f06ad20e4c3, 0x46f24eb7254ccf83
	.quad	0x46c4019914f0b53a, 0x46f160f438c70913
	.quad	0x46c2f2aa92823e80, 0x46f07ebd2a2d2844
	.quad	0x46c1f186b432c98b, 0x46ef4f12e9ab070a
	.quad	0x46c0fd8160ca94a0, 0x46edb5ad0b27805c
	.quad	0x46c015f67a552924, 0x46ec304efa2c6f4e
	.quad	0x46be749309831666, 0x46eabe09e9144b5e
	.quad	0x46bcd3caa04cdd1b, 0x46e95df988e76644
	.quad	0x46bb48774d0f8e45, 0x46e80f439b4ee04b
	.quad	0x46b9d189f9f85cbf, 0x46e6d11788a69c64
	.quad	0x46b86e0050236315, 0x46e5a2adfa0b4bc4
	.quad	0x46b71ce426a561d3, 0x46e4834877429b8f
	.quad	0x46b5dd4af79906a9, 0x46e37231085c7d9a
	.quad	0x46b4ae555af52cdf, 0x46e26eb9daed6f7e
	.quad	0x46b38f2e86f38216, 0x46e1783ceac28910
	.quad	0x46b27f0bd5d0e6b1, 0x46e08e1badf0fced
	.quad	0x46b17d2c50b2bfaf, 0x46df5f7d88472604
	.quad	0x46b088d83f7e4069, 0x46ddb92b5212fb8d
	.quad	0x46af42c17ae0ebf6, 0x46dc282cd3957eda
	.quad	0x46ad8c3ea48f2889, 0x46daab7abace48dc
	.quad	0x46abeceb1f9f5b3d, 0x46d94219bfcb4928
	.quad	0x46aa6399674d366b, 0x46d7eb1a2075864e
	.quad	0x46a8ef2a9a18d857, 0x46d6a597219a93da
	.quad	0x46a78e8dcd2e6bfd, 0x46d570b69502f313
	.quad	0x46a640bf6745325e, 0x46d44ba864670882
	.quad	0x46a504c882a97424, 0x46d335a62115bce2
	.quad	0x46a3d9be56279ee9, 0x46d22df298214423
	.quad	0x46a2bec1a4917edb, 0x46d133d96ae7e0dd
	.quad	0x46a1b2fe32991d5c, 0x46d046aeabcfcdec
	.quad	0x46a0b5aa42bf5054, 0x46cecb9cfe1d8642
	.quad	0x469f8c0c2e2ce8de, 0x46cd21397ead99cb
	.quad	0x469dc6b6f1384e18, 0x46cb8d094c86d374
	.quad	0x469c19fa87de37fb, 0x46ca0df0f0c626dc
	.quad	0x469a848df650bea7, 0x46c8a2e269750a39
	.quad	0x46990538b942ea7c, 0x46c74adc8f4064d3
	.quad	0x46979ad1fce5b3d8, 0x46c604ea819f007c
	.quad	0x4696443fdcf0c327, 0x46c4d0231928c6f9
	.quad	0x46950076ad55cc39, 0x46c3aba85fe22e20
	.quad	0x4693ce784b411931, 0x46c296a70f414053
	.quad	0x4692ad53760d7287, 0x46c1905613b3abf2
	.quad	0x46919c232fd50b88, 0x46c097f6156f32c5
	.quad	0x46909a0e254c75e0, 0x46bf59a20caf6695
	.quad	0x468f4c8c392fb944, 0x46bd9c73698fb1dc
	.quad	0x468d800ed59bd026, 0x46bbf716c6168bae
	.quad	0x468bcd30dfbd611b, 0x46ba6852c6b58392
	.quad	0x468a32923130213f, 0x46b8eefd70594a89
	.quad	0x4688aee4cd06ec1b, 0x46b789fb715aae95
	.quad	0x468740ebfab80eb4, 0x46b6383f726a8e04
	.quad	0x4685e77b6bbd2127, 0x46b4f8c96f26a26a
	.quad	0x4684a1766b6e5e8a, 0x46b3caa61607f920
	.quad	0x46836dcf18a6465c, 0x46b2acee2f5ecdb8
	.quad	0x46824b85a8bf0124, 0x46b19ec60b1242ed
	.quad	0x468139a7b37f8475, 0x46b09f5cf4dd2877
	.quad	0x4680374f8792ca97, 0x46af5bd95d8730d8
	.quad	0x467e87470e4f4246, 0x46ad9371e2ff7c35
	.quad	0x467cbbab18b73217, 0x46abe41de54d155a
	.quad	0x467b0a44aa2f067e, 0x46aa4c89e08ef4f3
	.quad	0x467971a1ec0f40c7, 0x46a8cb738399b12c
	.quad	0x4677f064a8ba8323, 0x46a75fa8dbc84bec
	.quad	0x467685414c16188e, 0x46a608078a70dcbc
	.quad	0x46752efdf060cd20, 0x46a4c37c0394d094
	.quad	0x4673ec7176d784b5, 0x46a39100d5687bfe
	.quad	0x4672bc82ab9d2302, 0x46a26f9df8519bd7
	.quad	0x46719e2774614040, 0x46a15e6827001f18
	.quad	0x467090640946d2d5, 0x46a05c803e4831c1
	.quad	0x466f24946f22d5ae, 0x469ed22548cffd35
	.quad	0x466d45f15b49b35e, 0x469d06ad6ecdf971
	.quad	0x466b83349fd05191, 0x469b551c847fbc96
	.quad	0x4669dacb2c432ef4, 0x4699bc09f112b494
	.quad	0x46684b37e1cbf8eb, 0x46983a1ff0aa239d
	.quad	0x4666d3126d74b6cc, 0x4696ce1aa3fd7bdd
	.quad	0x4665710631158bff, 0x469576c72b514859
	.quad	0x466423d13a3b73e1, 0x46943302cc4a0da8
	.quad	0x4662ea43465e3995, 0x469301ba221dc9bb
	.quad	0x4661c33cd3c37add, 0x4691e1e857adc568
	.quad	0x4660adae3e73c2b5, 0x4690d2966b1746f7
	.quad	0x465f512dd15b73b7, 0x468fa5b4f49cc6b2
	.quad	0x465d6608dc942687, 0x468dc3ae30b55c16
	.quad	0x465b9823c51276e1, 0x468bfd7555a3bd68
	.quad	0x4659e5ce2f93dd76, 0x468a517d9e61628a
	.quad	0x46584d6fe15b6b93, 0x4688be4f8f6c951f
	.quad	0x4656cd87746bc76b, 0x46874287ded49339
	.quad	0x465564a91cd221f0, 0x4685dcd669f2cd34
	.quad	0x4654117d7e2c667d, 0x46848bfd38302871
	.quad	0x4652d2c0909ebeb9, 0x46834ecf8a3c124a
	.quad	0x4651a7409475f2f9, 0x46822430f521cbcf
	.quad	0x46508ddd13bd35e7, 0x46810b1488aeb235
	.quad	0x464f0b0be22d18e8, 0x4680027c00a263a6
	.quad	0x464d1a75065a8c74, 0x467e12ee004efc37
	.quad	0x464b48117843c1c7, 0x467c3e44ae32b16b
	.quad	0x46499218b8ac7f8e, 0x467a854ea14102a8
	.quad	0x4647f6dc6010b4ad, 0x4678e6761569f45d
	.quad	0x464674c6ae60d852, 0x4677603bac345f65
	.quad	0x46450a592e3c968e, 0x4675f1353cdad001
	.quad	0x4643b62b6aafb0c8, 0x4674980cb3c80949
	.quad	0x464276e9b681072f, 0x4673537f00b6ad4d
	.quad	0x46414b54042f445b, 0x4672225b12bffc68
	.quad	0x4640323ccdc1a3dc, 0x46710380e1adb7e9
	.quad	0x463e5510173b9a50, 0x466febc107d5efaa
	.quad	0x463c6654733b86ad, 0x466df0f2a0ee6947
	.quad	0x463a964ed354f984, 0x466c14b2188bcee4
	.quad	0x4638e324c651b064, 0x466a553644f7f07d
	.quad	0x46374b179d1eba81, 0x4668b0cfce0579e0
	.quad	0x4635cc82d9070d95, 0x466725e7c5dd20f7
	.quad	0x463465daafca8b1d, 0x4665b2fe547a1340
	.quad	0x463315aaa46df48e, 0x466456a974e92e93
	.quad	0x4631da9433aebbcf, 0x46630f93c3699078
	.quad	0x4630b34d93135fc0, 0x4661dc7b5b978cf8
	.quad	0x462f3d41033c44cc, 0x4660bc30c5d52f15
	.quad	0x462d36d25268cd2b, 0x465f5b2be65a0c7f
	.quad	0x462b512a1fb1d8fc, 0x465d5f3a8dea7357
	.quad	0x46298a442fc4fc15, 0x465b82915b03515b
	.quad	0x4627e03b1cc6d738, 0x4659c3517e789488
	.quad	0x462651468e010b8a, 0x46581fb7df06136e
	.quad	0x4624dbb989001d84, 0x4656961b8d641d06
	.quad	0x46237e00dac4e8b5, 0x465524ec4d916cae
	.quad	0x462236a197bf0b9a, 0x4653cab1343d18d1
	.quad	0x46210437b1569d7e, 0x4652860757487a01
	.quad	0x461fcae93fb7323c, 0x465155a09065d4f7
	.quad	0x461db23c3f816f92, 0x4650384250e4c9fc
	.quad	0x461bbc1a022c14d4, 0x464e59890b926c78
	.quad	0x4619e658108af2e0, 0x464c642116a8a9e3
	.quad	0x46182eedbe410407, 0x464a8e405e651ab6
	.quad	0x461693f22ab61ce9, 0x4648d5f98114f872
	.quad	0x4615139a5f3661fb, 0x4647397c5a66e307
	.quad	0x4613ac3788a1b429, 0x4645b71456c5a4c4
	.quad	0x46125c354b26cb4e, 0x46444d26de513197
	.quad	0x461122182e9a270f, 0x4642fa31d6371537
	.quad	0x460ff8f84418d510, 0x4641bcca373b7b43
	.quad	0x460dd4262aac53e8, 0x4640939ab853339f
	.quad	0x460bd3474ec16ca5, 0x463efac5187b2863
	.quad	0x4609f40fd0082b72, 0x463cf1e86235d0e7
	.quad	0x4608345858c4438d, 0x463b0a68a2128bab
	.quad	0x4606921be96b86b1, 0x4639423165bc4444
	.quad	0x46050b75c536f927, 0x4637974e743dea3d
	.quad	0x46039e9f7dcbe479, 0x463607e9eacd1050
	.quad	0x460249ef1c3be817, 0x4634924a74dec729
	.quad	0x46010bd565b35393, 0x463334d19e0c2160
	.quad	0x45ffc5b8748842b2, 0x4631edfa3c5f5cca
	.quad	0x45fd9b4a18a38642, 0x4630bc56f1b54701
	.quad	0x45fb95cede6d524b, 0x462f3d2185e047d9
	.quad	0x45f9b2df77a02225, 0x462d26cb87945e87
	.quad	0x45f7f03b935e8e3a, 0x462b334fac4b9f99
	.quad	0x45f64bc777824f0e, 0x46296076f7918d1c
	.quad	0x45f4c389be9acb83, 0x4627ac2d72fc2c63
	.quad	0x45f355a9387de78c, 0x462614801550319e
	.quad	0x45f2006aeb6bc768, 0x4624979ac8b28927
	.quad	0x45f0c23033e2a376, 0x462333c68e2d0548
	.quad	0x45ef32ea02b55d23, 0x4621e767bce37dd7
	.quad	0x45ed099c5c770f5a, 0x4620b0fc5b6d05a0
	.quad	0x45eb05cfe2e99435, 0x461f1e3523b41d7d
	.quad	0x45e92508d0743fc9, 0x461d00de6608effe
	.quad	0x45e764f46cf19f9c, 0x461b0778b7b3301b
	.quad	0x45e5c36679625a01, 0x46192fb04ec0f6cf
	.quad	0x45e43e56c3e340a7, 0x46177756ec9f78fa
	.quad	0x45e2d3dee1869201, 0x4615dc61922d5a06
	.quad	0x45e182380bd2f494, 0x46145ce65699ff6d
	.quad	0x45e047b91fcb6491, 0x4612f71a5f159970
	.quad	0x45de45a9790460c1, 0x4611a94ff571654f
	.quad	0x45dc242efeaca760, 0x461071f4bbea09ec
	.quad	0x45da284cb82c31ce, 0x460e9f1ff8ddd774
	.quad	0x45d84f7a1eb7f7f3, 0x460c818223a202c7
	.quad	0x45d697595326d7dc, 0x460a887bd2b4404d
	.quad	0x45d4fdb462549af1, 0x4608b1a336c5eb6b
	.quad	0x45d3807ab51436a8, 0x4606fab63324088a
	.quad	0x45d21dbea9108398, 0x46056197e30205ba
	.quad	0x45d0d3b35021d695, 0x4603e44e45301b92
	.quad	0x45cf4154a787cc1b, 0x460281000bfe4c3f
	.quad	0x45cd0623f4f4a28f, 0x460135f28f2d50b4
	.quad	0x45caf2e69a262610, 0x46000187dded5975
	.quad	0x45c904e0b3aa82a3, 0x45fdc479de0ef001
	.quad	0x45c73985278fa30e, 0x45fbad4fdad3caa1
	.quad	0x45c58e7298af87d9, 0x45f9baed3ed27ab8
	.quad	0x45c401708b7e64c6, 0x45f7ead9ce4285bb
	.quad	0x45c2906cb94eb40d, 0x45f63ac6b4edc88e
	.quad	0x45c139788f2dd663, 0x45f4a88be2a6390c
	.quad	0x45bff58dab4f2a79, 0x45f332259185f1a0
	.quad	0x45bda552fdd03043, 0x45f1d5b1f3793044
	.quad	0x45bb7f1f31b571b6, 0x45f0916f04b6e18b
	.quad	0x45b98006c2117e39, 0x45eec77101de6926
	.quad	0x45b7a550f03b145b, 0x45ec960bf23153e0
	.quad	0x45b5ec74662c5961, 0x45ea8bd20fc65ef7
	.quad	0x45b453141082302a, 0x45e8a61745ec7d1d
	.quad	0x45b2d6fc2c9e8bc0, 0x45e6e25d0e756261
	.quad	0x45b1761f87a6dc3d, 0x45e53e4f7d1666cb
	.quad	0x45b02e94eb4ac8a5, 0x45e3b7c27a7ddb0e
	.quad	0x45adfd296adef82a, 0x45e24caf2c32af14
	.quad	0x45abc8ed301215eb, 0x45e0fb3186804d0f
	.quad	0x45a9bd5efd2c0f15, 0x45df830c0bb41fd7
	.quad	0x45a7d79f2db2d4a5, 0x45dd3c0f1a91c846
	.quad	0x45a61500f5293f06, 0x45db1e5acf351d87
	.quad	0x45a47306f04df3d6, 0x45d92712d259ce66
	.quad	0x45a2ef5ff0323b28, 0x45d7538c60a04476
	.quad	0x45a187e3fb74914d, 0x45d5a14b04b47879
	.quad	0x45a03a918225a966, 0x45d40dfd87456f4c
	.quad	0x459e0b15822be4e0, 0x45d2977b1172b9d5
	.quad	0x459bce26a2fb7176, 0x45d13bc07e891491
	.quad	0x4599bb1bc445c3c6, 0x45cff1dbb4300811
	.quad	0x4597cef42e9a617d, 0x45cd9a880f306bd8
	.quad	0x459606e51e0a4963, 0x45cb6e45220b55e0
	.quad	0x459460560e841d79, 0x45c96a0b33f2c4da
	.quad	0x4592d8dd47a40ad8, 0x45c78b07e9e924ac
	.quad	0x45916e3ca3d4393f, 0x45c5ce9ab1670dd2
	.quad	0x45901e5e8edda47b, 0x45c4325167006bb0
	.quad	0x458dcea670907819, 0x45c2b3e53538ff3f
	.quad	0x458b8e9bec48816d, 0x45c15137a7f44864
	.quad	0x45897945aa1c9c35, 0x45c0084ff125639d
	.quad	0x45878b88a4e7107b, 0x45bdaeb0b7311ec7
	.quad	0x4585c2827c986b62, 0x45bb7937d1c40c53
	.quad	0x45841b858361b0fe, 0x45b96d082f59ab06
	.quad	0x458294150fb19119, 0x45b7872d9fa10aad
	.quad	0x458129e20e732adc, 0x45b5c4e8e37bc7d0
	.quad	0x457fb58fa290d436, 0x45b423ac0df49a40
	.quad	0x457d499229819bc6, 0x45b2a117230ad284
	.quad	0x457b0c1a759f7739, 0x45b13af4f04f9998
	.quad	0x4578f9bb6c075486, 0x45afde703724e560
	.quad	0x45770f4744735c2b, 0x45ad77f0c82e7641
	.quad	0x457549cb0f7ef8e2, 0x45ab3ee02611d7dd
	.quad	0x4573a68a8c1234e1, 0x45a92ff33023d5bd
	.quad	0x457222fc469e8b8c, 0x45a7481a9e69f53f
	.quad	0x4570bcc5fd30f1dd, 0x45a5847eda620959
	.quad	0x456ee3728761897b, 0x45a3e27c1fcc74bd
	.quad	0x456c7fa0c7e3bac7, 0x45a25f9ee0b923dc
	.quad	0x456a4a56eb132a54, 0x45a0f9a068653200
	.quad	0x4568401b5336a8a0, 0x459f5cc7718082b0
	.quad	0x45665db58e2358c1, 0x459cf7e53d6a2ca5
	.quad	0x4564a029a7ea7cd1, 0x459ac0f5f3229372
	.quad	0x456304b3d1961171, 0x4598b498644847ea
	.quad	0x456188c45630dc53, 0x4596cfa9bcca59dc
	.quad	0x456029fbd8b92835, 0x45950f411d4fd2cd
	.quad	0x455dcc4fabf32f1c, 0x459370ab8327af5e
	.quad	0x455b767ecb334a7e, 0x4591f167f88c6b6e
	.quad	0x45594ec06c0ff29f, 0x45908f24085d4597
	.quad	0x455751977e5803d3, 0x458e8f70e181d61a
	.quad	0x45557bc950253825, 0x458c324c20e337dc
	.quad	0x4553ca58b816a87f, 0x458a03261574b54e
	.quad	0x45523a8197d2607e, 0x4587fe903cdf5855
	.quad	0x4550c9b4b0a6a16f, 0x4586215c58da3450
	.quad	0x454eeb27891d2bb3, 0x45846897d4b69fc6
	.quad	0x454c77dbfc848866, 0x4582d1877d731b7b
	.quad	0x454a357936adf17b, 0x458159a386b11517
	.quad	0x4548203fa7992554, 0x457ffd27ae9393ce
	.quad	0x454634b7f56b0a5c, 0x457d7c593130dd0b
	.quad	0x45446fada7e6a5fe, 0x457b2cd607c79bcf
	.quad	0x4542ce2a3690576b, 0x45790ae4d3405651
	.quad	0x45414d707280e6cf, 0x45771312dd1759e2
	.quad	0x453fd5f08ad2b29a, 0x4575422ef5d8949d
	.quad	0x453d48d57f7718b7, 0x45739544b0ecc957
	.quad	0x453aef3ce0add578, 0x45720997f73e73dd
	.quad	0x4538c52800f939c8, 0x45709ca0eaacd277
	.quad	0x4536c6e61e57bf9b, 0x456e9810295890ec
	.quad	0x4534f10e8ebc44a9, 0x456c2b45b5aa4a1d
	.quad	0x4533407b59d72a5b, 0x4569eee068fa7596
	.quad	0x4531b2443858c0a1, 0x4567df2b399c10a8
	.quad	0x453043b9f1621ff3, 0x4565f8b87a31bd85
	.quad	0x452de4c41eb96b45, 0x4564385c96e9a2d9
	.quad	0x452b77e5cbd5d147, 0x45629b2933ef4cbc
	.quad	0x45293c9fc62bfb11, 0x45611e68a6378f8a
	.quad	0x45272f0c4c8e9bff, 0x455f7f338086a86b
	.quad	0x45254b92affb11af, 0x455cf8d7d9ce040a
	.quad	0x45238ee17b150182, 0x455aa577251ae485
	.quad	0x4521f5e908f70e0c, 0x4558811d739efb5f
	.quad	0x45207dd6833bb380, 0x45568823e52970be
	.quad	0x451e481e7f6ac4bc, 0x4554b72ae68e8b4c
	.quad	0x451bcc58edad5559, 0x45530b14dbe876bc
	.quad	0x451983ee9896d582, 0x455181012ef86610
	.quad	0x45176aca47764427, 0x45501647ba798745
	.quad	0x45157d287836bd3d, 0x454d90e917701675
	.quad	0x4513b79118c097a1, 0x454b2a87e86d0c8a
	.quad	0x451216d1b97279a9, 0x4548f53dcb377293
	.quad	0x451097f82fc04025, 0x4546ed2f2515e933
	.quad	0x450e709b415656d0, 0x45450ecc9ed47f19
	.quad	0x450beaa3d6c15504, 0x454356cd5ce7799e
	.quad	0x4509996ed9b83967, 0x4541c229a587ab78
	.quad	0x450778be2bd9795b, 0x45404e15ecc7f3f6
	.quad	0x450584a99af8a842, 0x453deffc7e6a6017
	.quad	0x4503b99832cbefdd, 0x453b7b040832f310
	.quad	0x4502143a112d0466, 0x453938e021f36d76
	.quad	0x45009182b326b229, 0x4537258610b3b233
	.quad	0x44fe5d47637f5db5, 0x45353d3bfc82a909
	.quad	0x44fbd20fcc3b76d7, 0x45337c92babdc2fd
	.quad	0x44f97c9dda748fc7, 0x4531e06010120f6a
	.quad	0x44f7589207e91ad1, 0x453065b9616170d4
	.quad	0x44f561e669aa7fdb, 0x452e13dd96b3753b
	.quad	0x44f394e7a2ac9fc7, 0x452b950d32467392
	.quad	0x44f1ee2e61eccc99, 0x45294a72263259a5
	.quad	0x44f06a996198f06f, 0x45272fd93e036cdc
	.quad	0x44ee0e8fbad2703e, 0x45254164576929ab
	.quad	0x44eb8328ee330ae9, 0x45237b83c521fe96
	.quad	0x44e92e21013a7670, 0x4521daf033182e96
	.quad	0x44e70aff489136eb, 0x45205ca50205d26a
	.quad	0x44e515a7c77fab48, 0x451dfbb6235639fa
	.quad	0x44e34a53ce0bbb6f, 0x451b7807e294781f
	.quad	0x44e1a58b2b09fdcb, 0x4519298add70a734
	.quad	0x44e0241de6c31e5b, 0x45170beaf9c7ffb6
	.quad	0x44dd863cf753825c, 0x45151b2cd6709222
	.quad	0x44daffb906d0ae09, 0x451353a6cf7f7fff
	.quad	0x44d8afbf9e9520c2, 0x4511b1fa8cbe84a7
	.quad	0x44d691c7c768bece, 0x4510330f0fd69921
	.quad	0x44d4a1a79df39cde, 0x450da81670f96f9b
	.quad	0x44d2db8ca9009091, 0x450b24a16b4d09aa
	.quad	0x44d13bf4cb384e4a, 0x4508d6eeb6efdbd6
	.quad	0x44cf7f4f88751db4, 0x4506ba91ac734786
	.quad	0x44ccc7626bced452, 0x4504cb7966770ab5
	.quad	0x44ca4ab6470c1c5c, 0x450305e9721d0981
	.quad	0x44c80451c2811052, 0x4501667311fff70a
	.quad	0x44c5efa4d64f59f6, 0x44ffd3de10d62855
	.quad	0x44c40880373ed740, 0x44fd1aefbcd48d0c
	.quad	0x44c24b0d7368076e, 0x44fa9cc93c25aca9
	.quad	0x44c0b3c7b0d960f0, 0x44f85487ee3ea735
	.quad	0x44be7eea02e4ed88, 0x44f63daf8b4b1e0c
	.quad	0x44bbd6408059b696, 0x44f45421e69a6ca1
	.quad	0x44b96826d9e90341, 0x44f294175802d99a
	.quad	0x44b72fa4fa12d516, 0x44f0fa17bf41068f
	.quad	0x44b5282d2d5803fe, 0x44ef05e82aae2bb9
	.quad	0x44b34d935f1be064, 0x44ec578101b29058
	.quad	0x44b19c050c56d0d7, 0x44e9e39dc5dd2f7c
	.quad	0x44b01001dd9c7cce, 0x44e7a553a728bbf2
	.quad	0x44ad4ca9b634ecba, 0x44e5982008db1304
	.quad	0x44aab81c5c80cf39, 0x44e3b7e00422e51b
	.quad	0x44a85cfacb7477f2, 0x44e200c898d9ee3e
	.quad	0x44a6365862923eb9, 0x44e06f5f7eb65a56
	.quad	0x44a43fb317b5dc37, 0x44de00e9148a1d25
	.quad	0x44a274ea96044bd7, 0x44db623734024e92
	.quad	0x44a0d23817479c67, 0x44d8fd4e01891bf8
	.quad	0x449ea84dd1592590, 0x44d6cd44c7470d89
	.quad	0x449bef1b1a12823e, 0x44d4cd9c04158cd7
	.quad	0x4499730edfda64ac, 0x44d2fa34bf5c8344
	.quad	0x44972ede3b7eaa25, 0x44d14f4890ff2461
	.quad	0x44951db1ec3a3087, 0x44cf92c49dfa4df5
	.quad	0x44933b1c9d1576ec, 0x44cccaaea71ab0df
	.quad	0x44918311f8a03aca, 0x44ca40829f001197
	.quad	0x448fe3bcf4629fea, 0x44c7eef13b59e96c
	.quad	0x448d083fda665164, 0x44c5d11e1a252bf5
	.quad	0x448a6d7d18831888, 0x44c3e296303b2297
	.quad	0x44880dcd6603df1b, 0x44c21f47009f43ce
	.quad	0x4485e4062d5b6a4e, 0x44c083768c5e4542
	.quad	0x4483eb6ef47c2758, 0x44be1777d831265f
	.quad	0x44821fb7a81c5444, 0x44bb69f10b0191b5
	.quad	0x44807cefb734d68b, 0x44b8f8a3a05b5b53
	.quad	0x447dfefbdb19ac7e, 0x44b6be573c40c8e7
	.quad	0x447b4831fb123440, 0x44b4b645ba991fdb
	.quad	0x4478cf81557d20b6, 0x44b2dc119095729f
	.quad	0x44768f6f0feb4755, 0x44b12bbcfa4d62de
	.quad	0x447482fa78c40635, 0x44af4343c7d504b9
	.quad	0x4472a59289a484fb, 0x44ac74d4fe1e0e8b
	.quad	0x4470f30c4d0be5c0, 0x44a9e614ecbf4af6
	.quad	0x446ecf3428c48d4f, 0x44a791716475420c
	.quad	0x446bff86d9ec8499, 0x44a571d34563050a
	.quad	0x446970bb87f4ae14, 0x44a3829407a207d8
	.quad	0x44671d0b55b79b86, 0x44a1bf74244aed5a
	.quad	0x4464ff315d036fbd, 0x44a024924c7520d1
	.quad	0x4463125f6a3d2570, 0x449d5cc6ba567f29
	.quad	0x44615233ae8815f2, 0x449ab3560167ccaa
	.quad	0x445f755ea760487d, 0x449846e9dda7a163
	.quad	0x445c905bbd9ab5a6, 0x4496121d7db32bdd
	.quad	0x4459eebaa0589b4e, 0x449410047ead6894
	.quad	0x44578a6de0f41b89, 0x44923c2090cdde78
	.quad	0x44555df1790f2f61, 0x44909257fca001c0
	.quad	0x4453643ec463a3cf, 0x448e1dd9ec677783
	.quad	0x445198c18435598d, 0x448b5ceb5a13221b
	.quad	0x444fee9bab9f4e14, 0x4488dbaa11de2037
	.quad	0x444cf82e0eb6196b, 0x448694680a9a3ee6
	.quad	0x444a474e7029a919, 0x448481f73b3778e8
	.quad	0x4447d5af6513e2be, 0x44829f9e7d8fd094
	.quad	0x44459d93e1d8f57d, 0x4480e90f64b5b103
	.quad	0x444399c279e4699a, 0x447eb4b9e47b58c9
	.quad	0x4441c579bbca6885, 0x447bdfe62f60dd70
	.quad	0x44401c659160612d, 0x44794d1de5c4576f
	.quad	0x443d352b1ae26940, 0x4476f66f6ab90c3c
	.quad	0x443a78e8252c204d, 0x4474d67050b31c2a
	.quad	0x4437fd7c80f3410e, 0x4472e8318008cf89
	.quad	0x4435bcf92cc55d86, 0x4471273463a1589b
	.quad	0x4433b1f876b10da7, 0x446f1ec20afad0e2
	.quad	0x4431d791bb1324a1, 0x446c39fa0d4a5a2b
	.quad	0x4430294e37abcee8, 0x44699946bf7e02a1
	.quad	0x442d463db5fa3c13, 0x44673679b24aeb9b
	.quad	0x442a82a5f4047a5b, 0x44650bf2558ab78f
	.quad	0x4428011fb05fe090, 0x446314916abfa1ea
	.quad	0x4425bb91decf8a58, 0x44614bad9006f53b
	.quad	0x4423ac71ce35c1d3, 0x445f5a1196b5bb2e
	.quad	0x4421ceb656955c59, 0x445c698e001f6d30
	.quad	0x44201dcc2acf7755, 0x4459beca74b0f147
	.quad	0x441d2b166911c178, 0x445753637caac6d9
	.quad	0x441a6459c5b11342, 0x4455218993857afc
	.quad	0x4417e086accc805d, 0x445323f3f19cff3e
	.quad	0x44159962aef547b3, 0x445155d47fdb9c94
	.quad	0x4413894608650ede, 0x444f6599b70323ca
	.quad	0x4411ab0e4d284f44, 0x444c6dc8a4bb3ba6
	.quad	0x440ff4248ebb8299, 0x4449bcfd83a431e9
	.quad	0x440ce42dd8e4fa23, 0x44474ca889bbacd5
	.quad	0x440a1e8aa1400997, 0x444516d33e26c040
	.quad	0x44079c430435a7fc, 0x44431612a7ef535f
	.quad	0x440557046eb39249, 0x4441457ab75c2489
	.quad	0x440349127b59b217, 0x443f41259c9550c0
	.quad	0x44016d392dff5104, 0x443c46969ca99a2e
	.quad	0x43ff7d80dc993f2f, 0x443993e82b76e726
	.quad	0x43fc72c149cb214b, 0x44372267ac1b25a0
	.quad	0x43f9b270c24cc8fa, 0x4434ec0062aeeb78
	.quad	0x43f73585df7b6643, 0x4432eb2d18a2081b
	.quad	0x43f4f59f9910367e, 0x44311aeb0b11d1a1
	.quad	0x43f2ecf5b7f6abe3, 0x442eed5c0bbf1061
	.quad	0x43f1164ab45aa235, 0x442bf4ab21b4f3f0
	.quad	0x43eed9bdbc6f1b0a, 0x442944462d4d5991
	.quad	0x43ebd8c96533b39b, 0x4426d561de54f6a1
	.quad	0x43e921ec84d5860e, 0x4424a1d472804fc8
	.quad	0x43e6ae172414ceba, 0x4422a406e25fcb44
	.quad	0x43e476e3b661be8c, 0x4420d6e7662dda9d
	.quad	0x43e276873924f0b4, 0x441e6bba6770e22d
	.quad	0x43e0a7c2c9322f59, 0x441b797ab2ba22d2
	.quad	0x43de0bad18c4e37d, 0x4418cf813910fdcd
	.quad	0x43db18eba0be4d24, 0x441666f488db6e0a
	.quad	0x43d86f7884e1caad, 0x4414399f7770045f
	.quad	0x43d608484d592328, 0x441241e1ebbbf4ec
	.quad	0x43d3dcfaee52a8f5, 0x44107aa30ce6a5a0
	.quad	0x43d1e7cbac093f27, 0x440dbe8969a24c6f
	.quad	0x43d023827dc88ed9, 0x440ad7301258d788
	.quad	0x43cd16cd999791c3, 0x440837a640fa9d3d
	.quad	0x43ca3666de0788b0, 0x4405d90f358d61f6
	.quad	0x43c79e17816df1e8, 0x4403b5342f7be9c0
	.quad	0x43c546e385224d10, 0x4401c674ecd152d3
	.quad	0x43c32a7a483e977b, 0x440007b997a0b531
	.quad	0x43c1432649c86c4d, 0x43fce8cc007a6432
	.quad	0x43bf177ce0bd5836, 0x43fa109c0bccbc39
	.quad	0x43bbff3166bc36ee, 0x43f77f5624913c3a
	.quad	0x43b934fc0975fb30, 0x43f52e251d5d3b1f
	.quad	0x43b6b13ebb9a5ad4, 0x43f316da780bc4d9
	.quad	0x43b46d17a80cc174, 0x43f133deb1d35260
	.quad	0x43b2624f3a0a8870, 0x43ef00460b24acf8
	.quad	0x43b08b47d7733cb6, 0x43ebee2903d584f9
	.quad	0x43adc5de496b1810, 0x43e92920a7c80e26
	.quad	0x43aac9615b3c9fd7, 0x43e6a9b25345c773
	.quad	0x43a818d3a356669e, 0x43e4691b26b9c82f
	.quad	0x43a5acbdab2ed713, 0x43e2613e9610f6d1
	.quad	0x43a37e61fd4c0fe0, 0x43e08c969adf0bea
	.quad	0x43a187ab3d71db11, 0x43ddcc4ac4f59be5
	.quad	0x439f8637ea4e52ac, 0x43dad2d0a9a18288
	.quad	0x439c577fd709b099, 0x43d82498a7cc94b9
	.quad	0x43997a3dc62119c8, 0x43d5ba462dee8a02
	.quad	0x4396e66137bb7cca, 0x43d38d330d8806a0
	.quad	0x439494a3f6a9a70e, 0x43d1975e0627306c
	.quad	0x43927e767bb79ea2, 0x43cfa6b5ee8f3088
	.quad	0x43909dee32687729, 0x43cc78892308bd90
	.quad	0x438ddb6ae2f39381, 0x43c99b5ec6741cb3
	.quad	0x438ad1f9fba4b2ab, 0x43c7073c400e10dc
	.quad	0x438816dde4c11ca3, 0x43c4b4ee0b3a84d6
	.quad	0x4385a245d5e5289c, 0x43c29df4862ac231
	.quad	0x43836d26a686daaf, 0x43c0bc7294e0cbaf
	.quad	0x438171277cbbce9c, 0x43be163bd8df8640
	.quad	0x437f5120b45c00e6, 0x43bb0a61bce91993
	.quad	0x437c1c74b30d0bb0, 0x43b84cbb00f925f0
	.quad	0x43793b02e5cf0324, 0x43b5d5841ce6cb73
	.quad	0x4376a46f43f3118c, 0x43b39dbcd485dd07
	.quad	0x43745132973bb79b, 0x43b19f153b38a108
	.quad	0x43723a85891dc72b, 0x43afa7b9159fc471
	.quad	0x43705a4dba466c4e, 0x43ac6de3429e31fa
	.quad	0x436d561964307dc4, 0x43a98769faac8a1b
	.quad	0x436a4fa0f13737e8, 0x43a6ebf82977acf0
	.quad	0x4367984b636ad1be, 0x43a4940bc89fa5aa
	.quad	0x4365281628cb373a, 0x43a278e135bcf0a4
	.quad	0x4362f7cc38bc628d, 0x43a0946088b6f8ed
	.quad	0x436100f1aef8eaf5, 0x439dc21972b9e9f4
	.quad	0x435e7b62ce66acde, 0x439ab3e8cfada51a
	.quad	0x435b5198cf325114, 0x4397f5483f729c27
	.quad	0x43587b15da6677af, 0x43957e33e2b1c6da
	.quad	0x4355ef5de2e68985, 0x4393477480d89e25
	.quad	0x4353a6d00852a688, 0x43914a8b54629fb2
	.quad	0x43519a90b14f53af, 0x438f033fa073d520
	.quad	0x434f88eba04114cb, 0x438bcede5acc0d40
	.quad	0x434c3dea36b87937, 0x4388ee7b29d0b081
	.quad	0x43494a28136fa731, 0x438659917bbb6632
	.quad	0x4346a4b2c9663fa1, 0x43840877b79cd868
	.quad	0x43444580945b8452, 0x4381f44979177348
	.quad	0x43422558f1aa9f03, 0x438016d3f0358160
	.quad	0x43403dbf8db89298, 0x437cd508600d0ba8
	.quad	0x433d11c2965639f6, 0x4379d4ae77a21604
	.quad	0x433a03065db54a4b, 0x437723974e9529d8
	.quad	0x433745e6013d8cf3, 0x4374b9a944f57915
	.quad	0x4334d1f2eb853100, 0x43728f9c9b769ee3
	.quad	0x43329f9b7c4f56df, 0x43709ee66b6e99e9
	.quad	0x4330a814a1dfc5ed, 0x436dc34b6999ff72
	.quad	0x432dca8b63e38fa9, 0x436aa5249b4cca57
	.quad	0x432aa36c9242f8bc, 0x4367d9db080918ba
	.quad	0x4327d0fbfa6c3c19, 0x436558e88e8945ef
	.quad	0x43254a6b679dd96f, 0x43631aa564e92066
	.quad	0x432307d4e71272d7, 0x43611831a9c3763d
	.quad	0x4321022313b11381, 0x435e96c265c21fbf
	.quad	0x431e65f78e13edcd, 0x435b5d52c19374fe
	.quad	0x431b2959e487c93f, 0x43587a2188252d5f
	.quad	0x43184436cf62b6f8, 0x4355e440cc8caaf9
	.quad	0x4315ad66c67f3f63, 0x435393ad199301de
	.quad	0x43135cb549c616eb, 0x43518135a0647102
	.quad	0x43114ac7e9322a1a, 0x434f4ccd98eab06b
	.quad	0x430ee20fae75a2c5, 0x434bfaedff2748c1
	.quad	0x430b931b883c77f2, 0x4349026a7e3c9538
	.quad	0x43089e1f8e1d4be6, 0x434659f3419269ee
	.quad	0x4305f9a24050e89f, 0x4343f92e9472ca4c
	.quad	0x43039d2746cbe57f, 0x4341d89fb6602df9
	.quad	0x43018115431b6c4a, 0x433fe32077e095c4
	.quad	0x42ff3d3ca19edf64, 0x433c7bf775863df5
	.quad	0x42fbdf55dd9bdce0, 0x433970fb0b5580dc
	.quad	0x42f8dd8e25d2255d, 0x4336b88087e4af9f
	.quad	0x42f62e225ebca190, 0x433449de67f2c6b2
	.quad	0x42f3c855ef212bad, 0x43321d51dc348d4d
	.quad	0x42f1a4576cd5cddc, 0x43302be7023a443e
	.quad	0x42ef765035c713d8, 0x432cdec7155697e1
	.quad	0x42ec0d0bdeb46ae2, 0x4329c4671c1a6e3c
	.quad	0x42e901afbd3819be, 0x4326feb0af26f865
	.quad	0x42e64a386137b955, 0x432484b1e63b3be4
	.quad	0x42e3ddb15521ce49, 0x43224e68a1458bd7
	.quad	0x42e1b418ba2217c6, 0x432054a9a7c2f05a
	.quad	0x42df8c8bad8e2a20, 0x431d2214ad33ca5e
	.quad	0x42dc1ba4950b8f4f, 0x4319fb9933adac68
	.quad	0x42d90a0b40dd690c, 0x43172b99eccc462e
	.quad	0x42d64d860502b279, 0x4314a8e4dbe3539c
	.quad	0x42d3dcf1aadc099d, 0x43126b4018ef81f7
	.quad	0x42d1b02414a73357, 0x43106b4fe82cc6ae
	.quad	0x42cf7fa3e4bec2ae, 0x430d44feffb34893
	.quad	0x42cc0aee6d6b1406, 0x430a15d86bb23572
	.quad	0x42c8f684065398bf, 0x43073ea5ac0d71a9
	.quad	0x42c637ff9397e989, 0x4304b5fdd0f567fa
	.quad	0x42c3c618d3c706eb, 0x4302737769828878
	.quad	0x42c1988625955723, 0x43006f8da87263ce
	.quad	0x42bf4fc2f6d50e41, 0x42fd4710a9e149ed
	.quad	0x42bbdb204ff1cda3, 0x42fa12cc7b1bf616
	.quad	0x42b8c75a6fa17116, 0x42f73793d6253bd7
	.quad	0x42b609ec277b8703, 0x42f4abd0af44c7f8
	.quad	0x42b399725d96eb63, 0x42f266f2e981ccfb
	.quad	0x42b16d8d1241b86b, 0x42f06154a07d21a2
	.quad	0x42aefd875a51d28d, 0x42ed2842b40e25f0
	.quad	0x42ab8cd873c4de72, 0x42e9f27fa465d061
	.quad	0x42a87d2a89e5ac65, 0x42e7167c3937ded9
	.quad	0x42a5c3e42539c769, 0x42e48a7fb96552ca
	.quad	0x42a35791e04cd29f, 0x42e245dcbaa25b1b
	.quad	0x42a12fc6cdafd10d, 0x42e040d4ab2de626
	.quad	0x429e8a0077a1ed47, 0x42dce8fcb8dadc2c
	.quad	0x429b2118f75a4eb7, 0x42d9b55e7c11d9e6
	.quad	0x429818e8b1c2616f, 0x42d6dbce02ec5c77
	.quad	0x429566cdf4525eb0, 0x42d4527acab6dfeb
	.quad	0x4293014fd204bc71, 0x42d210a3ddcb4706
	.quad	0x4290dffe0bfc0c74, 0x42d00e7aba6527c9
	.quad	0x428df6a8d5e14f11, 0x42cc8a12a152d814
	.quad	0x428a9942579915cd, 0x42c95c35893651c9
	.quad	0x42879bdc576e403a, 0x42c6884d52cc9914
	.quad	0x4284f3d9114d799b, 0x42c4047ce663f641
	.quad	0x428297c4e6eb62fc, 0x42c1c7f9c74f3e7c
	.quad	0x42807f35ef1a4fc0, 0x42bf95dcee779f74
	.quad	0x427d455e0a3b0d94, 0x42bc0cc007cc808e
	.quad	0x4279f70bf04a77ce, 0x42b8e82cd2a6133c
	.quad	0x427707990a8defef, 0x42b61d0ef76712e4
	.quad	0x42746c779ebb14ae, 0x42b3a1882865d26e
	.quad	0x42721c4420bc9879, 0x42b16cce86450b20
	.quad	0x42700ea48df1e7fb, 0x42aeee1d41e1e516
	.quad	0x426c7856a7693627, 0x42ab72a1658393d4
	.quad	0x42693c7abef59a2c, 0x42a85ac17b553c4f
	.quad	0x42665df602b1e0ff, 0x42a59b72775450f3
	.quad	0x4263d256a5ee461d, 0x42a32ae03812fc00
	.quad	0x42619053bac5f645, 0x42a1004b9cd4bae6
	.quad	0x425f1f58fe66e142, 0x429e27d88d5289bf
	.quad	0x425b9216793da422, 0x429abdab3fb224ce
	.quad	0x42586bd6adace04e, 0x4297b5bd9f52a89e
	.quad	0x4255a104640aeb74, 0x4295051a941eb130
	.quad	0x42532755417b50dd, 0x4292a20366f6a0de
	.quad	0x4250f5a5274f5c45, 0x429083cdb1163405
	.quad	0x424e07ab300dc4b9, 0x428d458a013d18b4
	.quad	0x424a956163a49613, 0x4289f01f97b2e043
	.quad	0x4247879eb52380ed, 0x4286fb2eaf7d8102
	.quad	0x4244d30488394e18, 0x42845be480207b14
	.quad	0x42426d7af2869fc5, 0x428208a2b041836e
	.quad	0x42404e0c593552f5, 0x427ff1ba8cbc9c8d
	.quad	0x423cd98a274acae3, 0x427c49f8a8ec4aeb
	.quad	0x4239852d44d7528b, 0x42790c81ede57558
	.quad	0x4236927c2c3e4970, 0x42762d5a948b6358
	.quad	0x4233f65a98c177c9, 0x4273a1de0952fd2b
	.quad	0x4231a6ed66936eea, 0x42716098d4b94692
	.quad	0x422f36ed3084aa81, 0x426ec24d6a8bc072
	.quad	0x422b986ab7ebdd54, 0x426b3828ebcc128b
	.quad	0x422864933f3c0573, 0x4268158a3038115e
	.quad	0x42258f359f0c4e8f, 0x42654eb3e9a3e72b
	.quad	0x42230d82cb8a968c, 0x4262d93b0174f61a
	.quad	0x4220d5e5f59de7c1, 0x4260abe0d45fd5c2
	.quad	0x421dbfc240ab5f81, 0x425d7ce33a39bd89
	.quad	0x421a47db588b15cf, 0x425a134d30d655e4
	.quad	0x421736c0d0a31187, 0x42570e16f315ef40
	.quad	0x421480a1879e8f57, 0x425461cda38e2783
	.quad	0x42121b0591ce1cfd, 0x4252044a2faebb7b
	.quad	0x420ff94e3fca1752, 0x424fd91813f8cc8c
	.quad	0x420c3a9f9558ffa0, 0x424c2530177987fe
	.quad	0x4208eb738c76b2f2, 0x4248deb61106f334
	.quad	0x4205fee91a43fef1, 0x4245f91f55e86346
	.quad	0x4203699940a6a811, 0x4243694e7b13691b
	.quad	0x4201216c07263de0, 0x4241256a18de488b
	.quad	0x41fe3ae49fef5535, 0x423e49705a5ebd5f
	.quad	0x41faab87fb8e4441, 0x423abefb3186e784
	.quad	0x41f786c3dca158c4, 0x42379dc285401b7d
	.quad	0x41f4c036b7451223, 0x4234d9a4f359ba1e
	.quad	0x41f24cec8453db03, 0x423267e46fd85893
	.quad	0x41f02334e92993b9, 0x42303efdea0a0506
	.quad	0x41ec74fc41217dfb, 0x422cad0afbb569b1
	.quad	0x41e9166837399532, 0x42294e0d5e7a8744
	.quad	0x41e61d46c11dd916, 0x422653d077d9eef0
	.quad	0x41e37dbe7711fcd4, 0x4223b2a639494566
	.quad	0x41e12d55c1e73c65, 0x42216038b4af0a0e
	.quad	0x41de4594b115943b, 0x421ea6c598920c48
	.quad	0x41daabdabdb93484, 0x421b081aaf25ade1
	.quad	0x41d77f073eb945df, 0x4217d62079a4e4a6
	.quad	0x41d4b252d0bc8beb, 0x4215042e1a8664ed
	.quad	0x41d23a7345c57cca, 0x421287117d29a9e6
	.quad	0x41d00d6f8a57f06e, 0x421054e44f8ee735
	.quad	0x41cc44f136cf3bd8, 0x420cc9cbc5fe04a8
	.quad	0x41c8e38df2790b7a, 0x42095eb2cb828067
	.quad	0x41c5e8f828661e21, 0x42065acfefcd0029
	.quad	0x41c3490e7e2bc31c, 0x4203b20c56ad84f5
	.quad	0x41c0f91b7ff9bb2a, 0x420159b917beb87a
	.quad	0x41bddf56913a541e, 0x41fe90cb5cac7057
	.quad	0x41ba48cc1b8a7bc7, 0x41faeb7659e5f7ef
	.quad	0x41b71fde01e2ca8c, 0x41f7b4b752e86e5f
	.quad	0x41b4578e0b906b32, 0x41f4df8ace15322e
	.quad	0x41b1e4659a2a2156, 0x41f26072a17961a0
	.quad	0x41af788fc218597b, 0x41f02d48c75e7d9b
	.quad	0x41abac92daac0b9d, 0x41ec7a2ecd5f05a0
	.quad	0x41a85518c3484796, 0x41e90feaede7f2ae
	.quad	0x41a56441b55bfff1, 0x41e60dcef1cedc3a
	.quad	0x41a2cdd203ab43a1, 0x41e36787980e7387
	.quad	0x41a08700c199ad4f, 0x41e112346e13dd7e
	.quad	0x419d0c9857c390f3, 0x41de087915129a98
	.quad	0x419986a650394095, 0x41da6a5096da5b7d
	.quad	0x41966d6688315ad6, 0x41d73aff07c7874e
	.quad	0x4193b3d55ebd8547, 0x41d46d572e10e216
	.quad	0x41914e7b714e7093, 0x41d1f5ba17e5a90b
	.quad	0x418e667d9a8bcd9e, 0x41cf93d0d186fbcd
	.quad	0x418ab2733e383ad8, 0x41cbc1b22cec72b0
	.quad	0x4187712b76c8c7f6, 0x41c86529e9df069c
	.quad	0x418494d8e1d4fc61, 0x41c5702d052bf73a
	.quad	0x4182115447c6627d, 0x41c2d65aee08874c
	.quad	0x417fb7d503fc65c8, 0x41c08ccb49580d43
	.quad	0x417bd660913b938c, 0x41bd13c32a98512b
	.quad	0x41786db66e158524, 0x41b98a4bfd5a5fad
	.quad	0x41756f3ed5aa4222, 0x41b66e459a7794f4
	.quad	0x4172ce2265a96bef, 0x41b3b28bbce3c1c6
	.quad	0x41707f14a8d0c116, 0x41b14b8b6b67144e
	.quad	0x416cf049ebedf60d, 0x41ae5e26dbef0e28
	.quad	0x41696129ca292f7e, 0x41aaa854b5c4f131
	.quad	0x4166416763f6b3bc, 0x41a765d329106241
	.quad	0x4163837bf030f4a8, 0x41a488b9479ee1c4
	.quad	0x41611b82880134f9, 0x41a204c8d940530b
	.quad	0x415dfe0c1b8af1f3, 0x419f9e77238e0031
	.quad	0x415a49aa1651cfca, 0x419bbd2c8fd7e193
	.quad	0x415709b5a3a79128, 0x41985502f16a0f8d
	.quad	0x41542ffa7e9ace3f, 0x4195574ceffe3945
	.quad	0x4151affd2eccd616, 0x4192b72182c97af5
	.quad	0x414efd8be43ac9a9, 0x41906925da53a0fc
	.quad	0x414b2564005de7e5, 0x418cc6bb6d71090d
	.quad	0x4147c694cd2b4ffd, 0x41893a02d0c97221
	.quad	0x4144d23fa69bd814, 0x41861cb1a027e057
	.quad	0x41423b556e6e918e, 0x418361358dd1f243
	.quad	0x413fecbcf04dca90, 0x4180fba0d2660d89
	.quad	0x413bf29264dcdc82, 0x417dc2ef387bd0e0
	.quad	0x4138767d7fc43eb6, 0x417a130711aadcda
	.quad	0x413568f9937abc79, 0x4176d758e1ac9659
	.quad	0x4132bc67d8c20136, 0x417401abca024479
	.quad	0x413064d4616b0094, 0x417185819a7f8c6a
	.quad	0x412caf8458ad2a12, 0x416eafc2b00a99b1
	.quad	0x412917faff93e540, 0x416ade505ba61e89
	.quad	0x4125f2e79283b1ca, 0x416785c00b5cb27e
	.quad	0x41233220b1da4f59, 0x4164973634932c1a
	.quad	0x4120c93ac678b0cc, 0x416205a7d78be568
	.quad	0x411d5aa313452dae, 0x415f8b4440d68221
	.quad	0x4119a9b05368c88b, 0x415b9a31a7b9868c
	.quad	0x41166ede7f0c2d55, 0x415826756e1a42e2
	.quad	0x41139b7fc18e5891, 0x4155209676e4b424
	.quad	0x411122b662569616, 0x41527b019965e362
	.quad	0x410df2779ceabfc8, 0x415029ce648133fd
	.quad	0x410a2a5d2945d2b7, 0x414c45161cd95fe8
	.quad	0x4106dbccf848794a, 0x4148b81d680cdfc5
	.quad	0x4103f79bf21caa96, 0x41459ca24a7521dd
	.quad	0x41017080ae674896, 0x4142e48f266999cf
	.quad	0x40fe75b024885f54, 0x4140838b13324d03
	.quad	0x40fa98e26924c6c8, 0x413cdd86b83e679d
	.quad	0x40f738bf4bc8d296, 0x41393977456406dd
	.quad	0x40f445a6a9a273c6, 0x41360a47aca18e96
	.quad	0x40f1b1eabeffc3a5, 0x413341669953fe1c
	.quad	0x40eee324e1fde417, 0x4130d210b765b3d6
	.quad	0x40eaf4465e9c5668, 0x412d622fa53c02ce
	.quad	0x40e784e3008fb46b, 0x4129a961d6383ef7
	.quad	0x40e484eecd2f1383, 0x41266890cd0bf55f
	.quad	0x40e1e65fd1ef2701, 0x412390b73f2a4fb0
	.quad	0x40df39dc6baaccd7, 0x412114ae59581395
	.quad	0x40db3bb863d26278, 0x411dd1e5296953a3
	.quad	0x40d7bf89f052b591, 0x411a06dfa21b6c59
	.quad	0x40d4b4e35dbe0cdd, 0x4116b6a7a27c9005
	.quad	0x40d20d6781986167, 0x4113d1cca3d4f6d8
	.quad	0x40cf790f6877f51e, 0x41114acc164c64fe
	.quad	0x40cb6e93fa7299b3, 0x410e2ba80b9c3a1b
	.quad	0x40c7e82cde922833, 0x410a511aa3827999
	.quad	0x40c4d515a14a6132, 0x4106f3d9139319ed
	.quad	0x40c226a790f97768, 0x410404113d7d18e6
	.quad	0x40bfa02b8ac73416, 0x410173ed60fcd6fa
	.quad	0x40bb8c6342337220, 0x40fe6ea95e92c624
	.quad	0x40b7fe6d7fbcef2c, 0x40fa8767775dd309
	.quad	0x40b4e53acc7531b1, 0x40f71f97a2983044
	.quad	0x40b231e547065724, 0x40f42710a88aab19
	.quad	0x40afaed5c4559717, 0x40f18fb2ded8ebb1
	.quad	0x40ab94e0bfb59934, 0x40ee9a4d9b21386e
	.quad	0x40a80217e57d8a3f, 0x40eaa947efe69879
	.quad	0x40a4e52d23cf50b0, 0x40e7397d8e2bd385
	.quad	0x40a22f0652094ae6, 0x40e43a79684f6ef6
	.quad	0x409fa4eba730bf60, 0x40e19ddbd8138a90
	.quad	0x409b87f86a26fad7, 0x40deae2ef93df996
	.quad	0x4097f323487ff94a, 0x40dab66cfccafb75
	.quad	0x4094d4ec8ea8ee67, 0x40d7414e5b5ca43c
	.quad	0x40921e112e39bf18, 0x40d43e1e22ebfdb4
	.quad	0x408f8283ec45f117, 0x40d19e4732be2ff0
	.quad	0x408b65c7f9f1fbed, 0x40ceaa1efb3b003e
	.quad	0x4087d1b22b6810f6, 0x40caaeb7de6855e2
	.quad	0x4084b49e984886e0, 0x40c736f7c0d13f06
	.quad	0x4081ff2d0d5a2649, 0x40c431f651be2ff4
	.quad	0x407f47ee1cab73dd, 0x40c190f3f39e9af4
	.quad	0x407b2e9e76c8d9f9, 0x40be8e2722ca46cf
	.quad	0x40779e11d635b9a7, 0x40ba923a9d8d5019
	.quad	0x4074848ddf7dfffe, 0x40b71a91ee04e82c
	.quad	0x4071d2a13fdd2709, 0x40b4161e6298ed3a
	.quad	0x406ef5b15f73200a, 0x40b176014201ab17
	.quad	0x406ae2fb07705cc3, 0x40ae5a88cbf394e4
	.quad	0x406758b92cdfdc64, 0x40aa6137c537bf6d
	.quad	0x40644528f79b1b51, 0x40a6ec5f2d1367f4
	.quad	0x406198d422be3f8c, 0x40a3ead7491061af
	.quad	0x405e8c8a7276c930, 0x40a14dadee76975a
	.quad	0x405a838b09afcf62, 0x409e0fbc2ec572b9
	.quad	0x40570246e766d2f3, 0x409a1c215fcd0bea
	.quad	0x4053f700c0d99876, 0x4096accae115453e
	.quad	0x4051524997d01a00, 0x4093b08582357e32
	.quad	0x404e0d68d9047f7a, 0x409118577f06b2f2
	.quad	0x404a11277ca2bd3f, 0x408dae6e8d292a1e
	.quad	0x40469b7f34ec048e, 0x4089c3973d4c9b08
	.quad	0x40439ac6410ceb63, 0x40865c67e684d1e6
	.quad	0x4040ffa110b113f0, 0x408367af901b1370
	.quad	0x403d796b4f7aaf7f, 0x4080d678c614f535
	.quad	0x40398cd1cb38dcc0, 0x407d377f96b9fd62
	.quad	0x40362548d6675835, 0x407958648bd60350
	.quad	0x403331480815e7cd, 0x4075fbee5e7590f4
	.quad	0x4030a19336cc73a1, 0x407310fbf558eca2
	.quad	0x402cd1db96a6c6ef, 0x407088a80b837328
	.quad	0x4028f7b007e1de49, 0x406cabfe10b3371a
	.quad	0x4025a0a9c047e3c7, 0x4068db7ccf7600f4
	.quad	0x4022bb6f2dd8e254, 0x40658c38f07b7c3b
	.quad	0x402038ef3cbdc1c7, 0x4062ad2ebb6268bd
	.quad	0x401c1829acfb62b3, 0x40602f94d1fb1ba4
	.quad	0x40185308ad209551, 0x405c0d23d3daadad
	.quad	0x40150ec3549a202d, 0x40584df8496cc3ae
	.quad	0x40123a3bf963c1eb, 0x40550e4191e1b76c
	.quad	0x400f8d2fce0ebb41, 0x40523d2690dc7344
	.quad	0x400b4de68e608347, 0x404f980a88588961
	.quad	0x4007a03df8f9f479, 0x404b5c5135a44acb
	.quad	0x400470ce4924af72, 0x4047b10fe1f0aeaa
	.quad	0x4001aec242758b4f, 0x4044831de32e25bd
	.quad	0x3ffe9700b697ec96, 0x4041c1d98f1b1f71
	.quad	0x3ffa74be9568f922, 0x403ebda6af103d07
	.quad	0x3ff6e0c8fadbb050, 0x403a9b07f491a273
	.quad	0x3ff3c8164e42f29c, 0x40370618a9c019da
	.quad	0x3ff11a259faba91e, 0x4033ebfb36da371b
	.quad	0x3fed91518c2acaf6, 0x40313c51b7852ec0
	.quad	0x3fe98e739a118b5e, 0x402dd1d36683753b
	.quad	0x3fe616346ca3be0e, 0x4029cae5c1f5de61
	.quad	0x3fe315f58c13df9c, 0x40264e7f0a95542f
	.quad	0x3fe07d957435b8c4, 0x40234a1a5595e9cb
	.quad	0x3fdc7e35cf4db634, 0x4020ada93ac2688e
	.quad	0x3fd89cd6ead31b71, 0x401cd680d6a376d2
	.quad	0x3fd542176fe1c2b2, 0x4018ed9e84be9bac
	.quad	0x3fd25bd00bd97edd, 0x40158bc1beb8e117
	.quad	0x3fcfb491e02b7c15, 0x40129ecb15514182
	.quad	0x3fcb5fcd30c7e1f6, 0x401017069c4b54cf
	.quad	0x3fc7a1c33cc1922b, 0x400bcdb33f7b88f9
	.quad	0x3fc46610483f2395, 0x400804f671a7a35c
	.quad	0x3fc19b0f23241b88, 0x4004bf6ca87a4707
	.quad	0x3fbe62f62b4555dc, 0x4001eb67d8a75351
	.quad	0x3fba383ca9f98a0f, 0x3ffef3318a5788de
	.quad	0x3fb69f16aeb36770, 0x3ffab97c2106c4d2
	.quad	0x3fb383bf2b37a037, 0x3ff712bc1550fb6a
	.quad	0x3fb0d51cf5a16254, 0x3ff3eb13a24821e2
	.quad	0x3fad08cdac87dce6, 0x3ff131510c1da6ad
	.quad	0x3fa909a7c3ac6f99, 0x3fedad26311e9ef0
	.quad	0x3fa596acfa0bcc8f, 0x3fe99bf36c7ef068
	.quad	0x3fa29cc13bfd53a0, 0x3fe618c26c1169a6
	.quad	0x3fa00b60212cf113, 0x3fe3104d5f799552
	.quad	0x3f9ba886ae6e40e0, 0x3fe071e8b6003b16
	.quad	0x3f97d62a282a4851, 0x3fdc5e5338097f6b
	.quad	0x3f948a59e9cb1eb1, 0x3fd87730de08c821
	.quad	0x3f91b2abc895a771, 0x3fd518db221cf8ba
	.quad	0x3f8e7e6f4c33eded, 0x3fd230ae74a714aa
	.quad	0x3f8a4480db60fe17, 0x3fcf5d1c58fdc6ac
	.quad	0x3f869fd19aacb90a, 0x3fcb091a88a72f08
	.quad	0x3f837be42e1159e7, 0x3fc74d459ba38afe
	.quad	0x3f80c707db025298, 0x3fc414d114bdcde1
	.quad	0x3f7ce3ee3757dbe5, 0x3fc14dc49cbc0c30
	.quad	0x3f78df06bfb34f6d, 0x3fbdd13408401cdc
	.quad	0x3f7568986affafc5, 0x3fb9afd0eca1593d
	.quad	0x3f726d009f5af049, 0x3fb6203633a6814a
	.quad	0x3f6fb69c5d6b524e, 0x3fb30e632b0008c9
	.quad	0x3f6b49c67cd1611f, 0x3fb069124dc6eaef
	.quad	0x3f677a47ec4e9fa1, 0x3fac42b48d5cfe42
	.quad	0x3f643260788f0a1f, 0x3fa854b792c33d4a
	.quad	0x3f615f4e018a09ee, 0x3fa4f1f511f7b2d7
	.quad	0x3f5de1c72f739a49, 0x3fa2073f996519c0
	.quad	0x3f59b25dc6d6642e, 0x3f9f08155c194aad
	.quad	0x3f561853cc8eddac, 0x3f9ab41e011814e5
	.quad	0x3f52feeed430b87b, 0x3f96f9f62ec4193a
	.quad	0x3f505451535e8102, 0x3f93c45d7f9e2fb0
	.quad	0x3f4c122bcbda7f8e, 0x3f9100ffa10ff0f3
	.quad	0x3f481ff0b26f3b6a, 0x3f8d401bee3a7787
	.quad	0x3f44bb153d2d0728, 0x3f8927ce5fbbe352
	.quad	0x3f41cfe80beb05a4, 0x3f85a195c6e2a08e
	.quad	0x3f3e9ae566e02486, 0x3f82992f3c7d2ce7
	.quad	0x3f3a4a3297375461, 0x3f7ffa47aef63bd2
	.quad	0x3f36948e77b6c537, 0x3f7b7ccca35ce88e
	.quad	0x3f33644eed5b1126, 0x3f779ffc3cd6bc92
	.quad	0x3f30a6cd27d913d7, 0x3f744d7c3dca9cc8
	.quad	0x3f2c97f5c053e775, 0x3f71720abf01aa9b
	.quad	0x3f288c0c973b68fc, 0x3f6dfa22008cf2c8
	.quad	0x3f2512157ee1d8be, 0x3f69c08a63df00dc
	.quad	0x3f2215988e86b086, 0x3f661eb258af5a93
	.quad	0x3f1f09f2b684fb31, 0x3f62ff68a28f7dc4
	.quad	0x3f1aa222a98ba953, 0x3f60506e21782262
	.quad	0x3f16d9b06046eb66, 0x3f5c041afe3a1ad2
	.quad	0x3f139a30e3030664, 0x3f580d8271e40929
	.quad	0x3f10d05cd2b64652, 0x3f54a5cc1e67b046
	.quad	0x3f0cd740d2318d4d, 0x3f51b8f04bdfa1bf
	.quad	0x3f08bb7603d98280, 0x3f4e6b65816f0ff1
	.quad	0x3f0534d810db5377, 0x3f4a1a7ec86c94fb
	.quad	0x3f022e56de90dc1a, 0x3f4665a9398034f1
	.quad	0x3eff2bb06a7069e2, 0x3f4336f30c8d3345
	.quad	0x3efab79b6edb04e1, 0x3f407b7cbf13abf4
	.quad	0x3ef6e5b33b150249, 0x3f3c461717dacbd8
	.quad	0x3ef39f005226a7db, 0x3f383f56253c12f1
	.quad	0x3ef0cfc8192e69bd, 0x3f34cab82baddd6c
	.quad	0x3eecce310b024fd4, 0x3f31d39d04e50424
	.quad	0x3ee8acc81455f971, 0x3f2e9094beff3587
	.quad	0x3ee522570529739f, 0x3f2a3308036822db
	.quad	0x3ee219685023e1be, 0x3f267464f8a36aff
	.quad	0x3edeff1f945e7f7b, 0x3f233e2c9c277148
	.quad	0x3eda89fa515a2b44, 0x3f207d0b7bb52fc7
	.quad	0x3ed6b83bb4ee4348, 0x3f1c40cfbd11fd10
	.quad	0x3ed372982e2fde1d, 0x3f1833ffa698fa8b
	.quad	0x3ed0a51297b20ab7, 0x3f14bb29dadf3ac0
	.quad	0x3ecc7d093fb7e463, 0x3f11c147957723bd
	.quad	0x3ec8607006600009, 0x3f0e6896f5762306
	.quad	0x3ec4db1c7b733812, 0x3f0a096cc3260668
	.quad	0x3ec1d76959a6b622, 0x3f064a7647d3f88a
	.quad	0x3ebe858d8b3acc80, 0x3f0314deba7bab37
	.quad	0x3eba1a94b14e3d7f, 0x3f00550e92636252
	.quad	0x3eb6529df3d1cf1c, 0x3efbf46cd0f972c3
	.quad	0x3eb316449a955429, 0x3ef7ebd49fbb30ee
	.quad	0x3eb0517b9e1f89de, 0x3ef47796af08285b
	.quad	0x3eabe627dddb55d7, 0x3ef1827a73755ec7
	.quad	0x3ea7d8a7f2a8a2d0, 0x3eedf49a10ccc568
	.quad	0x3ea4613bf000c71d, 0x3ee99ee7037b652b
	.quad	0x3ea16a45fcb7b882, 0x3ee5e9197017791d
	.quad	0x3e9dc283bcbe780f, 0x3ee2bc40c543e36b
	.quad	0x3e996ca751cac37f, 0x3ee004b34180a4a9
	.quad	0x3e95b7cd13179dde, 0x3edb632d58444fad
	.quad	0x3e928cb2cb8b4015, 0x3ed768f3e13d3bdc
	.quad	0x3e8faedd62dabd96, 0x3ed401fa7657909e
	.quad	0x3e8b0de982dbf111, 0x3ed1190d162109ab
	.quad	0x3e87195b2becea19, 0x3ecd3803e22a78e4
	.quad	0x3e83b8387eea3f9d, 0x3ec8f694ad8ac632
	.quad	0x3e80d521f8291cd6, 0x3ec55326d6aac6fa
	.quad	0x3e7cbb9be9cbac1e, 0x3ec236e8d3a9e0e7
	.quad	0x3e78852e54d26542, 0x3ebf1ca221c0b98b
	.quad	0x3e74ec36b8fdf428, 0x3eba914b62872bc3
	.quad	0x3e71d9d0055d11d0, 0x3eb6af2ae42db580
	.quad	0x3e6e74cb7ebdea0a, 0x3eb35dbe86ed95c7
	.quad	0x3e69fa735b03463a, 0x3eb0880cfe68041e
	.quad	0x3e6627f6220ca6a9, 0x3eac3847cbf78a3b
	.quad	0x3e62e4d9d8b5b22f, 0x3ea81550cf271bfd
	.quad	0x3e601c325e8bb3c0, 0x3ea48cefa0aac509
	.quad	0x3e5b783bc148fcef, 0x3ea188ab9ce5fddd
	.quad	0x3e576aa8791eba33, 0x3e9dea9996bf1c0f
	.quad	0x3e53f58d390caeec, 0x3e9984c7bb9c53ff
	.quad	0x3e510299f255a2ca, 0x3e95c3c6ce5f2f75
	.quad	0x3e4cfd7e08a13b20, 0x3e928f8faa7c3202
	.quad	0x3e48b368e0429dac, 0x3e8fa73040873530
	.quad	0x3e450b2501707be6, 0x3e8afca3c464e1d5
	.quad	0x3e41ecf2c897b782, 0x3e8701780b38d71a
	.quad	0x3e3e891642306fee, 0x3e839c08dab159e0
	.quad	0x3e3a013c6709bdd5, 0x3e80b66dac93672b
	.quad	0x3e3624c9a2f2f8fc, 0x3e7c7bde43ebd873
	.quad	0x3e32da83d59392f5, 0x3e784520ec5eb55a
	.quad	0x3e300ce3767b77a8, 0x3e74ad54236cf6b4
	.quad	0x3e2b5312d520a3f4, 0x3e719d258cf47194
	.quad	0x3e274191dcab90bc, 0x3e6e015665e4efbd
	.quad	0x3e23ca855a30dad5, 0x3e698dc92b26aea0
	.quad	0x3e20d71d1069e44f, 0x3e65c29c3e79c162
	.quad	0x3e1ca7c7b61a5357, 0x3e628708aaed4d70
	.quad	0x3e186083aaabaf73, 0x3e5f8bd2046619b5
	.quad	0x3e14bc21b880f9de, 0x3e5ada636f165959
	.quad	0x3e11a28183b0e320, 0x3e56dafa60f704a1
	.quad	0x3e0dfe23a6ad4f8b, 0x3e537351629c53c0
	.quad	0x3e0980956bea8cc0, 0x3e508cff68f5874c
	.quad	0x3e05ae767663002e, 0x3e4c29ce58c1fc10
	.quad	0x3e026e4fd1165b76, 0x3e47f5772973d16c
	.quad	0x3dff54dde2ba8f56, 0x3e44612c5674eed9
	.quad	0x3dfaa0af3e698b26, 0x3e415539e864d70f
	.quad	0x3df6a0956d7d1b63, 0x3e3d7ad5cdc3741e
	.quad	0x3df339bd6e517d44, 0x3e39110bc4b50f8c
	.quad	0x3df0554f0943ba8c, 0x3e354fb970dbe54e
	.quad	0x3debbfac9007ec07, 0x3e321dd98bc7de87
	.quad	0x3de791862715d02f, 0x3e2ecc34851c9763
	.quad	0x3de403f77382e654, 0x3e2a2ca34863bfcb
	.quad	0x3de0feff2a4fc490, 0x3e263e0d12d4d288
	.quad	0x3ddcdc5de1ae8c09, 0x3e22e615f0543e41
	.quad	0x3dd8804761a993c4, 0x3e200e4ae934cb56
	.quad	0x3dd4cc23eb3b5ffa, 0x3e1b471c42165f4a
	.quad	0x3dd1a6c6c06ea18b, 0x3e172b316e47cc93
	.quad	0x3dcdf58ab9ae4fcb, 0x3e13ad1e7143aa75
	.quad	0x3dc96bd0bd6c9a31, 0x3e10b54bd6a9e23f
	.quad	0x3dc59163428fb3a6, 0x3e0c5f4a785a88d1
	.quad	0x3dc24be8d0138113, 0x3e08162809b8dff6
	.quad	0x3dbf09f3c1618809, 0x3e04721b76389525
	.quad	0x3dba53148c3fc482, 0x3e015a6678e0082c
	.quad	0x3db652d1d62b45e1, 0x3dfd73f8da963966
	.quad	0x3db2eda549c16ee8, 0x3df8fdeb6a9e8ebc
	.quad	0x3db00c2a84aed164, 0x3df5342fe16e83a5
	.quad	0x3dab3501c0fdbbcf, 0x3df1fcdfea216d16
	.quad	0x3da70f8998ccf075, 0x3dee83eb9bce31c4
	.quad	0x3da38b3a7222dd33, 0x3de9e170e2dbff8c
	.quad	0x3da08fb437656229, 0x3de5f27a9aa5f660
	.quad	0x3d9c1085f96d9fee, 0x3de29bfa42bc7b76
	.quad	0x3d97c6a3cf1c9dcf, 0x3ddf8de2739c95a9
	.quad	0x3d9423e65b2a3a8c, 0x3ddabfaa7d4233fa
	.quad	0x3d910ef40de709bc, 0x3dd6ac1833360c58
	.quad	0x3d8ce48f9d9e5928, 0x3dd336f5ff042b88
	.quad	0x3d88773adc5703ce, 0x3dd0484d7ff5f6bd
	.quad	0x3d84b6e86a5aa9d8, 0x3dcb978904649f57
	.quad	0x3d8189488e2e9743, 0x3dc760249f31a968
	.quad	0x3d7db0100ef385d3, 0x3dc3cd13761f1731
	.quad	0x3d79206c1ae9fb29, 0x3dc0c569a0b1627c
	.quad	0x3d754382e8081943, 0x3dbc67fe1e83e910
	.quad	0x3d71fe13002859ca, 0x3db80dbcff1d72cf
	.quad	0x3d6e71fde0c5e218, 0x3db45d945dc4844d
	.quad	0x3d69c159bbc9900a, 0x3db13da615eb6c5f
	.quad	0x3d65c8fc931c6d94, 0x3dad2ffe78d87996
	.quad	0x3d626cb8c1920344, 0x3da8b4017551e03b
	.quad	0x3d5f295714275bc3, 0x3da4e7bd56b77338
	.quad	0x3d5a592ca70605e5, 0x3da1b06621cfb60e
	.quad	0x3d5646a234bddd88, 0x3d9dee83fc205fc8
	.quad	0x3d52d4a498c21371, 0x3d99521701d324da
	.quad	0x3d4fd5235020e009, 0x3d956ad77d8efe38
	.quad	0x3d4ae71657ff542e, 0x3d921d11201bfbcf
	.quad	0x3d46bbc82f12468a, 0x3d8ea290040397f4
	.quad	0x3d43354802504d9e, 0x3d89e7295f29cf91
	.quad	0x3d403a3b07cf84b0, 0x3d85e631fb2a96db
	.quad	0x3d3b6a52af7c7202, 0x3d828313d62cbf4f
	.quad	0x3d3727cc024d462a, 0x3d7f4b2d92a8da6a
	.quad	0x3d338e1c7590edaf, 0x3d7a726cda9c5fc4
	.quad	0x3d3083385f1e344c, 0x3d76592390114765
	.quad	0x3d2be229b5ed10eb, 0x3d72e1e1bdc1cff3
	.quad	0x3d278a15c33bf0d1, 0x3d6fe77379b5869a
	.quad	0x3d23dea49bdca04d, 0x3d6af3202215009f
	.quad	0x3d20c5225e967ce3, 0x3d66c30c15ee186b
	.quad	0x3d1c4df14833b32e, 0x3d6338f646703f05
	.quad	0x3d17e2197e99732e, 0x3d603b4338f71d3b
	.quad	0x3d14266d76b7e9ef, 0x3d5b688e02001605
	.quad	0x3d10ff9aa4df55cb, 0x3d572355f261c90f
	.quad	0x3d0cad0ea9847218, 0x3d5387d609c076c8
	.quad	0x3d082f5884a3c4ff, 0x3d507bcd8d61f54d
	.quad	0x3d04650f71159187, 0x3d4bd20f0d88c869
	.quad	0x3d01324c9f973607, 0x3d477977767b819c
	.quad	0x3cfcfef7f529f1bf, 0x3d43ce0fee10ae91
	.quad	0x3cf8716298a66d68, 0x3d40b4fbeda58aa9
	.quad	0x3cf49a2f582864b8, 0x3d3c2f0b2bc85943
	.quad	0x3cf15cee56fb8f80, 0x3d37c4f426570458
	.quad	0x3ced43356b5d1bc3, 0x3d340b3e347db73a
	.quad	0x3ce8a7d700826ce3, 0x3d30e67b4f33d066
	.quad	0x3ce4c57f38808af9, 0x3d2c7efb04c36011
	.quad	0x3ce17f41219f6e6e, 0x3d28055de49eb405
	.quad	0x3cdd796294cc09e7, 0x3d243f076e4dac86
	.quad	0x3cd8d265709c8b81, 0x3d211003322f9f2a
	.quad	0x3cd4e6bf1c869176, 0x3d1cc169496c493b
	.quad	0x3cd199123dce7f7c, 0x3d183a55fe01c77f
	.quad	0x3ccda12f38ef6065, 0x3d14691f56a0b9d1
	.quad	0x3cc8f0ced10d0db4, 0x3d11315652423380
	.quad	0x3cc4fdbda9c9106c, 0x3d0cf5f3d2534600
	.quad	0x3cc1aa3b4e8f3caa, 0x3d08638e1112031d
	.quad	0x3cbdba6023e1257a, 0x3d0489478d82c425
	.quad	0x3cb902e5d96b5dc7, 0x3d014a433d21a4e2
	.quad	0x3cb50a589affacc9, 0x3cfd1c4c912f9acb
	.quad	0x3cb1b2a2ba958505, 0x3cf880c8cf6ecf16
	.quad	0x3cadc4cfb90a7ce5, 0x3cf49f5031dc1940
	.quad	0x3ca9088f811b7254, 0x3cf15aa4ccc2f79b
	.quad	0x3ca50c7d151d73d0, 0x3ced343a5202c7c4
	.quad	0x3ca1b23bebdcda6d, 0x3ce891da95a3a6f5
	.quad	0x3c9dc06e50abd949, 0x3ce4ab18582d9df2
	.quad	0x3c9901c342974910, 0x3ce1626283914e64
	.quad	0x3c950427d64b1c7d, 0x3cdd3d994938f3ad
	.quad	0x3c91a9076f0d2e24, 0x3cd896a9d7ab89b1
	.quad	0x3c8dad425efa38ef, 0x3cd4ac8e5c7c8723
	.quad	0x3c88ee8b30ca2586, 0x3cd16170c969f828
	.quad	0x3c84f1653e256f41, 0x3ccd385b6cd88b32
	.quad	0x3c819712f23cae3d, 0x3cc88f2f609fe4d3
	.quad	0x3c7d8b686448b5af, 0x3cc4a3b00e506616
	.quad	0x3c78cf03de32b406, 0x3cc157d10888e2f3
	.quad	0x3c74d4512f22a65d, 0x3cbd2488978a2f74
	.quad	0x3c717c7923127a39, 0x3cb87b7664b4e00c
	.quad	0x3c6d5b12a674c804, 0x3cb4908ab62a09ac
	.quad	0x3c68a35c1621f2cc, 0x3cb14591aa0080ca
	.quad	0x3c64ad16c988b007, 0x3cad023e74fea7e1
	.quad	0x3c6159616cbf8a0c, 0x3ca85b9c65443c51
	.quad	0x3c5d1c88b489c5c3, 0x3ca4733af4601fe1
	.quad	0x3c586bd4690c0845, 0x3ca12acdf1c9738c
	.quad	0x3c547bf000e37ae9, 0x3c9cd1b037f7490b
	.quad	0x3c512dff96b26d81, 0x3c982fd0e7486194
	.quad	0x3c4cd026b64a0ca8, 0x3c944bec79d5416c
	.quad	0x3c4828be8d7b2e74, 0x3c9107adbae7661d
	.quad	0x3c4441250d6b8cc7, 0x3c8c93261af2cd0d
	.quad	0x3c40fa934555eb5a, 0x3c87f854fd47e7d3
	.quad	0x3c3c765c89feb632, 0x3c841ad99b7fc9eb
	.quad	0x3c37da7c97c8ea4b, 0x3c80dc65148f57fc
	.quad	0x3c33fd0bbb47d67c, 0x3c7c46fcad39a071
	.quad	0x3c30bf675e9015a3, 0x3c77b57aa64c1e42
	.quad	0x3c2c0facb396944a, 0x3c73e04ac23c3f11
	.quad	0x3c2781800b4c5862, 0x3c70a933c1a65e31
	.quad	0x3c23b0069a07f02d, 0x3c6beda3eeb5f0a2
	.quad	0x3c207cd15415698a, 0x3c6767a404101f5a
	.quad	0x3c1b9cab20b7b4ac, 0x3c639c95b8dcd835
	.quad	0x3c171e48c82b190a, 0x3c606e649c54a11d
	.quad	0x3c135a840f1bb9bf, 0x3c5b879e3daa485d
	.quad	0x3c10333055f872d1, 0x3c570f426b1f5c67
	.quad	0x3c0b1dfbc5f13465, 0x3c53501cdad9df5b
	.quad	0x3c06b163d96b3dd9, 0x3c502c4cdfc5722c
	.quad	0x3c02fcfd4e6913ca, 0x3c4b157f19f267ea
	.quad	0x3bffc5d8e0519af3, 0x3c46acd55017e4e2
	.quad	0x3bfa945119b38a65, 0x3c42fb4e266d3e9f
	.quad	0x3bf63b6a2745bde1, 0x3c3fc696b5025168
	.quad	0x3bf297f53c6e927f, 0x3c3a97e9c202c067
	.quad	0x3bef18eb2ba6357f, 0x3c3640e915b3f3ea
	.quad	0x3bea006a7219c6a4, 0x3c329ea2353deb28
	.quad	0x3be5bcff1208eb99, 0x3c2f278f182d5cce
	.quad	0x3be22bf73da1838d, 0x3c2a0f8fae515880
	.quad	0x3bde60853b8b4b65, 0x3c25cc15bf9dbbbb
	.quad	0x3bd963124add21c0, 0x3c223a9b1f0c9515
	.quad	0x3bd536cefa1810b4, 0x3c1e7c6162103b4e
	.quad	0x3bd1b995f6e584af, 0x3c197d2ef035140a
	.quad	0x3bcd9da06644bc9d, 0x3c154efd8e5e8a15
	.quad	0x3bc8bd1c79049ec2, 0x3c11cfc34a10ee47
	.quad	0x3bc4a98db9bff0e8, 0x3c0dc5f9803d5324
	.quad	0x3bc1416a031bacf2, 0x3c08e1907994f8d3
	.quad	0x3bbcd13f7b7c3414, 0x3c04ca4b88f6234c
	.quad	0x3bb80f645203dff7, 0x3c015eac2ce52257
	.quad	0x3bb415f515af2672, 0x3bfd054eb8db2ad5
	.quad	0x3bb0c410a1d6b3ca, 0x3bf83d8652f7235c
	.quad	0x3babfc6c8b2d1c95, 0x3bf43eb1f8cfdcf1
	.quad	0x3ba75acacc068ebe, 0x3bf0e7ed05fb3af3
	.quad	0x3ba37cc328e513e5, 0x3bec3b617ec3cfd6
	.quad	0x3ba0422a6340a512, 0x3be791e9c59e2b42
	.quad	0x3b9b2036a988bead, 0x3be3ace8dce03fbd
	.quad	0x3b96a0349d192d1a, 0x3be06c218ca5f25a
	.quad	0x3b92deb8d0dae905, 0x3bdb69393c895b87
	.quad	0x3b8f78b3aa5bebbe, 0x3bd6df997f6bab1b
	.quad	0x3b8a3dafb67a96cf, 0x3bd315ac58b7d6b7
	.quad	0x3b85e0885ebd9cc3, 0x3bcfd7d13f78002d
	.quad	0x3b823c981e88b022, 0x3bca8fe21d205eb0
	.quad	0x3b7e66846a73c925, 0x3bc62777b62fde0c
	.quad	0x3b7955ea2f392221, 0x3bc279bb2446baf4
	.quad	0x3b751cacbb42476e, 0x3bbecfc5eb955129
	.quad	0x3b719722d0b598a4, 0x3bb9b06ad8cbcafb
	.quad	0x3b6d4f0c5733dbc9, 0x3bb56a684fe99fca
	.quad	0x3b6869f70ffc1fcb, 0x3bb1d9d500e92622
	.quad	0x3b645586a9e82938, 0x3badc163a555fefb
	.quad	0x3b60ef18dbc017ff, 0x3ba8cbe28ca7c426
	.quad	0x3b5c338d2435fb4b, 0x3ba4a94f1540c9ea
	.quad	0x3b577ae3cb88b469, 0x3ba136b93820fc76
	.quad	0x3b538bf7be87e681, 0x3b9cadeb8c3bba05
	.quad	0x3b50453702b9a5bb, 0x3b97e356a2db5e15
	.quad	0x3b4b154294e891da, 0x3b93e50df3387f95
	.quad	0x3b4689b85dc875b1, 0x3b909125281c373a
	.quad	0x3b42c0dc90fab5ba, 0x3b8b969aedac7779
	.quad	0x3b3f346b0aa94647, 0x3b86f7d0d10edd84
	.quad	0x3b39f5604d9610b0, 0x3b831e8350b95dae
	.quad	0x3b3597757e14e4e8, 0x3b7fd3a5c3ac18bb
	.quad	0x3b31f50b401397f7, 0x3b7a7ca8fa240180
	.quad	0x3b2ddd8dcb76e388, 0x3b760a5532471804
	.quad	0x3b28d50fcdd2a012, 0x3b7256887c26e498
	.quad	0x3b24a512f5483d32, 0x3b6e82efb884fa70
	.quad	0x3b2129521372a709, 0x3b6961449f1f5f93
	.quad	0x3b1c872d91eff745, 0x3b651be080b9d49d
	.quad	0x3b17b56e9895b756, 0x3b618df034ba2c47
	.quad	0x3b13b37e1b01d1bd, 0x3b5d31877f1753ba
	.quad	0x3b105e763ef1c6e1, 0x3b5845928aac023d
	.quad	0x3b0b3291e83a6dda, 0x3b542d6673958cf7
	.quad	0x3b06978c8d7d61b8, 0x3b50c58552d896bd
	.quad	0x3b02c3987ce2b431, 0x3b4be0be95f0126e
	.quad	0x3aff2a6593b4ee39, 0x3b472aab5cc51918
	.quad	0x3af9e0f0cfd57ab4, 0x3b433fd04413c4e8
	.quad	0x3af57c6a75ebbd36, 0x3b3ffc132424c87a
	.quad	0x3af1d636b1da2b46, 0x3b3a91d6af35687b
	.quad	0x3aed9c6f3705063c, 0x3b36119a09e14fe5
	.quad	0x3ae8936d384f421a, 0x3b3253fb5c838ba6
	.quad	0x3ae464f8c7e074fc, 0x3b2e7068fdcaeb4e
	.quad	0x3ae0ec1f5aebc21f, 0x3b2945fff2eb1b17
	.quad	0x3adc14515cb6f8f0, 0x3b24fb5a7146299a
	.quad	0x3ad74b15b6eeceb1, 0x3b216ab8334ccb0a
	.quad	0x3ad352169fa33216, 0x3b1ce965139dad89
	.quad	0x3ad0060a522d6818, 0x3b17fe578074e0c8
	.quad	0x3aca933ad3e37ea3, 0x3b13e8d828e807b4
	.quad	0x3ac608e37fe916b7, 0x3b1084c9533fea9d
	.quad	0x3ac24490f08ca22d, 0x3b0b68488148e38c
	.quad	0x3abe4940102c0a26, 0x3b06bbe630bdc58c
	.quad	0x3ab91a40479b1837, 0x3b02daed7fd23569
	.quad	0x3ab4cdb9a0d20ef7, 0x3aff45c523b5ec4e
	.quad	0x3ab13d21ec7ce7a5, 0x3af9ee3b5d440d20
	.quad	0x3aac90f21d2d475f, 0x3af57f9f997e1f52
	.quad	0x3aa7aa5b8d4b4359, 0x3af1d262b74c69e4
	.quad	0x3aa39a647b21bed6, 0x3aed8b50e711660a
	.quad	0x3aa03c70a0dadb1d, 0x3ae87c4bc616ed3d
	.quad	0x3a9ae43ba1c85bb1, 0x3ae44a615135e868
	.quad	0x3a96446b3db12c58, 0x3ae0cfed72363bb7
	.quad	0x3a926f997cdc041d, 0x3adbdb5f7a82d0f4
	.quad	0x3a8e86218ea3e6ac, 0x3ad7136d3b897e11
	.quad	0x3a89440cec9f5e3a, 0x3ad31cf2729ac24d
	.quad	0x3a84e93295651e9b, 0x3acfa860b2bf75f8
	.quad	0x3a814df714b2cc27, 0x3aca36fa64c5b19f
	.quad	0x3a7ca3058fde005f, 0x3ac5b478418ed951
	.quad	0x3a77b135dc219792, 0x3ac1f8035d726d41
	.quad	0x3a73995999427ba7, 0x3abdbf75e60682c2
	.quad	0x3a703604de581436, 0x3ab89f0afa1deeca
	.quad	0x3a6ad067d36fa2c8, 0x3ab4602a49df0a52
	.quad	0x3a662c6642f5d4b9, 0x3ab0dc2db21eaf21
	.quad	0x3a62556d7a42568a, 0x3aabe61355e30a98
	.quad	0x3a5e5068065139be, 0x3aa7145a7dd1cf8c
	.quad	0x3a590efd5cd13c30, 0x3aa31725e0702649
	.quad	0x3a54b62e9374c452, 0x3a9f93e90900fd6b
	.quad	0x3a511de133cc6916, 0x3a9a1d0c10ff74df
	.quad	0x3a4c49bf95c5f745, 0x3a9597928f3e0c70
	.quad	0x3a475f56ab48bd89, 0x3a91d9f316556fcc
	.quad	0x3a434f00cbd8ea42, 0x3a8d8389849eaf01
	.quad	0x3a3fe61cbe17950d, 0x3a88650e1db268eb
	.quad	0x3a3a589caf82618c, 0x3a84293ddcb013c1
	.quad	0x3a35c1e107375834, 0x3a80a90025fd130c
	.quad	0x3a31f7319c565581, 0x3a7b87eb911fc5ef
	.quad	0x3a2daa6c6af5c17f, 0x3a76bea387f6b0a0
	.quad	0x3a287d63120a742c, 0x3a72c9c915a28dda
	.quad	0x3a2436e80df031f0, 0x3a6f094496a5e827
	.quad	0x3a20aef9bffa708d, 0x3a69a19446f657cc
	.quad	0x3a1b890579385cdc, 0x3a652a33b4b8094c
	.quad	0x3a16b84ffdb5d885, 0x3a6179841589cd00
	.quad	0x3a12be9773700384, 0x3a5cda2d93f291ab
	.quad	0x3a0eecef0206652c, 0x3a57d0e0e7cac5b0
	.quad	0x3a09821029662ccf, 0x3a53a804f20fd2f4
	.quad	0x3a05097c74b3d08e, 0x3a5038a34010e13f
	.quad	0x3a0158fcf12f6c8e, 0x3a4ac508371be502
	.quad	0x39fc9b60c296975d, 0x3a461608ea10db83
	.quad	0x39f7958bc88e6006, 0x3a42383e3bce3750
	.quad	0x39f370dfa8e149d1, 0x3a3e0e820ef74630
	.quad	0x39f0060a594f59c7, 0x3a38c9f67fa9c048
	.quad	0x39ea6925bee98d74, 0x3a3471203b047e85
	.quad	0x39e5c351b4996320, 0x3a30dae92b938870
	.quad	0x39e1ee518d278c58, 0x3a2bcabf2ba981bf
	.quad	0x39dd8b2f8b0b2924, 0x3a26e8f25135d13f
	.quad	0x39d855f0a34582a6, 0x3a22e219acb023ae
	.quad	0x39d40b1881e58e30, 0x3a1f1fe817902ceb
	.quad	0x39d0818d80634105, 0x3a19a5d5233d8e13
	.quad	0x39cb2ecbb2e8d76c, 0x3a1521d0766f8b85
	.quad	0x39c6614d9da549fb, 0x3a1168c985c93c95
	.quad	0x39c26c7736a63e7f, 0x3a0cae6809d7d445
	.quad	0x39be546a107b57d5, 0x3a079f71edd3cb51
	.quad	0x39b8f64020effd9c, 0x3a037443c37e4835
	.quad	0x39b48aa64075b150, 0x3a0004e8297ce819
	.quad	0x39b0e6e891142764, 0x39fa60ceba01346a
	.quad	0x39abcfa525d16889, 0x39f5b71dfbe662f9
	.quad	0x39a6e0be1ed4e4cc, 0x39f1dfe04c5b884a
	.quad	0x39a2d14568fa3103, 0x39ed6c299b6b03de
	.quad	0x399ef39c9c67da70, 0x39e8366f8264d161
	.quad	0x399973b86e9a718f, 0x39e3ec401194be5f
	.quad	0x3994ed55e6d4d5df, 0x39e0641ea45be131
	.quad	0x3991345b1de4a541, 0x39daf7b06dd7c2fa
	.quad	0x398c48e8cf8e20ed, 0x39d62e7924beab28
	.quad	0x39873f6cd7db5a56, 0x39d23e2123cac1dc
	.quad	0x39831afb2e91937b, 0x39ce00be39adba8f
	.quad	0x397f6600b76754fc, 0x39c8ab4ee2717624
	.quad	0x3979cc2881babaf0, 0x39c447fa5b4e25fe
	.quad	0x3975316d5b010b17, 0x39c0abf02c055867
	.quad	0x3971688993cfebe3, 0x39bb67d9f35f4de8
	.quad	0x396c98758b0a4eba, 0x39b685ccfe1e2ab5
	.quad	0x39677baf72da4868, 0x39b281e65593d670
	.quad	0x3963484c1e2418cb, 0x39ae698bd1000fd2
	.quad	0x395fa991c2110340, 0x39a8fc0326c87b11
	.quad	0x3959fe006460b912, 0x39a485d5ed97243e
	.quad	0x395555b844a27ecd, 0x39a0db191585c5a2
	.quad	0x395182875c9f3984, 0x399baf50ff65044d
	.quad	0x394cbce2423a80ac, 0x3996bb8ebe73c54a
	.quad	0x394794741d4d28c6, 0x3992a9fd1221e357
	.quad	0x3943586a18110b0e, 0x398ea4b746dbeae3
	.quad	0x393fbd1c1dcb3991, 0x3989271dfe5687e7
	.quad	0x393a085cf5d6c87e, 0x3984a4b9ae2c857d
	.quad	0x393559911f8b7812, 0x3980f0c2d578f06a
	.quad	0x393181ddd71c27fb, 0x397bccd0201398ba
	.quad	0x392cb5889458c00e, 0x3976cec95dfef21a
	.quad	0x392789499da6bff1, 0x3972b5ae7721763f
	.quad	0x39234b0b5ddf82c6, 0x396eb1327842cc63
	.quad	0x391fa04646636ebe, 0x39692bda7bca05b7
	.quad	0x3919eb0ea42d451e, 0x3964a4186866270a
	.quad	0x39153ce6234f7db7, 0x3960ec8a57831ec5
	.quad	0x3911668fdbb007d5, 0x395bbfd05e1b64f3
	.quad	0x390c8289c5fd0187, 0x3956bf24d893426c
	.quad	0x39075a62b0407aef, 0x3952a4c4fb42b862
	.quad	0x3903206cc37b0e4a, 0x394e8ec43d273fba
	.quad	0x38ff53937c26236e, 0x39490a22ee0d506e
	.quad	0x38f9a69ad7793258, 0x394483f4fee6553c
	.quad	0x38f50039cbf56e41, 0x3940ce82f0139653
	.quad	0x38f13119a81ee824, 0x393b888d3fea2a71
	.quad	0x38ec24cdc6a6909b, 0x39368ce8cbb7eaeb
	.quad	0x38e7089487e1182e, 0x3932778e05f0f826
	.quad	0x38e2d94fe2dcd5a4, 0x392e3e0a1bcb7b90
	.quad	0x38ded85fe218f015, 0x3928c29185861611
	.quad	0x38d93c37ffa2be30, 0x392444e2559eb861
	.quad	0x38d4a49efe08b764, 0x39209735c9244f77
	.quad	0x38d0e26d33274acd, 0x391b28030446d467
	.quad	0x38cb9dfc560135f0, 0x391638fa554a9791
	.quad	0x38c6955081ac80b2, 0x39122ed7a20d2031
	.quad	0x38c276f565251c73, 0x390dc07399fb9ebd
	.quad	0x38be30d639687648, 0x3908566bbf3afdcc
	.quad	0x38b8adc46e842374, 0x3903e7fef514c8f7
	.quad	0x38b42bb0eedd3fb2, 0x3900479dd0162987
	.quad	0x38b07beb0edff1b8, 0x38fa9fe7272a642b
	.quad	0x38aaf070915be74e, 0x38f5c4d5495043b3
	.quad	0x38a602994f04daa5, 0x38f1cbea64272b5f
	.quad	0x38a1fb139d7ad130, 0x38ed18375dee0b86
	.quad	0x389d5fdfa65dd70d, 0x38e7c798c690caf6
	.quad	0x3897fdb85ec65bd4, 0x38e36eec953c25e3
	.quad	0x38939787263ebbca, 0x38dfc2409fc1812e
	.quad	0x388ffeb0495cc103, 0x38d9f29b80329143
	.quad	0x388a1f276c1aeb71, 0x38d5328106ecc8f8
	.quad	0x388552f40714fe54, 0x38d1507fc4d2f4ba
	.quad	0x388167c9d827337c, 0x38cc484291d11ff0
	.quad	0x387c690e28b6a9bf, 0x38c7189333483e3b
	.quad	0x38772f13b97db104, 0x38c2dbc3e931f24d
	.quad	0x3872eaa616a9b21c, 0x38becb050b3055a0
	.quad	0x386edda16b7edc87, 0x38b9231c8255bcdb
	.quad	0x38692da9c960076a, 0x38b4848161f4e509
	.quad	0x38648955baf138af, 0x38b0beb55467080a
	.quad	0x3860bf90e157d9da, 0x38ab542338309321
	.quad	0x385b5082a5d8de09, 0x38a64c56b8fb3cec
	.quad	0x3856454856772fed, 0x38a231052b5f7dd6
	.quad	0x385227ecea87251d, 0x389dadb937ed07eb
	.quad	0x384d99724acabf71, 0x389834eb55a1d18e
	.quad	0x38481ff31715569a, 0x3893bdc43dd8955f
	.quad	0x3843a90e48619574, 0x389018fd4cd15479
	.quad	0x384005296113b586, 0x388a3fee5158c03f
	.quad	0x383a1acf8c750894, 0x3885664a8518a142
	.quad	0x38354421936100c1, 0x388171860917e7c8
	.quad	0x383152813e135602, 0x387c6f152728fb8f
	.quad	0x382c375a4cba7b23, 0x38772bf4ab4db677
	.quad	0x3826fa5568fa20f3, 0x3872e18c95c4bfb1
	.quad	0x3822b5b13ef0805c, 0x386ec41a3d4cf576
	.quad	0x381e77117811a7d2, 0x38691022d83bf8f5
	.quad	0x3818ccd934db2cb0, 0x38646a292659269e
	.quad	0x38142faa33070d2a, 0x3860a05da41d6048
	.quad	0x38106db98d7f6125, 0x385b14375f322de2
	.quad	0x380abcdbdfcc9f7c, 0x38560c75486158b0
	.quad	0x3805c15c23fbb403, 0x3851f35bc35fb59f
	.quad	0x3801b2fdb7cab6df, 0x384d39954e0a9d3d
	.quad	0x37fccb8a64624f6c, 0x3847c98ab66270f5
	.quad	0x37f76bb52e82b59a, 0x38435be6eb898758
	.quad	0x37f30c117f001ac3, 0x383f819edd38db9c
	.quad	0x37eefa0e49e3fecc, 0x3839a2821242ebd0
	.quad	0x37e92fa046d58d4e, 0x3834dadd528d6ea9
	.quad	0x37e479ae4e865fee, 0x3830f6d9e092345c
	.quad	0x37e0a4c603089f16, 0x382b987187720ae4
	.quad	0x37db0e03e96a5485, 0x3826711ad9310ce1
	.quad	0x37d5fc89a9e03199, 0x38223f97aea9f29f
	.quad	0x37d1dd90a3522c75, 0x381dac6b554960ff
	.quad	0x37cd07c0b8b30398, 0x38181f77dc55f2bd
	.quad	0x37c795540ea5dda7, 0x38139bb36d1a51da
	.quad	0x37c327f191dd6247, 0x380fdf7c425dfb89
	.quad	0x37bf1db008e061d6, 0x3809e6c7f42ee3a0
	.quad	0x37b944b7c8850269, 0x38050bd38f4b0e14
	.quad	0x37b4846e1e475567, 0x38011954fcd9d596
	.quad	0x37b0a8512d6deeb0, 0x37fbc7d8a23288e1
	.quad	0x37ab0b57b848dfd5, 0x37f69099571fea27
	.quad	0x37a5f385601a1095, 0x37f25378a9823720
	.quad	0x37a1d0aee3f21eae, 0x37edc36feecfa2ba
	.quad	0x379ce9ce0f1b56b8, 0x37e82a9fb7ad076b
	.quad	0x379775af322a6fb6, 0x37e39ea243c7bf71
	.quad	0x3793084e2fb958e5, 0x37dfda4af81b306a
	.quad	0x378ee0aaff5c7275, 0x37d9da7a2c5ab52c
	.quad	0x37890b5b261712ac, 0x37d4fb44aa933f5c
	.quad	0x37844f853ca3d2a1, 0x37d1068e39733d5f
	.quad	0x37807839b24e2329, 0x37cba0b385a9673f
	.quad	0x377ab4ef712ea53c, 0x37c669cb88b98bb4
	.quad	0x3775a6a27edc2aaf, 0x37c22e458ff074e2
	.quad	0x37718ccfb2383c0d, 0x37bd7dccacf16bdf
	.quad	0x376c72c7d427b5c7, 0x37b7ea9a57d9c3fd
	.quad	0x37670debd3477d7c, 0x37b364981b4fcacc
	.quad	0x3762ae4c8505c4dc, 0x37af723b60a4c45a
	.quad	0x375e45347f37826d, 0x37a97e0b5db827a8
	.quad	0x3758859d9d834871, 0x37a4a9cae44d02aa
	.quad	0x3753dcdd6f53a761, 0x37a0bf347561e06f
	.quad	0x3750163c7a1b8ce3, 0x379b246ea577dcd5
	.quad	0x374a0de9e4d0326a, 0x3795fe1a8f2ffd47
	.quad	0x374518a7407eb90e, 0x3791d15869af1a46
	.quad	0x3741146574533e59, 0x378cde08f63664fd
	.quad	0x373ba6f77161f191, 0x378761ba88bf6eed
	.quad	0x373661c59f17fae0, 0x3782efafc89163c3
	.quad	0x37321d2894bdd4c7, 0x377eab12c8aa7e50
	.quad	0x372d50e0eba3e44d, 0x3778d4d432dee077
	.quad	0x3727b84a5753cf1f, 0x37741a589d11cb19
	.quad	0x37233091416396db, 0x377045db9ec2ba81
	.quad	0x371f0bb3ff173143, 0x376a57861242277f
	.quad	0x37191c3cacc75aaa, 0x376551681b8d3610
	.quad	0x37144ea256a84bb0, 0x376140098b38820c
	.quad	0x37106bb841410434, 0x375be9e2feb561e0
	.quad	0x370a8d98b0d57710, 0x375694e9fdcb7be5
	.quad	0x37057755a2313bdf, 0x37524419d9ce37ff
	.quad	0x37015a03d39bca43, 0x374d8bf1578b3aac
	.quad	0x36fc0c4e9f387792, 0x3747e4dfe2cee6a2
	.quad	0x36f6aa9b63079411, 0x3743520b0bf08a51
	.quad	0x36f250ad98a67e4f, 0x373f3daa3dd37f3a
	.quad	0x36ed9842421f4af1, 0x37394140b3abb78e
	.quad	0x36e7e859d0226582, 0x373469d2facc66f7
	.quad	0x36e34f9e5d4c96d3, 0x37307f7c6b04c092
	.quad	0x36df314a5f5af6d7, 0x372aa9f80ec12e52
	.quad	0x36d9306ca687d568, 0x37258b5e63278412
	.quad	0x36d456b681315daf, 0x372167dcc97a0fd3
	.quad	0x36d06b98180e66f0, 0x371c1ee5bab4ede7
	.quad	0x36ca82a4c036e3f3, 0x3716b69077bfc3c7
	.quad	0x36c565cda5d05a6a, 0x371257dcc5bc2717
	.quad	0x36c144d77262f022, 0x370d9fdd2296338f
	.quad	0x36bbdec7b50a66c0, 0x3707eb427b4ddd71
	.quad	0x36b67cb265d8483a, 0x37034f5aee912170
	.quad	0x36b224399b226996, 0x36ff2ca4dc8ff69f
	.quad	0x36ad448f86c23d12, 0x36f92943634830d2
	.quad	0x36a79b2a15ae0faa, 0x36f44e2d8e947442
	.quad	0x36a3098d833c2da0, 0x36f0627b1e47c261
	.quad	0x369eb3aa595948f3, 0x36ea705784809825
	.quad	0x3698c0f08dff4e68, 0x36e554226cd542ef
	.quad	0x3693f49a8880f6ad, 0x36e1343e7a202e90
	.quad	0x369015dd1c62a082, 0x36dbc0384ab3550d
	.quad	0x3689edb80143a705, 0x36d660fe966c4e28
	.quad	0x3684e52056f2dec4, 0x36d20b6b60dae611
	.quad	0x3680d62a769875e0, 0x36cd1893fc15ba16
	.quad	0x367b2128dd015485, 0x36c7747e31ddd25c
	.quad	0x3675dad6d3a16694, 0x36c2e7c997078049
	.quad	0x36719a81ef58dfc6, 0x36be790d89e8e564
	.quad	0x366c5ae1b79c4ee8, 0x36b88e545d12ba57
	.quad	0x3666d56e11abc8a7, 0x36b3c919aea97870
	.quad	0x366262a204b39df1, 0x36afe13c6f07b6ae
	.quad	0x365d9a774b67b183, 0x36a9ae2b16a9550a
	.quad	0x3657d48e51f6d6ed, 0x36a4af14f857334e
	.quad	0x36532e43016e50e4, 0x36a0a8564eab8ff5
	.quad	0x364edf747f9f14f1, 0x369ad3a333504020
	.quad	0x3648d7d80e14b910, 0x3695996d7e13f467
	.quad	0x3643fd1708b687cb, 0x3691636f3d76858a
	.quad	0x364014ad3fec9ec4, 0x368bfe545fce7a55
	.quad	0x3639dee40ecc2982, 0x368687ce08618977
	.quad	0x3634ceca2b274540, 0x368221a377d62eb4
	.quad	0x3630bbd071377b87, 0x367d2dcd30499eb7
	.quad	0x362ae9438e9a5c0b, 0x367779da2df7a30c
	.quad	0x3625a30285652ad0, 0x3672e2a7c1fe1c5f
	.quad	0x362164daef1c2b15, 0x366e61933d473856
	.quad	0x361bf6806876a635, 0x36686f2e6e7e582a
	.quad	0x36167960688424ef, 0x3663a62b4892ce6e
	.quad	0x36120f7f47f404a7, 0x365f99234ed0089e
	.quad	0x360d061d530972c5, 0x3659676058974913
	.quad	0x3607517e8c57f622, 0x36546bd7c1e28ef0
	.quad	0x3602bb6ba79809ed, 0x365069f8cb02119f
	.quad	0x35fe179628712470, 0x364a61febb6d574d
	.quad	0x35f82af24bbe81dd, 0x36453351984f5d61
	.quad	0x35f3684a09debb18, 0x364108b4faaa8971
	.quad	0x35ef2a603a977e7c, 0x363b5e91e3ee196d
	.quad	0x35e9054beadf5a51, 0x3635fc381e001854
	.quad	0x35e415c074fc9065, 0x3631a8782bc000be
	.quad	0x35e01ef55a0092e3, 0x362c5c9be5ba37d4
	.quad	0x35d9e016e74801cb, 0x3626c625c9dd5c05
	.quad	0x35d4c3713bae315d, 0x362248f08aa2a9f5
	.quad	0x35d0a8cf82738469, 0x361d5b98efc2e8d5
	.quad	0x35cabada51b7b47e, 0x361790b07dcc17dd
	.quad	0x35c570fb47030aa8, 0x3612e9c8b4dec3de
	.quad	0x35c13270ae279a57, 0x360e5affac730013
	.quad	0x35bb951931589ad6, 0x36085b69d604d483
	.quad	0x35b61dfa678e3296, 0x36038aa7fa8655e3
	.quad	0x35b1bb88966006c4, 0x35ff5a41ad29abd6
	.quad	0x35ac6e52f00f28e6, 0x35f925df815332e1
	.quad	0x35a6ca07adb2cabe, 0x35f42b32a68b6433
	.quad	0x35a243c4de072741, 0x35f02c65f05a223c
	.quad	0x359d4603cf73627e, 0x35e9ef9ba1f58105
	.quad	0x359774b9c8b06520, 0x35e4cb0a4ddc2264
	.quad	0x3592cad15ed5f00d, 0x35e0ab038a2ddd17
	.quad	0x358e1ba565f2f2da, 0x35dab82536c08c11
	.quad	0x35881da56c03901c, 0x35d569ce24f30cad
	.quad	0x358350587b61e2e7, 0x35d128ac3f80b9ac
	.quad	0x357eeeaf2386ba73, 0x35cb7f008c184953
	.quad	0x3578c45dba9ebaff, 0x35c6071b5b7d5f0b
	.quad	0x3573d40375ab2fc9, 0x35c1a5112ad78884
	.quad	0x356fbe96dd52dd2a, 0x35bc43afb43abf3a
	.quad	0x35696874b77050b3, 0x35b6a28d7dab4750
	.quad	0x3564557ac9b8a4ff, 0x35b21fe234726979
	.quad	0x35604568afbad70b, 0x35ad05b30647f5b6
	.quad	0x355a097bba9c5bba, 0x35a73bbedaae952f
	.quad	0x3554d4668bc3c638, 0x35a298ce64edbc52
	.quad	0x3550a969821c25d4, 0x359dc489a35fd890
	.quad	0x354aa703eac27071, 0x3597d248efdebaf1
	.quad	0x3545506ec96ce1d8, 0x35930f843b6c62b7
	.quad	0x35410b0827e1c59f, 0x358e7fb2011e1175
	.quad	0x353b409eb99c2287, 0x358865c4d7ebd336
	.quad	0x3535c93bed6568e9, 0x358383b206d0bb99
	.quad	0x353169ff47b694c6, 0x357f36aa78ac249d
	.quad	0x352bd5de633517f7, 0x3578f5cbbd7e3bd9
	.quad	0x35263e7724f64774, 0x3573f5064180659d
	.quad	0x3521c60a3dd2224e, 0x356fe8f1d993bb19
	.quad	0x351c66566ef40333, 0x356981f750955121
	.quad	0x3516afcac6c09d1a, 0x3564632fef2669ec
	.quad	0x35121ee56dbc8c6a, 0x35604b03ffb7174a
	.quad	0x350cf19c31a391ac, 0x355a09e23dee12db
	.quad	0x35071ce2ba111a68, 0x3554cddefbe00dae
	.quad	0x3502744e94597df0, 0x35509eb734c1a314
	.quad	0x34fd77474fa3c96f, 0x354a8d28a7b21f9e
	.quad	0x34f7856cde19858b, 0x354534c49c3a48a0
	.quad	0x34f2c60519b06073, 0x3540ef5469afe541
	.quad	0x34edf6f23e67822e, 0x353b0b689ea896f0
	.quad	0x34e7e9197060941a, 0x35359793ad60d8ab
	.quad	0x34e313ca61e59763, 0x35313c9ee6b2a529
	.quad	0x34de703ac45eb1a5, 0x352b84429b1d33d8
	.quad	0x34d8479b71b66ff2, 0x3525f60114dc317a
	.quad	0x34d35d621cd7892f, 0x3521865baa279b03
	.quad	0x34cee2c2766d39ae, 0x351bf759f4ae6481
	.quad	0x34c8a0a908fbee34, 0x35164fc41f392bcd
	.quad	0x34c3a29293d26666, 0x3511cc51b3533d1b
	.quad	0x34bf4e2f320ed2f5, 0x350c645558315ad7
	.quad	0x34b8f3fbe30bc1d8, 0x3506a496dcf46820
	.quad	0x34b3e324f4cf0981, 0x35020e4a4b8e031e
	.quad	0x34afb22b934b9930, 0x34fccadf3adb1af0
	.quad	0x34a941518f17ca26, 0x34f6f4367d03dbd8
	.quad	0x34a41ee59ab3f625, 0x34f24c114d622260
	.quad	0x34a00733b2d2d2a7, 0x34ed2aa649df6e65
	.quad	0x3499886bd6d1085b, 0x34e73e63a45afd4d
	.quad	0x349455a452136a60, 0x34e285756918be22
	.quad	0x3490314c07978175, 0x34dd835dd5ba6335
	.quad	0x3489c91111b6c15f, 0x34d782e2c1c97a81
	.quad	0x3484873499e69a71, 0x34d2ba486638ab1e
	.quad	0x3480573c7a800f18, 0x34cdd4be385e9720
	.quad	0x347a030c72f0cf33, 0x34c7c17c5d99552c
	.quad	0x3474b36ddfcc8743, 0x34c2ea5f617d321f
	.quad	0x347078e5ec28bafd, 0x34be1e853589fe15
	.quad	0x346a362e51221b9f, 0x34b7f9fd64579e1a
	.quad	0x3464da2bb75a5c65, 0x34b3159306d0abd0
	.quad	0x3460962c95c3eb50, 0x34ae6076548c0765
	.quad	0x345a624c67aa97df, 0x34a82c376c3acddf
	.quad	0x3454fb4e0c13d490, 0x34a33bbfc6dd55a6
	.quad	0x3450aef82f484486, 0x349e9a5b32d2ef52
	.quad	0x344a874210dbadcf, 0x34985800f4a2d262
	.quad	0x344516b94dabb86d, 0x34935cc607ce4fd8
	.quad	0x3440c33410fd4c56, 0x348ecc03cea2935d
	.quad	0x343aa4f078af0321, 0x34887d359f39448e
	.quad	0x34352c5696370c9d, 0x3483788a50e33e44
	.quad	0x3430d2cf5025ba2d, 0x347ef546c9652b0a
	.quad	0x342abb3ec79d594d, 0x34789bb66243bfd5
	.quad	0x34253c13ca08d951, 0x34738ef570827673
	.quad	0x3420ddbcd68fc943, 0x346f1601a115b514
	.quad	0x341aca1a45423b35, 0x3468b369b3c6ec4f
	.quad	0x341545e3b0f8838a, 0x34639ff49c7fe5e8
	.quad	0x3410e3f374dd9d68, 0x345f2e18e05495b4
	.quad	0x340ad1767288e013, 0x3458c43bad265564
	.quad	0x340549be08e15927, 0x3453ab798c59d4c2
	.quad	0x3400e56def61fbc4, 0x344f3d7844c8a592
	.quad	0x33fad14d1b2f0b5f, 0x3448ce1e26fb8214
	.quad	0x33f5479f9137160b, 0x3443b17a8d383f04
	.quad	0x33f0e22b05782284, 0x343f4412db819edf
	.quad	0x33eac99e5e7b9269, 0x3438d108ccedcd75
	.quad	0x33e53f8a0f98a8b8, 0x3433b1f28f8795ca
	.quad	0x33e0da2d734853ff, 0x342f41e3132440da
	.quad	0x33daba70af1767b0, 0x3428ccf9296410ae
	.quad	0x33d531844d58365e, 0x3423ace12e143377
	.quad	0x33d0cd7bedf59779, 0x341f36eac3bc78c2
	.quad	0x33caa3d0ca096eed, 0x3418c1f2a8f92477
	.quad	0x33c51d9a0dfd2e93, 0x3413a24aae988ae7
	.quad	0x33c0bc211a3c2859, 0x340f23332c263066
	.quad	0x33ba85d1a4e6bedc, 0x3408affe95ac6f2a
	.quad	0x33b503dbfed30324, 0x34039237fbbcfa18
	.quad	0x33b0a62b7d92f095, 0x33ff06cce511da3e
	.quad	0x33aa608c535a2ba1, 0x33f8972c09d7f45c
	.quad	0x33a4e45f9fa4adff, 0x33f37cb698950bda
	.quad	0x33a08bad69ed20a4, 0x33eee1cfc9be3df9
	.quad	0x339a341fe436d2d7, 0x33e8778fdb058321
	.quad	0x3394bf3f24d273a5, 0x33e361d88db2b95b
	.quad	0x33906cbce44363ec, 0x33deb45ad695330a
	.quad	0x338a00b13659be7c, 0x33d851447ccc879b
	.quad	0x3384949952fc2371, 0x33d341b44ff4c3c6
	.quad	0x3380497386163a39, 0x33ce7e93fdecae00
	.quad	0x3379c66ac5ae65b3, 0x33c82469dbf1833e
	.quad	0x337464915486577b, 0x33c31c64a141680e
	.quad	0x337021ee5a248c7f, 0x33be40a7f340982a
	.quad	0x3369857c70b8b2bc, 0x33b7f125320f1e94
	.quad	0x33642f4e894cc71a, 0x33b2f2086b6a5cf4
	.quad	0x335fec9b69351b70, 0x33adfac9ed4c27ce
	.quad	0x33593e1b371520a1, 0x33a7b7a0d21f0262
	.quad	0x3353f4fc50de840a, 0x33a2c2c295822108
	.quad	0x334f8d6a0e0a9508, 0x339dad335f7aacdb
	.quad	0x3348f080f16c57c0, 0x3397780bee4609a1
	.quad	0x3343b5c9cfaada16, 0x33928eb9d3f5000a
	.quad	0x333f269560bdbf92, 0x338d5823ab37d92e
	.quad	0x33389cec0363502d, 0x3387329a5753ca24
	.quad	0x333371e9af8e6ccf, 0x3382561873c1cc7a
	.quad	0x332eb86f931c309d, 0x337cfbdfc9b64d6e
	.quad	0x3328439f081b525a, 0x3376e7843670c8d2
	.quad	0x33232991dc38028e, 0x3372190c2136fc76
	.quad	0x331e434fdd743954, 0x336c98b1eed08258
	.quad	0x3317e4e079de1a2e, 0x33669705c180d6c1
	.quad	0x3312dcfb3be31ebd, 0x3361d7c5aaa09490
	.quad	0x330dc7920bafc5dc, 0x335c2ee925b3e3f6
	.quad	0x330780fa5599d558, 0x3356415eeac7f744
	.quad	0x33028c6164ec1235, 0x33519278bf59ff34
	.quad	0x32fd459605b63623, 0x334bbed8e8100752
	.quad	0x32f71839bad6a45b, 0x3345e6d30c67b96b
	.quad	0x32f2380250c57526, 0x3341495babbc8d8e
	.quad	0x32ecbdbf53eed588, 0x333b48d8b08c37b5
	.quad	0x32e6aaee88d3a5e6, 0x333587a8905112eb
	.quad	0x32e1e01e0cda0c0e, 0x3330fca71267dd26
	.quad	0x32dc3074a0c1c67d, 0x332acd43894c1f06
	.quad	0x32d6396af97c5f7f, 0x33252428954b7c2f
	.quad	0x32d184f669e7e645, 0x3320ac95a364b406
	.quad	0x32cb9e1f37f768c9, 0x331a4c779750fb77
	.quad	0x32c5c4033ae88d94, 0x3314bc9e91b546a8
	.quad	0x32c126ceaa621095, 0x33105963d1a5105b
	.quad	0x32bb072a84d6770b, 0x3309c6d5a387a6d7
	.quad	0x32b54b0d08180ac6, 0x33045157f4a2e598
	.quad	0x32b0c5eb30658611, 0x3300034f87652744
	.quad	0x32aa6c038fdf5aed, 0x32f93cc0a254a9f5
	.quad	0x32a4cedf419a9b38, 0x32f3e2a3c60327aa
	.quad	0x32a062912bcc23f9, 0x32ef552fb3e1c70b
	.quad	0x3299cd187cff951c, 0x32e8ae9d3a6eb66f
	.quad	0x32944fd186d008c2, 0x32e370d2466d3327
	.quad	0x328ffa0c91caab55, 0x32de9ef97aa04b46
	.quad	0x32892ad80b12a09b, 0x32d81cd14bd535bb
	.quad	0x3283ce3bd0683046, 0x32d2fc348f3a8121
	.quad	0x327f2b20c0b002ab, 0x32cde47d70b3398c
	.quad	0x327885b1157e885c, 0x32c787c377ac34cd
	.quad	0x32734a760cc47aca, 0x32c2851c338b22e4
	.quad	0x326e58ea51580bad, 0x32bd263d33512bb6
	.quad	0x3267de1218b19542, 0x32b6efdaa9c0e45e
	.quad	0x3262c4d7bed4d522, 0x32b20bdae2cd61c6
	.quad	0x325d83f3d3e6d150, 0x32ac64ba5bdb46de
	.quad	0x32573468ba3c29b8, 0x32a6557da47246f7
	.quad	0x32523db7a001a935, 0x32a190c20d5b5808
	.quad	0x324cacc668087b83, 0x329ba075f0192b60
	.quad	0x324689215536317f, 0x3295b9128fb09361
	.quad	0x3241b56b45aac06f, 0x329114228bb99133
	.quad	0x323bd3e92f58e3ae, 0x328ad9efd6e7e350
	.quad	0x3235dca68b92a62f, 0x32851afe8bbb6b6c
	.quad	0x32312c46cab86e91, 0x3280964c48f92b05
	.quad	0x322af9e0c680145a, 0x327a11a652260d00
	.quad	0x32252f60dcf5b390, 0x32747ba5483b6e8f
	.quad	0x3220a29c7db10f70, 0x3270178df0b67157
	.quad	0x321a1f2ec5b27de2, 0x326948157e97fbd7
	.quad	0x321481b643932bec, 0x3263db68a0470a4f
	.quad	0x321018bc93b8e2e5, 0x325f306942454ae6
	.quad	0x3209445149305037, 0x32587db6da6dd3ca
	.quad	0x3203d409d78b6819, 0x32533aa83bd4deab
	.quad	0x31ff1de9c1ab95aa, 0x324e311742f9561b
	.quad	0x31f869c2824b4b6b, 0x3247b300d303ed2c
	.quad	0x31f326bb792c8c5b, 0x324299c1370fc2d1
	.quad	0x31ee0b212b870715, 0x323d31b83aa1a53b
	.quad	0x31e78ff85165ac91, 0x3236e8665a634aff
	.quad	0x31e27a27826da7a5, 0x3231f90dcff1976e
	.quad	0x31dcf9b0072f8176, 0x322c32d9c998168a
	.quad	0x31d6b763e947db08, 0x32261e5684f4d137
	.quad	0x31d1cea67fe8699c, 0x322158e51a7ac97e
	.quad	0x31cbea20cad09b1f, 0x321b350464c51c99
	.quad	0x31c5e0717c155a1c, 0x3215553c2fc66728
	.quad	0x31c1248cf18568a2, 0x3210b99abbccdbb1
	.quad	0x31badcf760300963, 0x320a38baebfb68e4
	.quad	0x31b50b87f214792d, 0x32048d7dafad7ffe
	.quad	0x31b07c2b12fe4dba, 0x32001b7eac5ea688
	.quad	0x31a9d2b0d0c4a0b1, 0x31f93e7a4bb07430
	.quad	0x31a43908aa677d25, 0x31f3c77c897ed254
	.quad	0x319fab995891c153, 0x31eefdba02e2ceff
	.quad	0x3198cbc2fe600108, 0x31e846b92a47c343
	.quad	0x3193694f45c1b92f, 0x31e30395337f89bb
	.quad	0x318e6371d3dc0233, 0x31ddc7fb7bbca8ad
	.quad	0x3187c89c6867890e, 0x31d751e7a10e8264
	.quad	0x31829cb17b0f706b, 0x31d2421ee0211f87
	.quad	0x317d20647a807a0c, 0x31cc9649548abac7
	.quad	0x3176c9a3fd812077, 0x31c6606f00ed6d5d
	.quad	0x3171d37ef5f490cd, 0x31c1836b52067807
	.quad	0x316be2ec88ae1479, 0x31bb6922692e74d4
	.quad	0x3165cf38f9818abf, 0x31b572b1a2c0293a
	.quad	0x31610e013ef486f7, 0x31b0c7c6b93f06a1
	.quad	0x315aab7b734b99f6, 0x31aa40fcadcdd133
	.quad	0x3154d9b2cf546b09, 0x31a4890ac32b69b5
	.quad	0x31504c7bad04b57c, 0x31a00f779993bbc1
	.quad	0x31497a78d5f1c6db, 0x31991e450ac30542
	.quad	0x3143e9611e821800, 0x3193a3ce69b6a143
	.quad	0x313f1e56c0773bb7, 0x318eb57d7362f984
	.quad	0x313850426f2df55d, 0x3188015f467ddd40
	.quad	0x3132fe8bb3e4f4d8, 0x3182c3495adab7d8
	.quad	0x312dac8e8a813f1f, 0x317d53ae35dbfa26
	.quad	0x31272d2c2a7422ab, 0x3176eaa5fce4af3a
	.quad	0x31221972950f570d, 0x3171e7c114a57a33
	.quad	0x311c44004226dc17, 0x316bf9ebf2ac34cf
	.quad	0x3116118037139874, 0x3165da6aa3adb7a3
	.quad	0x31113a4e15d42467, 0x31611173d5813f4d
	.quad	0x310ae501496e23f2, 0x315aa895a750e0f6
	.quad	0x3104fd7f2b705e64, 0x3154d0f59b16ac32
	.quad	0x3100614ef7575b09, 0x31504098aca1b898
	.quad	0x30f98fdb1084fd1c, 0x31495ffef5a788b3
	.quad	0x30f3f16033b4da17, 0x3143ce864a4f75bb
	.quad	0x30ef1d3d20014dd3, 0x313eeabf27142ccb
	.quad	0x30e844cb59a101a9, 0x31382070510e6e91
	.quad	0x30e2ed514b22b68b, 0x3132d35346de60f3
	.quad	0x30dd84bdf7421499, 0x312d5fe3202b4d44
	.quad	0x30d7040489842ad7, 0x3126ea2738b3dbeb
	.quad	0x30d1f1777f205012, 0x3121df8a8637ba9c
	.quad	0x30cbf956a62adf73, 0x311be0e1bcc5bf2b
	.quad	0x30c5cdae0381ff94, 0x3115bd567e120a1c
	.quad	0x30c0fdef3b187063, 0x3110f35198b8b7f7
	.quad	0x30ba7b2fd5556b6a, 0x310a6df243f2c6f4
	.quad	0x30b4a1e48fd99b8e, 0x31049a26968a8fd1
	.quad	0x30b012cc9c3d142a, 0x31000ec5ed2dbe3e
	.quad	0x30a90a652d08b6ec, 0x30f9073f3afbdfeb
	.quad	0x30a380bacb3471d9, 0x30f380b5f70c487d
	.quad	0x309e603798765b0a, 0x30ee63fa380d130b
	.quad	0x3097a705e88ab4c8, 0x30e7ace6e086aab7
	.quad	0x30926a399e180e7c, 0x30e2711978a97cf7
	.quad	0x308cabc2c3d98d7c, 0x30dcba0a72ae9c08
	.quad	0x308651157275ac6f, 0x30d65efbb20adf2d
	.quad	0x30815e60bb1a2bac, 0x30d16b5cc5019368
	.quad	0x307b08358e30e1b1, 0x30cb1fca598944c3
	.quad	0x3075088c08941b89, 0x30c51d84fa353951
	.quad	0x30705d2722aa0abe, 0x30c06f82c9619b90
	.quad	0x3069757d44a0d5d1, 0x30b9953a1cf16aad
	.quad	0x3063cd5765cc7b51, 0x30b3e87f66d27bb0
	.quad	0x305eccf7568ff3af, 0x30aefb0c5f0312cd
	.quad	0x3057f37a88128933, 0x30a81a4d1085cfd1
	.quad	0x30529f5b70afae6e, 0x30a2bfdda4e2b20c
	.quad	0x304cf48b1a182cb9, 0x309d2ab3b59164a6
	.quad	0x304682022c0d8296, 0x3096aeea740e7e26
	.quad	0x30417e72ed48d1c2, 0x3091a389017ca93c
	.quad	0x303b30c9decefa86, 0x308b6dd2d215fccf
	.quad	0x303520de188c8ff4, 0x308552ee415230cd
	.quad	0x30306a7030db71fb, 0x308093620e33d9f9
	.quad	0x30298166f02e00aa, 0x3079c4336b720df7
	.quad	0x3023cfce2d301755, 0x30740629fd47fda6
	.quad	0x301ec63bac9af50a, 0x306f1e828f7f1e6e
	.quad	0x3017e609b497d4bf, 0x30682d92bd0fbc5b
	.quad	0x30128e89244647b5, 0x3062c8658b1c7fab
	.quad	0x300cd07ee41894f6, 0x305d2def7b6139fb
	.quad	0x30065e4eca3c47ce, 0x3056a9a29142865a
	.quad	0x30015cbd7439af48, 0x3051995fff959855
	.quad	0x2ffaf324889fe32e, 0x304b549f742691f7
	.quad	0x2ff4e9c920d5db05, 0x3045380a4af4c2e9
	.quad	0x2ff03a122e1077b7, 0x304078d07375b0b0
	.quad	0x2fe92d9bd168c630, 0x3039921acfd99f39
	.quad	0x2fe388030ea8589c, 0x3033d867ecfb60a5
	.quad	0x2fde4c4faf832008, 0x302ecccda72dba49
	.quad	0x2fd77f4a046c515e, 0x3027e5deef2de87b
	.quad	0x2fd2387f5f4b712e, 0x30228a511d87ce7d
	.quad	0x2fcc413282821079, 0x301cc3995b1e2c40
	.quad	0x2fc5e78bc56d0fbb, 0x30164f5f80200f46
	.quad	0x2fc0faba5af01355, 0x30114d5424501d7e
	.quad	0x2fba51f8a6830159, 0x300ad54bef9112d0
	.quad	0x2fb465b65a83bdbb, 0x3004ce07b8d50856
	.quad	0x2faf9c5589e7201f, 0x300020f8e226943e
	.quad	0x2fa87dc5ad8af9ec, 0x2ff90123a8271991
	.quad	0x2fa2f918e4d3f95c, 0x2ff3613b89391a8f
	.quad	0x2f9d6485a170413a, 0x2fee098381b76cd3
	.quad	0x2f96c3b66970be3d, 0x2fe7465697a54c64
	.quad	0x2f91a0fd8c3a4e6f, 0x2fe20858c20a1795
	.quad	0x2f8b4ce217bd5e55, 0x2fdbf05934cfa1cc
	.quad	0x2f8522e259c7017a, 0x2fd5a41409f84e49
	.quad	0x2f805caa9cf257c4, 0x2fd0c2b83023243d
	.quad	0x2f7954427a430b11, 0x2fc9f5672cf62a4f
	.quad	0x2f739a5d07601e71, 0x2fc41985de8f7a14
	.quad	0x2f6e56c72cc01fcc, 0x2fbf1f5d5615d783
	.quad	0x2f67797a6e64ddc9, 0x2fb8179bfb69c631
	.quad	0x2f6229374c838060, 0x2fb2a5d1d1f1ae5c
	.quad	0x2f5c18d454a503ae, 0x2facdd1c2bddbb9e
	.quad	0x2f55bb5b3e414ad3, 0x2fa655e203c78ad0
	.quad	0x2f50ce808921de57, 0x2fa1481ab5a1469a
	.quad	0x2f49fdfe587f056a, 0x2f9abd4ca4bd8884
	.quad	0x2f4418b54bd6a895, 0x2f94af20f59f283d
	.quad	0x2f3f128f851039d9, 0x2f8fff032b2dbde7
	.quad	0x2f3804c6e03f60cb, 0x2f88be8c488684b4
	.quad	0x2f3290596a08a94f, 0x2f83223f2e5be0f0
	.quad	0x2f2cb1395c8187f6, 0x2f7d964d959533d1
	.quad	0x2f262bb1316ec5fc, 0x2f76df780d5ecc43
	.quad	0x2f21211a1b47d3ae, 0x2f71ae2302fd4bcd
	.quad	0x2f1a772150026811, 0x2f6b5455f4e2ce45
	.quad	0x2f147143aa78b5fe, 0x2f651eade2a24279
	.quad	0x2f0f93996ba5e93d, 0x2f6051b3f15282e5
	.quad	0x2f08626f2553e204, 0x2f593760037df87a
	.quad	0x2f02d4091cd12adc, 0x2f537ace1ccc1a8d
	.quad	0x2efd1294db79df79, 0x2f4e17b7713cf17f
	.quad	0x2ef6715149108678, 0x2f473db39c4b278b
	.quad	0x2ef1529206516167, 0x2f41f27cc2724f90
	.quad	0x2eeabce28a1f17f2, 0x2f3bb70eb3792a1c
	.quad	0x2ee4a1fe3e55f964, 0x2f35659e4463ddd1
	.quad	0x2edfd6eb54be7326, 0x2f308462ba9624db
	.quad	0x2ed89049c51b8388, 0x2f297f4ffe1284a1
	.quad	0x2ed2f2b5e6789756, 0x2f23ad748e88c53f
	.quad	0x2ecd3aa617478594, 0x2f1e5e5db98318a5
	.quad	0x2ec68a9e9f7b2f9a, 0x2f176e6798f53e9a
	.quad	0x2ec161c2a1de488e, 0x2f121393590da64b
	.quad	0x2ebacda38e82463b, 0x2f0be32dc731f12c
	.quad	0x2eb4a9c33e05809a, 0x2f05824d30f3fce1
	.quad	0x2eafdaf4969fc450, 0x2f009660e736b8bd
	.quad	0x2ea88d45a53c41c5, 0x2ef994b0856743cb
	.quad	0x2ea2eba8f55fe897, 0x2ef3b9051c5e7679
	.quad	0x2e9d287e1e77c85a, 0x2eee689bae600601
	.quad	0x2e96770239fc87e6, 0x2ee77071c1633b26
	.quad	0x2e914e513c1b20dc, 0x2ee210a174166fcd
	.quad	0x2e8aa90041143186, 0x2edbd7abebe480e6
	.quad	0x2e8488642c71cfa6, 0x2ed5740f6d4ed277
	.quad	0x2e7f9f9ce5a157bb, 0x2ed0874302ee34fd
	.quad	0x2e785974997b931f, 0x2ec97701e51a6bfe
	.quad	0x2e72bf0c37efc00b, 0x2ec39d3aac239fe2
	.quad	0x2e6cdc89092e43c3, 0x2ebe36341a88ea0c
	.quad	0x2e6636f0e2785c54, 0x2eb743c5e4db43f9
	.quad	0x2e6118b19def65f8, 0x2eb1e9b8ad36fd99
	.quad	0x2e5a4fd2c459c710, 0x2eab94cde5e4fc30
	.quad	0x2e543ea7a73d5cf0, 0x2ea53b3a109a94ae
	.quad	0x2e4f26454740b953, 0x2ea057635a1ed1df
	.quad	0x2e47f60ab495565c, 0x2e9926f55b776f91
	.quad	0x2e426de8be09d876, 0x2e935abb1f1cadef
	.quad	0x2e3c5889cb51dbb9, 0x2e8dc853b381e5a0
	.quad	0x2e35cbe6a335189c, 0x2e86e96e5d005f5d
	.quad	0x2e30c22190c33c65, 0x2e819fc0dba0e848
	.quad	0x2e29c42b0a7816ac, 0x2e7b1c21d6e11086
	.quad	0x2e23ce41b9a97542, 0x2e74d91f3701143c
	.quad	0x2e1e71ba6efe048b, 0x2e7007de792cfd6e
	.quad	0x2e176552635a3b27, 0x2e68a6663a0ececb
	.quad	0x2e11fa1c7f04e719, 0x2e62f310e41037d6
	.quad	0x2e0b9f88d1e59fb3, 0x2e5d2185735c5ad9
	.quad	0x2e0538582347c59e, 0x2e566381bdd98a02
	.quad	0x2e004c9ca3c242ad, 0x2e51346f1ba5a69a
	.quad	0x2df9093a8968bba5, 0x2e4a706fd9470fb8
	.quad	0x2df339c31e0d51b7, 0x2e445000f1eec014
	.quad	0x2ded8619415342d3, 0x2e3f3510620184ea
	.quad	0x2de6aa95f63dd017, 0x2e37f84791f6fdbb
	.quad	0x2de16648113f6ec6, 0x2e32689bc620188b
	.quad	0x2ddab5b65b277be7, 0x2e2c45998d7521ae
	.quad	0x2dd47f9aad3382fe, 0x2e25b50e4b7d6356
	.quad	0x2dcf7591b1b1c875, 0x2e20aa3508d5db00
	.quad	0x2dc82335294ba260, 0x2e19959eb6f64db6
	.quad	0x2dc2848053b7dfb1, 0x2e13a2fb2a16d1cc
	.quad	0x2dbc68a6f5a8ef62, 0x2e0e23b370697cbb
	.quad	0x2db5c9ffcce7e5fd, 0x2e0720876851d9fb
	.quad	0x2db0b5b54d487d35, 0x2e01be79c992aff6
	.quad	0x2da9a0421e5c5d71, 0x2dfb3980569c43a5
	.quad	0x2da3a5c4268d4e27, 0x2df4e1fc4f822568
	.quad	0x2d9e1fba80d34a41, 0x2df0042910b94342
	.quad	0x2d97172912ec21f8, 0x2de8908e30f7a1b3
	.quad	0x2d91b271db151968, 0x2de2d5e5a1b8288e
	.quad	0x2d8b1f9ef2d6b135, 0x2ddce1b3b9ea6267
	.quad	0x2d84c872d1af92bc, 0x2dd623e8fb994f23
	.quad	0x2d7fd87064e02a6f, 0x2dd0f8695160ca38
	.quad	0x2d78652a61cdcd3b, 0x2dca031b186be289
	.quad	0x2d72af84a660968d, 0x2dc3eee8e04dc3a0
	.quad	0x2d6c9f07af149226, 0x2dbe8bd23cc416f0
	.quad	0x2d65eacf76fffc0c, 0x2db766e8d5583265
	.quad	0x2d60c80f3efbbf3f, 0x2db1ed2fab014c43
	.quad	0x2d59b1f8ffd8f3c8, 0x2dab76010ebb6c6a
	.quad	0x2d53ab5d5023fe4a, 0x2da507d813502ab7
	.quad	0x2d4e1c174ea2aaa6, 0x2da01aa61c90eacc
	.quad	0x2d470b05029068da, 0x2d98a90544ab274d
	.quad	0x2d41a1fba21de5f0, 0x2d92e0fb0911dd84
	.quad	0x2d3afb70654af059, 0x2d8ce6f24739f7c7
	.quad	0x2d34a458b53b2a84, 0x2d861eefc532711f
	.quad	0x2d2f944d95c81983, 0x2d80edb77098a960
	.quad	0x2d28272ab43f7156, 0x2d79e82e04d9025f
	.quad	0x2d2278886c5a4d73, 0x2d73d237a2e0f859
	.quad	0x2d1c3f57b512a1f2, 0x2d6e5385c7d0efe0
	.quad	0x2d1598c52c5d1746, 0x2d673258d0b919eb
	.quad	0x2d10828ad1da0983, 0x2d61bdb57d01cecc
	.quad	0x2d093d4935512f54, 0x2d5b223e5e67d24a
	.quad	0x2d034a3670d3cd59, 0x2d54bf43098a2ef1
	.quad	0x2cfd7b67cefff216, 0x2d4fb93db1e39a21
	.quad	0x2cf686e7356020d2, 0x2d48402d3eada60a
	.quad	0x2cf135e695d6d4f8, 0x2d42892e31597360
	.quad	0x2cea4b6028e1ae52, 0x2d3c5502f868f04b
	.quad	0x2ce415808da66669, 0x2d35a670a5d83e0e
	.quad	0x2cdead51e60a821d, 0x2d308ac71830fd4e
	.quad	0x2cd76cfe88ffbfa7, 0x2d29467d9d3bce7d
	.quad	0x2cd1e2e61d740a91, 0x2d234ea92731d6f0
	.quad	0x2ccb4f6c22875415, 0x2d1d7e402cf49a21
	.quad	0x2cc4d8e03e448998, 0x2d16860e96265ba8
	.quad	0x2cbfd2c6816f010b, 0x2d1132f279000564
	.quad	0x2cb8494b75728df1, 0x2d0a4356bd52863e
	.quad	0x2cb28836b62851b4, 0x2d040cac092d16a6
	.quad	0x2cac476ceb4ce0a6, 0x2cfe9bb8c8c45eaa
	.quad	0x2ca592d26553a529, 0x2cf75c6ad9777c96
	.quad	0x2ca074be65f60432, 0x2cf1d3d889242361
	.quad	0x2c991a14719373e5, 0x2ceb34c7bf3e0108
	.quad	0x2c93248b33f78dd9, 0x2ce4c1bf325b5886
	.quad	0x2c8d316bfa6ecf07, 0x2cdfab351a6d7271
	.quad	0x2c8641dc398561ef, 0x2cd827d8b273a859
	.quad	0x2c80f79d08c027e2, 0x2cd26c35a8453a6e
	.quad	0x2c79ddabce45ff88, 0x2ccc18e854f7a653
	.quad	0x2c73b6a0443345f1, 0x2cc56c727238c10e
	.quad	0x2c6e0b830517633f, 0x2cc05545196af9e3
	.quad	0x2c66e4903f595976, 0x2cb8e6b62ae03487
	.quad	0x2c6170eca4e7a4ca, 0x2cb2facf384d3a3b
	.quad	0x2c5a92756c27d93a, 0x2caceddf1e753b81
	.quad	0x2c543d40bf74392d, 0x2ca60b61e0028436
	.quad	0x2c4ed3e286c4c0de, 0x2ca0cbd09b1e5e10
	.quad	0x2c477993389df313, 0x2c9997719e8b73a8
	.quad	0x2c41dfa945eaae99, 0x2c937e77cf85ca37
	.quad	0x2c3b36ec5aa05880, 0x2c8db1e802a6c81f
	.quad	0x2c34b749e64b35f5, 0x2c869d3aa6fccfd9
	.quad	0x2c2f88d823260c9e, 0x2c81383f4dd09079
	.quad	0x2c27ffa0f1fabb65, 0x2c7a388f33976b7b
	.quad	0x2c2242e12375b352, 0x2c73f613589599c6
	.quad	0x2c1bc9a844ffd2b5, 0x2c6e635a66e3ebe7
	.quad	0x2c1523af73f84783, 0x2c6720bfb4a981d7
	.quad	0x2c10146a610e0588, 0x2c6199a49bcc5100
	.quad	0x2c087590d6d36008, 0x2c5ac8ae259e160c
	.quad	0x2c0299b80ea6bb7f, 0x2c54609b0c4183ca
	.quad	0x2bfc496292aa266b, 0x2c4f00af26520f9d
	.quad	0x2bf5817f72c95e4c, 0x2c4794ce31e24c7b
	.quad	0x2bf059392396d038, 0x2c41ef2877dbfcad
	.quad	0x2be8da5a346cbb3f, 0x2c3b468dc95cb829
	.quad	0x2be2e36a9eb80d32, 0x2c34bd213115ac94
	.quad	0x2bdcb4fb203e18a0, 0x2c2f88862b544527
	.quad	0x2bd5cfe5be9615c7, 0x2c27f861b04cbe3a
	.quad	0x2bd0923c6394f695, 0x2c22380a7a548a2f
	.quad	0x2bc92d18166ccd51, 0x2c1bb1122f6e5762
	.quad	0x2bc31f510cb3f507, 0x2c150ad48dd9b3a6
	.quad	0x2bbd0b7c794af438, 0x2c0ff9ab8e5d6631
	.quad	0x2bb60e2f23228ded, 0x2c084a97f6b3e853
	.quad	0x2bb0bef1906dac58, 0x2c0273a4b16ba84f
	.quad	0x2ba96d0ca88e4fc0, 0x2bfc07484e1da469
	.quad	0x2ba34ce1af3c1b60, 0x2bf549037ceef1fe
	.quad	0x2b9d4c1f7c67dd18, 0x2bf0298e0fc06037
	.quad	0x2b963bcc0600e3b1, 0x2be88ab45875f419
	.quad	0x2b90def17046c37e, 0x2be2a16e161fa35f
	.quad	0x2b8999a40ba75f42, 0x2bdc48699c75f345
	.quad	0x2b836bb3093bcf7f, 0x2bd5771e906a9978
	.quad	0x2b7d764e5657aa20, 0x2bd04a04a1699caa
	.quad	0x2b7658528dc53bd5, 0x2bc8b822865b44e6
	.quad	0x2b70f1f1acd583c0, 0x2bc2c0fc98ac934c
	.quad	0x2b69b2768ee2e280, 0x2bbc73df0b6d4334
	.quad	0x2b637b7d60833afb, 0x2bb594bab8ddacb1
	.quad	0x2b5d89a6c43f4c10, 0x2bb05dee05833b3c
	.quad	0x2b5663803afd90e2, 0x2ba8d278c9cbfc58
	.quad	0x2b50f7c5f2e42650, 0x2ba2d206b997c2cc
	.quad	0x2b49b74a41343d69, 0x2b9c89434d36542f
	.quad	0x2b437c1bd3bb9cfe, 0x2b95a192e33cf627
	.quad	0x2b3d85fb90bdf218, 0x2b90651bc0c61b20
	.quad	0x2b365d3aea4b609e, 0x2b88d9799e5f2521
	.quad	0x2b30f0609e7aa674, 0x2b82d464a6b30dc2
	.quad	0x2b29a813d2878f74, 0x2b7c88645e6c88ee
	.quad	0x2b236d8ce9d2217b, 0x2b759d89052b0525
	.quad	0x2b1d6b5543d3c940, 0x2b705f7d07f3fb02
	.quad	0x2b1645913a262a36, 0x2b68cd14a1185c8d
	.quad	0x2b10dbd2f003b6a5, 0x2b62c810d60e767e
	.quad	0x2b0984f6bfe67780, 0x2b5c714448c370a6
	.quad	0x2b034ff297cd534d, 0x2b5588a691f2cd1f
	.quad	0x2afd39f201da2255, 0x2b504d1f01416963
	.quad	0x2af61cba521cabb4, 0x2b48ad66d03eba59
	.quad	0x2af0ba4cc94c45b3, 0x2b42ad281b8cc2a0
	.quad	0x2ae94e44c9a075e7, 0x2b3c44191b160ec2
	.quad	0x2ae32391bcecdc03, 0x2b35631c55b5d22c
	.quad	0x2adcf2449a3fda4b, 0x2b302e2c911c7929
	.quad	0x2ad5e3150cc8eda4, 0x2b287aba1a7120bf
	.quad	0x2ad08c1bf3c985fa, 0x2b2283e938a586f7
	.quad	0x2ac9047cb663bb8c, 0x2b1c014c17012593
	.quad	0x2ac2e8d117dfdd44, 0x2b152d41b7968429
	.quad	0x2abc94f2cb2815a8, 0x2b1002edb3674f27
	.quad	0x2ab599268900e7bc, 0x2b0835843f5f0b0c
	.quad	0x2ab051aaf415041d, 0x2b024cb3e8b7d756
	.quad	0x2aa8a84869fc8267, 0x2afba9781881c8a9
	.quad	0x2aa2a037bab743e1, 0x2af4e79366e7a470
	.quad	0x2a9c22d2c350e306, 0x2aef978cc962d426
	.quad	0x2a953f982a03a248, 0x2ae7de65083f0e21
	.quad	0x2a900b7f70f68972, 0x2ae208076f18ea30
	.quad	0x2a883a7a5a0b9d4d, 0x2adb3d6740403453
	.quad	0x2a824a6b05eb3eda, 0x2ad492b17a8d9ad4
	.quad	0x2a7b9ce7efad864c, 0x2acf126a42ab2a64
	.quad	0x2a74d7351162fad8, 0x2ac77623e1a3ca2f
	.quad	0x2a6f74706d1f613c, 0x2ac1b680aeae0c3c
	.quad	0x2a67bc0a6e57fbc5, 0x2ababe0fed214bca
	.quad	0x2a61e82c35430e3d, 0x2ab42f5d0cb0afeb
	.quad	0x2a5b045f25c98b4b, 0x2aae77a20528f8f5
	.quad	0x2a5460e7202036c7, 0x2aa6fdace394b03c
	.quad	0x2a4ebd15c07c2acd, 0x2aa158d7d54f1681
	.quad	0x2a472e125d540295, 0x2a9a2c9115542385
	.quad	0x2a417a558b9c184f, 0x2a93be755f8b210c
	.quad	0x2a3a5a8a3f3de092, 0x2a8dc88f077bd369
	.quad	0x2a33ddb38ecb5b52, 0x2a86760d57bb9982
	.quad	0x2a2df2826b036578, 0x2a80efdda755dbb3
	.quad	0x2a2691c997f37f0e, 0x2a798a2e123c782e
	.quad	0x2a2101d72c627ff7, 0x2a7340f49a722110
	.quad	0x2a19a0db3d2b8dac, 0x2a6d06b3f65f6fd0
	.quad	0x2a134eb72e63e592, 0x2a65e06fcff790f4
	.quad	0x2a0d166c8f34fca4, 0x2a607c787991a680
	.quad	0x2a05e880d9f1fe43, 0x2a58d849f54265f7
	.quad	0x2a007fb3b2ff1602, 0x2a52b7ec30262d2b
	.quad	0x29f8d8df0cbffd52, 0x2a4c33b5a8ad639f
	.quad	0x29f2b52265317648, 0x2a453e17e1a8afad
	.quad	0x29ec2aa6bd34f17b, 0x2a3fff41d2913dab
	.quad	0x29e5339d751ff2a1, 0x2a3818627da2e9e4
	.quad	0x29dfe9f93308c405, 0x2a32248100f21115
	.quad	0x29d80438073219de, 0x2a2b515531d535eb
	.quad	0x29d21234fbc4a127, 0x2a24905d9b84e0cb
	.quad	0x29cb31198aa5f8ab, 0x2a1ef4bcc5f71a72
	.quad	0x29c474946f304456, 0x2a174c0ac8d03b2b
	.quad	0x29bec59d00f3fe38, 0x2a1187e74c209a91
	.quad	0x29b7249848679fa9, 0x2a0a6169b09c4411
	.quad	0x29b16739cec78bd4, 0x2a03d8a8ccb26cd9
	.quad	0x29aa2bbd0795adee, 0x29fddb87127c2076
	.quad	0x29a3ace589cd3352, 0x29f674e5d7be735c
	.quad	0x299d949ad392f075, 0x29f0e35e84d33d3f
	.quad	0x29963bbbf78651cc, 0x29e965d9f895d99c
	.quad	0x2990b5827a3ba382, 0x29e3186c34406960
	.quad	0x29891c922f9ee4c0, 0x29dcb5d51a48d7d4
	.quad	0x2982de164c74e725, 0x29d594a1039f0199
	.quad	0x297c5941f108d9d1, 0x29d0382d1e479246
	.quad	0x29754b639c219649, 0x29c8609634a384cc
	.quad	0x296ffcc62473097a, 0x29c25120afe02122
	.quad	0x2968059c757355ae, 0x29bb85e31314f4b4
	.quad	0x296209ad26ca18d9, 0x29b4acee7c0fcbaf
	.quad	0x295b15e18d0d2d12, 0x29af0f38c6449ad9
	.quad	0x2954554e9983b016, 0x29a753919ff4b182
	.quad	0x294e865bf893f8f4, 0x29a1844080030d76
	.quad	0x2946e8db855aac9a, 0x299a4dede3a3eb93
	.quad	0x2941312cc0ae5d04, 0x2993bf7fe7aa33a0
	.quad	0x2939ccc1bfbf7ecb, 0x298da5e8d4d639ed
	.quad	0x29335b35e7d0088e, 0x298640bc7176cda7
	.quad	0x292d0a5ff60b92cf, 0x2980b342b640cc13
	.quad	0x2925c84558f35d95, 0x2979102c47629cb9
	.quad	0x2920560f8bafb2c7, 0x2972ce013e375d0f
	.quad	0x2918801ce509ea26, 0x296c36f07720a932
	.quad	0x29125ec7207b3c64, 0x296529fe13854ed9
	.quad	0x290b8b58f7c67c36, 0x295fbf2dc269c35d
	.quad	0x2904a5c0b3b7424d, 0x2957cec854a40ddc
	.quad	0x28fef3874e46141b, 0x2951da13f1aaaee6
	.quad	0x28f732197e24d857, 0x294ac4c46230c45c
	.quad	0x28f1619ff0ea7ec6, 0x2944112fbeff8a1f
	.quad	0x28ea0bb46a0a2c53, 0x293e15420dda8758
	.quad	0x28e383201c8ba71a, 0x29368bd97eb5b05d
	.quad	0x28dd3b4e4b894768, 0x2930e54a78756b6b
	.quad	0x28d5e4c4aaef0130, 0x292951c14f527745
	.quad	0x28d0654a030d3e70, 0x2922f8178dd14a04
	.quad	0x28c88dc03d1ca801, 0x291c6b6bf9361ee4
	.quad	0x28c2621d65152a67, 0x2915495f2949c65e
	.quad	0x28bb860981f4834a, 0x290fe24891c8ca0c
	.quad	0x28b49a0d4c97c281, 0x2907e02609a87253
	.quad	0x28aed66ed1143993, 0x2901e064158c947b
	.quad	0x28a713a5a10cc9b0, 0x28fac4304f253262
	.quad	0x28a14455cbbff469, 0x28f4093bdea6e36f
	.quad	0x2899d62205df47a6, 0x28edfe14a435c3c2
	.quad	0x289353bfdeb15aa4, 0x28e6720e3d624fdc
	.quad	0x288ce97f23783a55, 0x28e0cba8970a9d66
	.quad	0x28859f649793ea9a, 0x28d921e961b81171
	.quad	0x28802b46c188f22d, 0x28d2cd3135c626d1
	.quad	0x28782dcfdba2d59c, 0x28cc2097f7f7c953
	.quad	0x287213830f44d648, 0x28c5096e15b063db
	.quad	0x286b0639acae41c7, 0x28bf76b39886a20d
	.quad	0x286432d063e4cc5a, 0x28b786c2636e4e2a
	.quad	0x285e3096b161ade1, 0x28b196dc712e8651
	.quad	0x28568f1646f450cc, 0x28aa4c39680abb0b
	.quad	0x2850dad51a121c5f, 0x28a3a80eb1934625
	.quad	0x28492ed52465cf13, 0x289d6196b3830612
	.quad	0x2842cf8cdb32b26d, 0x2895f4b3b930a91a
	.quad	0x283c1934bb7035c1, 0x289067b3db09279e
	.quad	0x2834fbc11c19c0b7, 0x2888832413bcb6f5
	.quad	0x282f5613cdc1ad52, 0x28824f8b72bbd6ee
	.quad	0x28276547ab0f816a, 0x287b5a5bcacf14dd
	.quad	0x2821770c93ef3136, 0x28746d8046ba690c
	.quad	0x281a128a30d837eb, 0x286e8209bd7c6d4d
	.quad	0x281375630e92b790, 0x2866c744b66f6406
	.quad	0x280d0a93cd8add1e, 0x2861015024fefc8d
	.quad	0x2805ab4549d6cf15, 0x2859631ba1694964
	.quad	0x28002a8fed4a1944, 0x2852f2b3b1ae197d
	.quad	0x27f81e6d5efc2ece, 0x284c47e5b8f9de0c
	.quad	0x27f1fd54f3e20bfc, 0x28451a481761d265
	.quad	0x27ead523512d80ae, 0x283f7d2ff106229c
	.quad	0x27e4023f854f9c86, 0x28377da522f79ec5
	.quad	0x27ddd649c8fad0d5, 0x283185a192bd02b4
	.quad	0x27d63e684c4d4572, 0x282a22ed5ef67f83
	.quad	0x27d094b5ecc6e290, 0x28237d9a85948033
	.quad	0x27c8b7643330549e, 0x281d10da89b8212a
	.quad	0x27c26b65f14cd4da, 0x2815ab7d4224f7e2
	.quad	0x27bb734f53e57228, 0x2810276587fa1c20
	.quad	0x27b473b9d1931175, 0x280814bdb918424d
	.quad	0x27ae78d8c6e84fdd, 0x2801f2684f2af658
	.quad	0x27a6b2a2c93cd65a, 0x27fabf540fb4e1a1
	.quad	0x27a0e7a7b055d281, 0x27f3eddfeeed0dd2
	.quad	0x27992d87cacce695, 0x27edb1c82f79707d
	.quad	0x2792bf57b6e0d98d, 0x27e61ea0b7eb4c3c
	.quad	0x278bea4f9488e121, 0x27e0799f1fb897d8
	.quad	0x2784c7d8bf7bdc41, 0x27d889f21fdb1d69
	.quad	0x277eef6b8bfa9225, 0x27d245c20ba28a39
	.quad	0x277705ed2bbfd521, 0x27cb3598a0d59840
	.quad	0x277121f1b69882eb, 0x27c4418fde75923e
	.quad	0x27697ec608197c79, 0x27be27e05b6c31f9
	.quad	0x2762f7b0edc74f1c, 0x27b671af7f5d8858
	.quad	0x275c380c41f75030, 0x27b0b3d4442eda68
	.quad	0x2754fd20f15083b3, 0x27a8db341e4d4306
	.quad	0x274f37ea8d01e9c5, 0x27a27e37e3bc73c9
	.quad	0x274736cebb19a201, 0x279b83a639f29a80
	.quad	0x2741428c012e2c57, 0x27947730acf38edc
	.quad	0x2739a9ae80c06018, 0x278e710d5155d028
	.quad	0x27331371c2b63b80, 0x2786a331ab64b688
	.quad	0x272c5b240b14f4d6, 0x2780d4fd25f7f52e
	.quad	0x2725129ffd17a136, 0x27790712f4e38e37
	.quad	0x271f510ba62354a5, 0x27729ac951c1e60b
	.quad	0x27174468acd1611c, 0x276ba819d5f14678
	.quad	0x271148e1d96c299e, 0x27648dce2dc3ecd5
	.quad	0x2709ad7d58aaba44, 0x275e8c0193d16d55
	.quad	0x2703121b71d77179, 0x2756b2456938b866
	.quad	0x26fc52f68dd90e64, 0x2750dc826696c76c
	.quad	0x26f507f397188496, 0x27490cc63cdbf2a2
	.quad	0x26ef3a5bdf92c388, 0x27429af3c144f8c0
	.quad	0x26e72e7cbdbb95db, 0x273ba24cc0f4c8e2
	.quad	0x26e134d638b07143, 0x27348500e815d897
	.quad	0x26d98a2111174d79, 0x272e7841c45926d0
	.quad	0x26d2f3b409e1b7b6, 0x27269ea5b1b71301
	.quad	0x26cc1fa91a869695, 0x2720ca4195cda6d3
	.quad	0x26c4dd4c7d7ec9fa, 0x2718ec33daf13649
	.quad	0x26bef442d8796795, 0x27127eb66fea5e85
	.quad	0x26b6f56f0c0f22b9, 0x270b72598c77c448
	.quad	0x26b106c4a594a047, 0x27045cf12a60cb9a
	.quad	0x26a9403b0e4bd1b9, 0x26fe36284e81b5ff
	.quad	0x26a2b8c63e7468c1, 0x26f668ac570f2fc8
	.quad	0x269bc22598793379, 0x26f09e8e37ef2488
	.quad	0x2694936d06178106, 0x26e8a5f0c63b5c24
	.quad	0x268e7fffb3b16a7d, 0x26e2469273320bda
	.quad	0x26869a431ed205a0, 0x26db191b44e70edf
	.quad	0x2680bf7e7cce4d07, 0x26d41655d7606103
	.quad	0x2678d11ace4d8996, 0x26cdc6e2b76185d5
	.quad	0x2672625d4b960a47, 0x26c6114f58eab906
	.quad	0x266b3c139841a735, 0x26c05a2f4a403a4d
	.quad	0x26642ba35d81be5c, 0x26b83b3c9af7ee45
	.quad	0x265ddf9fa6fc513a, 0x26b1f386e3013e68
	.quad	0x26561e943a26f542, 0x26aa9826f127d04d
	.quad	0x26506044c28d2704, 0x26a3b26ef9596f74
	.quad	0x26483eb403668f94, 0x269d2c68adc24dd3
	.quad	0x2641f1fd15ed30fe, 0x26959a199b7c8167
	.quad	0x263a8fcbdc7eab51, 0x268ffcb2bfa5b8da
	.quad	0x2633a7bfb4be9962, 0x2687adf828472cfd
	.quad	0x262d15ee90987618, 0x2681870951a86a79
	.quad	0x2625848951944920, 0x2679f1bfa110cbba
	.quad	0x261fd57d7b45b3ca, 0x267332fc55367264
	.quad	0x26178b8ffae32bf0, 0x266c696d39db75f3
	.quad	0x26116996dab0cd1e, 0x2665051f4ea04fdf
	.quad	0x2609c046dcaa75a4, 0x265f194b2a4cb970
	.quad	0x26030a06c462f23e, 0x265700975cbb46aa
	.quad	0x25fc2662350ce7fa, 0x265102fae0ec7794
	.quad	0x25f4cec5169fb931, 0x264928c588cfb6d9
	.quad	0x25eec1db7d8e44b5, 0x26429a3060c44f3a
	.quad	0x25e6babae8929706, 0x263b814aa869e0e4
	.quad	0x25e0cb7ae5506e7e, 0x263454ee7edd0063
	.quad	0x25d8d106f7f4047e, 0x262e0e0b72e6ef2e
	.quad	0x25d255213192c405, 0x2626360f251c2f1f
	.quad	0x25cb1500fc71b69a, 0x2620699a6631f93f
	.quad	0x25c40052c8ba04b4, 0x261840a0d97bb129
	.quad	0x25bd8a3d24511c07, 0x2611eaa023d58a69
	.quad	0x25b5cfadd7b97160, 0x260a77ea01d8b821
	.quad	0x25b01a47ddad3ea8, 0x26038c7c7057a652
	.quad	0x25a7c5ff3799c35b, 0x25fcdf6c504a93e5
	.quad	0x25a18c087e86a1f3, 0x25f551bff88c1175
	.quad	0x2599e64530b957f4, 0x25ef7ae8590bb800
	.quad	0x25931c908986e1a8, 0x25e73d293026bc2a
	.quad	0x258c33b25da2082e, 0x25e12730a9790f69
	.quad	0x2584ce362055227e, 0x25d951a7082f394a
	.quad	0x257eb1b0ae0a386a, 0x25d2af1081b22794
	.quad	0x2576a3779e1ff3b0, 0x25cb925bc48353e0
	.quad	0x2570b1f245435eea, 0x25c4575deb5305a2
	.quad	0x25689efddb97fd18, 0x25be029ff0fc8645
	.quad	0x256227180cb0a8ca, 0x25b6228a92a17423
	.quad	0x255ac39e8a7de062, 0x25b05302bb5e3a1a
	.quad	0x2553ba5b5279aa24, 0x25a81331d3a2cc81
	.quad	0x254d145ea8ff6403, 0x25a1c02d69097c72
	.quad	0x25456df011e743b9, 0x259a2c1b0ae83a64
	.quad	0x253f94750d0f9308, 0x25934ad734ae6135
	.quad	0x2537442e7172840a, 0x258c703bfdc748cd
	.quad	0x253123a683e9b9d5, 0x2584f5290291de6e
	.quad	0x25293f94a8e393e5, 0x257ee2bb5a2a4470
	.quad	0x252298449094a080, 0x2576c16f34d9525e
	.quad	0x251b62c8f87855a8, 0x2570c379a70923bc
	.quad	0x25142a02f59d51ef, 0x2568b21b8919710f
	.quad	0x250db09bb0ffb21f, 0x2562303a1b68b2de
	.quad	0x2505daee76f997a8, 0x255ac9c706a79cfc
	.quad	0x25001604a662bf4c, 0x2553b983b3f72fb5
	.quad	0x24f7ad33d50dacd0, 0x254d0b33fd9b6e85
	.quad	0x24f16c1e4c8c451a, 0x2545615904c6373a
	.quad	0x24e9a32159dea0d8, 0x253f7950165d693d
	.quad	0x24e2dc48781056c9, 0x253729dc070c926a
	.quad	0x24dbbf2871addffb, 0x25310b9b38c6e833
	.quad	0x24d4684a4152d4e0, 0x2529154f9f73ee5f
	.quad	0x24ce03df4eb2c204, 0x25227418ebfd96be
	.quad	0x24c6120558a89b12, 0x251b26192fa2f36e
	.quad	0x24c03a014bcb5352, 0x2513f7df7d25b3e6
	.quad	0x24b7db773a6f6623, 0x250d5ec232ba3385
	.quad	0x24b1893b9023690d, 0x250598c75ff21ea4
	.quad	0x24a9c6ba6a49465a, 0x24ffc1f9e46a53e2
	.quad	0x24a2f125d64e7642, 0x24f758c452444076
	.quad	0x249bd607b51aff83, 0x24f1294b791c6529
	.quad	0x2494735d5e25dd32, 0x24e939e692035be7
	.quad	0x248e0bb7795ebab2, 0x24e289cc9b3b4107
	.quad	0x248611962fb4b008, 0x24db3e5c199dc217
	.quad	0x248035217aa6e0ad, 0x24d40415be2c6028
	.quad	0x2477cd9c096da3b3, 0x24cd6871e2c76342
	.quad	0x24717a22cd2a508f, 0x24c599d2a64857ab
	.quad	0x2469a95351e8c9f1, 0x24bfba952efabe51
	.quad	0x2462d63f329a8bcb, 0x24b74cc660d4897a
	.quad	0x245ba6ba0cb47e2b, 0x24b11baa6a990cd8
	.quad	0x24544ae89d144108, 0x24a91ecc31adec4e
	.quad	0x244dc7e8d1b8f556, 0x24a270b14a1f9816
	.quad	0x2445d9a42222275c, 0x249b11d883fd3ec1
	.quad	0x24400789e350bd1a, 0x2493ddca348b8e79
	.quad	0x2437840aaba80c98, 0x248d27f9dd765764
	.quad	0x24313f45ccd8c935, 0x24856472f42babf3
	.quad	0x24294bc9a9955f26, 0x247f6359d3980ea5
	.quad	0x24228c5f3eaf8edd, 0x2477063ccd1b83c6
	.quad	0x241b32a3c3e46a35, 0x2470e31f012ad2b3
	.quad	0x2413f01c91fe7f47, 0x2468c4cd2c02ec2d
	.quad	0x240d3a718c61d154, 0x2462298481c2ca0d
	.quad	0x24056bd3dd5a05c1, 0x245aa1de55237abc
	.quad	0x23ff65222fadfc00, 0x2453861db33230b0
	.quad	0x23f700eb717cfb77, 0x244c9f401331dbf6
	.quad	0x23f0da5e12700c8d, 0x2444fa3a533642f6
	.quad	0x23e8b0da54d3c71f, 0x243ebed8656f1a7b
	.quad	0x23e215aeed941b43, 0x2436873a105b43c2
	.quad	0x23da7d28bd609e50, 0x2430815216360470
	.quad	0x23d3659f3261d190, 0x24282e8d038330ca
	.quad	0x23cc6770887b13f6, 0x2421b65bea6b7e6a
	.quad	0x23c4cb570f463d9d, 0x2419f1b427ce89a2
	.quad	0x23be715dafe5cd60, 0x2412ff9fffd4f5f9
	.quad	0x23b6480ba9b1723c, 0x240bd241d06b6757
	.quad	0x23b04e575dd6f2eb, 0x24045e411382662b
	.quad	0x23a7dcff6d521467, 0x23fdd1da1bc7ec85
	.quad	0x23a1759a98201ff3, 0x23f5d36e9f7af39c
	.quad	0x23998b82586ccf2d, 0x23eff233639de02a
	.quad	0x2392af6afc0ce651, 0x23e7606528b3cf28
	.quad	0x238b54f244df93df, 0x23e11a8b54a30c34
	.quad	0x2383fcc4e4385b18, 0x23d9066e8a3084ad
	.quad	0x237d3abb2d5b9282, 0x23d24e2ffedd9f78
	.quad	0x23755eaec016b2b5, 0x23cac6e23cde6ac9
	.quad	0x236f3e576e5bfb2c, 0x23c394ff72563c26
	.quad	0x2366d6394041cb01, 0x23bca3259bb8013e
	.quad	0x2360b0a8012d71fb, 0x23b4effb58fcce20
	.quad	0x2358647f7f3a91de, 0x23ae9cac23b8427e
	.quad	0x2351d29e5c60946b, 0x23a6602f707600f3
	.quad	0x234a0aa72640fd47, 0x23a05a7bd790a4bc
	.quad	0x234305e23384e58a, 0x2397e6b1b23c38f4
	.quad	0x233bc9e08de1532f, 0x239176cc55ca9b80
	.quad	0x23344b4e89c6a35f, 0x238984a277e8539a
	.quad	0x232da366d9d2b975, 0x2382a417253e014b
	.quad	0x2325a3c60cb2c6b1, 0x237b3b2c9b4277c6
	.quad	0x231f98800fc076db, 0x2373e333559670c8
	.quad	0x23171033226bf0af, 0x236d0b8591b88278
	.quad	0x2310d53e944a7e18, 0x236534ff7f271b4d
	.quad	0x23089187f3d75a14, 0x235ef6ed82d51675
	.quad	0x2301ed5d0deddfb7, 0x23569a61d0edc9d2
	.quad	0x22fa28be72757b85, 0x23507f57aca805f1
	.quad	0x22f3154ef266983d, 0x234814481a9f253c
	.quad	0x22ebd6d859990532, 0x2341921067277b5d
	.quad	0x22e44dcd404b4fcd, 0x2339a3a7d2712f82
	.quad	0x22dd9cdf2aadd6a6, 0x2332b45137355f77
	.quad	0x22d5979672b76b96, 0x232b497e1657b91b
	.quad	0x22cf7be424410479, 0x2323e6cfcc06ed27
	.quad	0x22c6f36e7903ba4f, 0x231d06cfa865bc4e
	.quad	0x22c0ba8019bd4e86, 0x23152a47395ed2ae
	.quad	0x22b8621eaa755f34, 0x230edca8e605e67a
	.quad	0x22b1c4a9efdce654, 0x23067f77ef705254
	.quad	0x22a9e475b5aaea97, 0x2300660edcde1e02
	.quad	0x22a2dd03980220ac, 0x22f7e727aec99554
	.quad	0x229b7b478b8fda1c, 0x22f16b24c391593b
	.quad	0x22940424c4fd21f7, 0x22e96221780dfe95
	.quad	0x228d276d459f43c7, 0x22e27e2788696d86
	.quad	0x22853aa8c500f5d0, 0x22daf1357749947c
	.quad	0x227ee9c5073f397e, 0x22d39fac2bf7a531
	.quad	0x2276812e6a2e8fc0, 0x22cc9538eaa71fb0
	.quad	0x22706198ecffc0e0, 0x22c4d04b3a802aee
	.quad	0x2267d857ef6fe55a, 0x22be4f0604536408
	.quad	0x22615a4dc243cc5f, 0x22b610a0b4ec8401
	.quad	0x225940cad97ee071, 0x22b00fbde3ac71c6
	.quad	0x22525f772e00c70a, 0x22a7614bf61d6bfa
	.quad	0x224abb2fd3f529ef, 0x22a103beefa07650
	.quad	0x2243718d87e8a0af, 0x2298c2ef94786008
	.quad	0x223c48328a4346eb, 0x229203fa39242793
	.quad	0x2234910b37b4de72, 0x228a36313f8e64ec
	.quad	0x222de8817c6f33b9, 0x228310e5f6fbfd44
	.quad	0x2225be6c950a7e6f, 0x227bbbb999bb060a
	.quad	0x221f9ccdcf7c94fe, 0x22742afa66f9fdc1
	.quad	0x2216fa2fc442a9d3, 0x226d54340d9c375d
	.quad	0x2210b2e58cb15f5c, 0x226552b1ae6aeaa2
	.quad	0x220844d490056942, 0x225f004e9f45a94b
	.quad	0x2201a217943b9ac7, 0x22568887b7750462
	.quad	0x21f99edc3fa555f4, 0x2250605cdc8a1e5e
	.quad	0x21f29c58e31af831, 0x2247ccfa0b55e3f7
	.quad	0x21eb08c96a2d341c, 0x22414b13fa04509f
	.quad	0x21e3a2063aa9bfc9, 0x22392087a96ea8f4
	.quad	0x21dc831fc61280f7, 0x223240a6edc95f53
	.quad	0x21d4b37d15842e1d, 0x222a83b0db0fa5b6
	.quad	0x21ce0e63f582488b, 0x22234170d65d2fe5
	.quad	0x21c5d11b81c3fea7, 0x221bf6f703f6c8b1
	.quad	0x21bfab1b4f400c2e, 0x22144dcd884a52dc
	.quad	0x21b6fb3ff8ccf41c, 0x220d7adc6f76430f
	.quad	0x21b0ace5d20891a2, 0x2205661968fc8c68
	.quad	0x21a8324934a763f4, 0x21ff0fe41a3b588b
	.quad	0x21a18d7d8058e531, 0x21f68ab147365bff
	.quad	0x2199769602e7d2c4, 0x21f05b48bc57ed71
	.quad	0x21927797b62a04a4, 0x21e7bbf2311e9661
	.quad	0x218ac8851524d431, 0x21e137b41cf9c9a4
	.quad	0x21836b7751d5da7f, 0x21d8fa3947e525d9
	.quad	0x217c2874cefea298, 0x21d21d7603b6e2cc
	.quad	0x2174695ee8470b66, 0x21ca45e3910021ac
	.quad	0x216d96c311be3eb3, 0x21c30cd0207d04ed
	.quad	0x216571909f179506, 0x21bb9f4dc504a668
	.quad	0x215f13cd05945d89, 0x21b40603dadb780a
	.quad	0x2156844e0504f766, 0x21ad06d41c212c13
	.quad	0x21504ff770417c7e, 0x21a509522cc01f2f
	.quad	0x2147a1d7e8c27e50, 0x219e7cd2184183eb
	.quad	0x21411dc1d57f7df8, 0x219616fb7b910c11
	.quad	0x2138ca6e2e342651, 0x219000d1267395e3
	.quad	0x2131f372812d1e14, 0x21872f3f6faafe57
	.quad	0x2129fe4fa21e8c98, 0x2180cacf12619fe1
	.quad	0x2122d1356c845fd1, 0x2178525cca4f244d
	.quad	0x211b3db9cc5a58f3, 0x21719c8ed29100e2
	.quad	0x2113b7359a6b9391, 0x216980913a0c5f1e
	.quad	0x210c88e8c09b9bb2, 0x2162763b979d57b5
	.quad	0x2104a59cf5958098, 0x215aba192db244fd
	.quad	0x20fde016eddfacad, 0x215357ff9fbc97f4
	.quad	0x20f59c942db45eae, 0x214bff2fa5de1e9d
	.quad	0x20ef437cec9632b8, 0x21444204156d00fc
	.quad	0x20e69c4293cefa3f, 0x213d500e0534289d
	.quad	0x20e059a8a5ce0ce7, 0x21353470ed39dd97
	.quad	0x20d7a4cdf5c8de47, 0x212eacebdf5973c2
	.quad	0x20d117e42e10afc5, 0x21262f6cc2a62dbd
	.quad	0x20c8b65a792fe140, 0x21200aff63626acf
	.quad	0x20c1dc89fe4a5f8a, 0x2117331cb44dd6ec
	.quad	0x20b9d10a7562f377, 0x2110c5bd0cbfba30
	.quad	0x20b2a7b1b1593291, 0x21083fa43f4f73d5
	.quad	0x20aaf4fe4d278bf9, 0x210186c76677c8f7
	.quad	0x20a37971726a776e, 0x20f955251a12574c
	.quad	0x209c225447c48b85, 0x20f24e359c6528bb
	.quad	0x209451dde15504ec, 0x20ea73bf0e7dcf7b
	.quad	0x208d592869bae136, 0x20e31c1d70a5a26c
	.quad	0x20853109f6b70a02, 0x20db9b8fd3b82ace
	.quad	0x207e99944d35a898, 0x20d3f09320694d40
	.quad	0x20761706e7ea0b42, 0x20ccccb2e7856e93
	.quad	0x206fe3aefa4cdaa2, 0x20c4cba948866255
	.quad	0x206703e40ae0b133, 0x20be0741675f15a5
	.quad	0x20609bc65f9b8064, 0x20b5ad70c9e433d4
	.quad	0x2057f7aeba02f7ef, 0x20af4b51e95f89d5
	.quad	0x20514a9f8443d058, 0x20a695f8add0a062
	.quad	0x2048f272381e3222, 0x20a04c7c2a8ead79
	.quad	0x2041fe6a1ccca721, 0x2097854e0a5444cf
	.quad	0x2039f437947f2743, 0x2090f822de49bc54
	.quad	0x2032b72bc2a1bb29, 0x20887b7be69a8c26
	.quad	0x202afd058f4d5cb9, 0x2081a8a41a9a7340
	.quad	0x202374e8637e822f, 0x2079788b1f83908e
	.quad	0x201c0ce07e3f5247, 0x20725e0558a5c077
	.quad	0x201437a22e46ffc9, 0x206a7c824c7683f1
	.quad	0x200d23ca31c0220c, 0x2063184a6ce13b46
	.quad	0x2004ff5980398e02, 0x205b8765a48c0cf1
	.quad	0x1ffe41c1da9f8a5f, 0x2053d775743f06ae
	.quad	0x1ff5cc0cd28b81e5, 0x204c9936e428a9d9
	.quad	0x1fef66c3f065ea05, 0x20449b86c1b194ce
	.quad	0x1fe69db8a882e290, 0x203db1f5331fbe71
	.quad	0x1fe049650c331274, 0x2035647ccc18e717
	.quad	0x1fd774577e1faf4f, 0x202ed19d0b78718c
	.quad	0x1fd0e2e586d3df5c, 0x202632541cab3ac0
	.quad	0x1fc84fe1b767669b, 0x201ff82820edeaab
	.quad	0x1fc17fdd44e1dc6c, 0x201705073deb552a
	.quad	0x1fb9304d9065a4b9, 0x201092c6a4a26abf
	.quad	0x1fb220449767742a, 0x2007dc8eab3ed87a
	.quad	0x1faa158f0df4c356, 0x20012ce032c827ce
	.quad	0x1fa2c4123936432b, 0x1ff8b8e0c1372c25
	.quad	0x1f9aff97ef6163ed, 0x1ff1ca5926404568
	.quad	0x1f936b3b4511d82b, 0x1fe999f1ae9f978b
	.quad	0x1f8bee57a0fbbbdc, 0x1fe26b285aeabdbe
	.quad	0x1f8415b32c89327c, 0x1fda7fb366632c72
	.quad	0x1f7ce1bb2fa9523e, 0x1fd30f431387ee69
	.quad	0x1f74c36baf8c2285, 0x1fcb6a15925d0c25
	.quad	0x1f6dd9ad3d89a4a5, 0x1fc3b69cf0bd5608
	.quad	0x1f657454d4c97f21, 0x1fbc590587256b75
	.quad	0x1f5ed615f7bfd7d2, 0x1fb46127e8d37ba7
	.quad	0x1f56285ce2e2e29b, 0x1fad4c6e38ed7f06
	.quad	0x1f4fd6db0d73348e, 0x1fa50ed44039bd53
	.quad	0x1f46df705a8252f7, 0x1f9e4438317c2a1e
	.quad	0x1f406defd40bdb09, 0x1f95bf9082dc8412
	.quad	0x1f379979f15ddb0d, 0x1f8f4049875ce630
	.quad	0x1f30f2823287afb6, 0x1f8673497e5a0d03
	.quad	0x1f2856628e34ac2c, 0x1f802042eb28efef
	.quad	0x1f217913a85a33a7, 0x1f7729ea3d219a53
	.quad	0x1f19161145d0e326, 0x1f70a2671c8cdbee
	.quad	0x1f120191f16dc709, 0x1f67e35c0288722e
	.quad	0x1f09d86b59187f4e, 0x1f612680a24c58f5
	.quad	0x1f028be97e6e9065, 0x1f589f8647df9662
	.quad	0x1efa9d5434377e7b, 0x1f51ac7d823a316c
	.quad	0x1ef31805749922c3, 0x1f495e4eba9494ca
	.quad	0x1eeb64ad6eec66d3, 0x1f42344a7c981006
	.quad	0x1ee3a5cfae5998ec, 0x1f3a1f993b67371d
	.quad	0x1edc2e56cdffce02, 0x1f32bdd30bebc795
	.quad	0x1ed43530bcc0ee3a, 0x1f2ae347debd3070
	.quad	0x1eccfa2e45eea63d, 0x1f23490165a1de50
	.quad	0x1ec4c60fe9d5cbc1, 0x1f1ba93aee1c301f
	.quad	0x1ebdc80ffece4451, 0x1f13d5be7b8309a9
	.quad	0x1eb558533bc564e3, 0x1f0c7150ead1fd0e
	.quad	0x1eae97d659702f92, 0x1f0463f1fe01b7da
	.quad	0x1ea5ebdf78f85a03, 0x1efd3b6691d169e3
	.quad	0x1e9f6959f5cadd73, 0x1ef4f3825f642b00
	.quad	0x1e9680982d0eea8a, 0x1eee0756e0ca137b
	.quad	0x1e901e38dd55bfc7, 0x1ee58454d7cf0720
	.quad	0x1e87165faec70a10, 0x1eded4fb1c7fef16
	.quad	0x1e8088796f5a0260, 0x1ed6164d6a338985
	.quad	0x1e77ad1726ce2f3c, 0x1ecfa42ad866b600
	.quad	0x1e70f3587953aeb5, 0x1ec6a94eea23ecd2
	.quad	0x1e68449e977fef01, 0x1ec03a5dffc21d0d
	.quad	0x1e615ebef6827c9d, 0x1eb73d3b028fc2cf
	.quad	0x1e58dcd4e591ac76, 0x1eb0a3416f4dd0f1
	.quad	0x1e51ca951b79a938, 0x1ea7d1f23d694b62
	.quad	0x1e497597e1aad586, 0x1ea10ca917d13a59
	.quad	0x1e4236c25d3c18a2, 0x1e9867540c340902
	.quad	0x1e3a0ec452e85047, 0x1e91767d933fa0f7
	.quad	0x1e32a32d78fe110f, 0x1e88fd3ed17c059f
	.quad	0x1e2aa8360248e3ed, 0x1e81e0a6bf884441
	.quad	0x1e230fbc7c8ab284, 0x1e79938feb3469d1
	.quad	0x1e1b41c7c6ff8cc6, 0x1e724b0bc63cac6b
	.quad	0x1e137c54cf4ab1fc, 0x1e6a2a23bdfb3241
	.quad	0x1e0bdb5393a7ccd2, 0x1e62b59324d7fd9b
	.quad	0x1e03e8db3be9418c, 0x1e5ac0d5c13ef72a
	.quad	0x1dfc74b284572b4c, 0x1e532022b5a4d882
	.quad	0x1df45533fa93710c, 0x1e4b57808c42df0b
	.quad	0x1ded0dbced86364c, 0x1e438a9fb93eb860
	.quad	0x1de4c142bbcdb51b, 0x1e3bedfde3fbf9f1
	.quad	0x1ddda64a6bca7ad0, 0x1e33f4eee0ab230d
	.quad	0x1dd52ceab3daa53b, 0x1e2c8426c9c266d4
	.quad	0x1dce3e31f45a0a96, 0x1e245ef458066425
	.quad	0x1dc5980ea6ad6692, 0x1e1d19d38acfc932
	.quad	0x1dbed549e6504cf2, 0x1e14c893d1bef1fe
	.quad	0x1db60290f4619f98, 0x1e0daedbd083bb8e
	.quad	0x1daf6b681cab013b, 0x1e0531b0925a021e
	.quad	0x1da66c53a6323b06, 0x1dfe4316b16614af
	.quad	0x1da00031007ac3e3, 0x1df59a2d7cbb3c39
	.quad	0x1d96d5387be7adf6, 0x1deed65ac2de0264
	.quad	0x1d904a064f4bdd38, 0x1de601ed1ee8e719
	.quad	0x1d873d20f9b5e73b, 0x1ddf687e2b942e41
	.quad	0x1d80931e5b5e6c43, 0x1dd668d1bf455ad8
	.quad	0x1d77a3ee7681856f, 0x1dcff956b675583b
	.quad	0x1d70db636a632668, 0x1dc6cebd6a35f863
	.quad	0x1d6809822a836e1f, 0x1dc0445cf3250898
	.quad	0x1d6122bfb19eafe7, 0x1db73392002f5fc2
	.quad	0x1d586dbd3e416493, 0x1db08b3e84ebc2b9
	.quad	0x1d51691d609b1ec9, 0x1da79731441e1e21
	.quad	0x1d48d080d9d1c96d, 0x1da0d13aa83e4b01
	.quad	0x1d41ae66ac0b0b6a, 0x1d97f97cea22928b
	.quad	0x1d3931ae34603f62, 0x1d91163bef9eebc1
	.quad	0x1d31f285d8d6c817, 0x1d885a56a6965552
	.quad	0x1d299126a3e88ca5, 0x1d815a2cf3193875
	.quad	0x1d223565474c154e, 0x1d78b9a03d510324
	.quad	0x1d19eecbad1cb519, 0x1d719cf85b21a11f
	.quad	0x1d1276ef7e686add, 0x1d69173b9121e9f7
	.quad	0x1d0a4a7f136af77e, 0x1d61de88eb969b39
	.quad	0x1d02b70f3735b79f, 0x1d59730ab373bc61
	.quad	0x1cfaa422e918100d, 0x1d521ec98edb9593
	.quad	0x1cf2f5af68314ac2, 0x1d49cceff40f1fb1
	.quad	0x1ceafb999f61e5d4, 0x1d425da56105b758
	.quad	0x1ce332bb50b471fb, 0x1d3a24cdf0f0a2e7
	.quad	0x1cdb50c6169e961b, 0x1d329b07bb123c75
	.quad	0x1cd36e1e845638bb, 0x1d2a7a87a6267113
	.quad	0x1ccba38bae4baa67, 0x1d22d6dc3e1e1b47
	.quad	0x1cc3a7c4f63d9d53, 0x1d1ace007da9e0c8
	.quad	0x1cbbf3ce55012ad1, 0x1d13110ede9680ce
	.quad	0x1cb3df9b045b81fc, 0x1d0b1f1c5f28dcc9
	.quad	0x1cac4172983c2f7e, 0x1d03498bef599a58
	.quad	0x1ca4158d828399ae, 0x1cfb6dbfbfb30836
	.quad	0x1c9c8c5db3f49157, 0x1cf380402cbf1542
	.quad	0x1c944989c55b9312, 0x1cebb9cfb13e7262
	.quad	0x1c8cd475a1f163ee, 0x1ce3b518c77fb7d2
	.quad	0x1c847b7dad17cf31, 0x1cdc0331f1f7ac71
	.quad	0x1c7d19a128cff8a4, 0x1cd3e8036f737914
	.quad	0x1c74ab57affd05a9, 0x1ccc49ccfb511d2c
	.quad	0x1c6d5bc7eab14dfb, 0x1cc418ee5e1d890e
	.quad	0x1c64d906e49e5535, 0x1cbc8d8810c585d4
	.quad	0x1c5d9ad27381fd3d, 0x1cb447c860fdcf2c
	.quad	0x1c55047b0bcf6527, 0x1cacce4b4e41cdca
	.quad	0x1c4dd6aa46d0f45c, 0x1ca47480e39f8181
	.quad	0x1c452da49a426b16, 0x1c9d0bffb62a59f5
	.quad	0x1c3e0f39ed2991f9, 0x1c949f07f95c9d66
	.quad	0x1c355474c1ca1f2b, 0x1c8d468f3ef07049
	.quad	0x1c2e446d00e60d84, 0x1c84c74e66ce3841
	.quad	0x1c2578dd7a37e92b, 0x1c7d7de4e02c6f6f
	.quad	0x1c1e76303a6f7572, 0x1c74ed45aae1d60c
	.quad	0x1c159ad189ced845, 0x1c6db1ec9f31f5e1
	.quad	0x1c0ea4717be0f8c8, 0x1c6510e0078c325e
	.quad	0x1c05ba448d444792, 0x1c5de2939b1372f7
	.quad	0x1bfecf1fdc04a7db, 0x1c5532108a122ff3
	.quad	0x1bf5d72aff4768da, 0x1c4e0fc8180b06b8
	.quad	0x1beef62bb0a0594a, 0x1c4550cb12e0f1db
	.quad	0x1be5f17a3f894e1d, 0x1c3e39798a3f0a89
	.quad	0x1bdf19869809eb8a, 0x1c356d045cee7811
	.quad	0x1bd60928993f7077, 0x1c2e5f989fd91cad
	.quad	0x1bcf392381fab056, 0x1c2586b2049c7737
	.quad	0x1bc61e2d491b1f68, 0x1c1e82174a67122f
	.quad	0x1bbf54f6b79a6d5f, 0x1c159dca8e17880f
	.quad	0x1bb6308082b0b65c, 0x1c0ea0e8c77dc629
	.quad	0x1baf6cf5e2bb03dc, 0x1c05b2456b2d3672
	.quad	0x1ba6401b7549eebb, 0x1bfebc01a8965943
	.quad	0x1b9f8118143e7eb0, 0x1bf5c41b0093e8e9
	.quad	0x1b964cf8501f223b, 0x1beed357da1f18ba
	.quad	0x1b8f9155c9a1fbd1, 0x1be5d344aaa010f1
	.quad	0x1b86571245f3d39a, 0x1bdee6e2a9b9efd0
	.quad	0x1b7f9da8f1a8a0cc, 0x1bd5dfbcc1628fd2
	.quad	0x1b765e6590135a00, 0x1bcef69acba2f951
	.quad	0x1b6fa60cf0228aad, 0x1bc5e97e9c2cbc7f
	.quad	0x1b6662ef70ab154b, 0x1bbf027a5f3a7f56
	.quad	0x1b5faa7ea0cc6ecb, 0x1bb5f0869476fb64
	.quad	0x1b5664ae34801e0e, 0x1baf0a7cf2ae7563
	.quad	0x1b4faafc59456a8c, 0x1ba5f4d2082760f5
	.quad	0x1b4663a133fef350, 0x1b9f0e9f85c03b41
	.quad	0x1b3fa785ea194bf2, 0x1b95f65f5b366281
	.quad	0x1b365fc8d3a43882, 0x1b8f0ee08ba43cd5
	.quad	0x1b2fa01c9ede6a16, 0x1b85f52df8b025d3
	.quad	0x1b26592683be2829, 0x1b7f0b3febf9cbcd
	.quad	0x1b1f94c33d66f35b, 0x1b75f13e53118eaa
	.quad	0x1b164fbcbf86f1ab, 0x1b6f03bf02da5a7a
	.quad	0x1b0f857e040665a0, 0x1b65ea91e400b8af
	.quad	0x1b06438f0b98cab0, 0x1b5ef860a0000a7a
	.quad	0x1aff7252a6ecb2bb, 0x1b55e12b2b611c72
	.quad	0x1af634a1f3bd0d7e, 0x1b4ee92905044d53
	.quad	0x1aef5b484c995f72, 0x1b45d50dadc42d9d
	.quad	0x1ae622fb08184d56, 0x1b3ed61de2b81fc4
	.quad	0x1adf40678969b4f4, 0x1b35c63df237cf4d
	.quad	0x1ad60ea0d9b5d711, 0x1b2ebf4655983167
	.quad	0x1acf21ba5a45e2af, 0x1b25b4c17f7488b1
	.quad	0x1ac5f79af6759efd, 0x1b1ea4aae160108a
	.quad	0x1abeff4c1e71b057, 0x1b15a09ed86def16
	.quad	0x1ab5ddf1e460242c, 0x1b0e86556bc034fe
	.quad	0x1aaed92990861c73, 0x1b0589dd784842f0
	.quad	0x1aa5c1af1c6454be, 0x1afe6451363b8311
	.quad	0x1a9eaf60be99fa59, 0x1af57085cdb6c23e
	.quad	0x1a95a2dd0483fd76, 0x1aee3eaad7319948
	.quad	0x1a8e820101a05296, 0x1ae554a135c6b3d2
	.quad	0x1a858186e973c8cb, 0x1ade1570321beee3
	.quad	0x1a7e511af403f0e1, 0x1ad53639f61bab8b
	.quad	0x1a755db8f7b445c6, 0x1acde8b06f0475d8
	.quad	0x1a6e1cc067882b19, 0x1ac5155b36a1ff17
	.quad	0x1a6537803429dd3d, 0x1abdb87bf13d1856
	.quad	0x1a5de5045a77840f, 0x1ab4f210fabcd4fe
	.quad	0x1a550eea743a03b0, 0x1aad84e44d6006fd
	.quad	0x1a4da9faec295ac1, 0x1aa4cc6819f5a3a9
	.quad	0x1a44e406557456e3, 0x1a9d4dfc3ea1615f
	.quad	0x1a3d6bb950e85a76, 0x1a94a46e38335bf7
	.quad	0x1a34b6e334ceafc3, 0x1a8d13d79b7b4d75
	.quad	0x1a2d2a55c543d97b, 0x1a847a31bd7fd98a
	.quad	0x1a248791257b832e, 0x1a7cd68b49be13bd
	.quad	0x1a1ce5e780d6c294, 0x1a744dc1cd628aec
	.quad	0x1a145620e7623619, 0x1a6c962d320e4c77
	.quad	0x1a0c9e86a88f07ff, 0x1a641f2e3dd79383
	.quad	0x1a0422a3dd414b5e, 0x1a5c52d432db963c
	.quad	0x19fc544c4080f626, 0x1a53ee878deaf1c1
	.quad	0x19f3ed2c02828af5, 0x1a4c0c9812daaed1
	.quad	0x19ec07521d52071e, 0x1a43bbdedbff7430
	.quad	0x19e3b5cbe0c97302, 0x1a3bc391730e1bf4
	.quad	0x19dbb7b2d547171a, 0x1a338745dbc97fd1
	.quad	0x19d37c9685446b6b, 0x1a2b77d9c068db21
	.quad	0x19cb6589b1020c3e, 0x1a2350cecc05d9cf
	.quad	0x19c3419f75c953bc, 0x1a1b298b2516cc35
	.quad	0x19bb10f29bfb2a68, 0x1a13188c6bf4cd49
	.quad	0x19b304faa5c619af, 0x1a0ad8c07976bbc0
	.quad	0x19aaba0a14c264cc, 0x1a02de91f0a22435
	.quad	0x19a2c6bc6b0e1424, 0x19fa859534d21642
	.quad	0x199a60ed1d150c44, 0x19f2a2f2fa027fc3
	.quad	0x199286f9728ce321, 0x19ea30255dde65be
	.quad	0x198a05b929d439ab, 0x19e265c387eea954
	.quad	0x198245c6b4e79163, 0x19d9d88d7b14c6d3
	.quad	0x1979a88c12e847c2, 0x19d22717ef05792f
	.quad	0x197203396b14a770, 0x19c97eea82eb8229
	.quad	0x19694984031d9858, 0x19c1e704cd7ceb7c
	.quad	0x1961bf6702f3caf4, 0x19b92359cbfdea74
	.quad	0x1958e8bf6806bcab, 0x19b1a59effeaeef1
	.quad	0x19517a6513ed67fa, 0x19a8c5f8fd2e86f6
	.quad	0x1948865ce1efe9b6, 0x19a162fb960e6361
	.quad	0x1941344953a2bc16, 0x199866e5fdcf6e5c
	.quad	0x1938227b33ef66f4, 0x19911f2fc7a0a0a9
	.quad	0x1930ed298ab66e97, 0x1988063ee5dc8676
	.quad	0x1927bd39341e60d2, 0x1980da50e937b941
	.quad	0x1920a51b89b5ac38, 0x1977a421ee53231b
	.quad	0x191756b5bc0538cf, 0x1970947461417eb2
	.quad	0x19105c351e298147, 0x196740ad61b23997
	.quad	0x1906ef0f9946142e, 0x19604daf9d1f19d0
	.quad	0x1900128c07d7eac9, 0x1956dbff8cae0f32
	.quad	0x18f686657e900799, 0x195006180668cd93
	.quad	0x18ef906bdc779cfc, 0x19467636af21f0cb
	.quad	0x18e61cd5f4e4d33c, 0x193f7b85f0c272bb
	.quad	0x18defa90ac757637, 0x19360f70ed4a200e
	.quad	0x18d5b27f4d3aafaf, 0x192ee98b6b3e4f34
	.quad	0x18ce63b1303dfbfb, 0x1925a7cc414fb8aa
	.quad	0x18c5477f92833195, 0x191e566abbe94f87
	.quad	0x18bdcbf7abb88524, 0x19153f666d2fde17
	.quad	0x18b4dbf47c1fc8a0, 0x190dc24dc933bf6d
	.quad	0x18ad338de3492428, 0x1904d65ced070949
	.quad	0x18a46ffb60cbd760, 0x18fd2d5e0d435050
	.quad	0x189c9a9d09a6515f, 0x18f46ccce9c8cdf5
	.quad	0x189403b12a03d499, 0x18ec97c4837b573e
	.quad	0x188c014dae645fc3, 0x18e402d32c6be96d
	.quad	0x1883973247f05596, 0x18dc01a996aebdb3
	.quad	0x187b67c7ad400b86, 0x18d3988c1191e211
	.quad	0x18732a9aa5db4bb3, 0x18cb6b3510058b7a
	.quad	0x186ace321e309c7b, 0x18c32e137db0ef23
	.quad	0x1862be059f3526f7, 0x18bad48e069f2207
	.quad	0x185a34b346493cc3, 0x18b2c384d1c64d5b
	.quad	0x1852518df52ef492, 0x18aa3ddacff96f65
	.quad	0x18499b70897047dc, 0x18a258fae0968e74
	.quad	0x1841e54dc4edf3a3, 0x1899a740f1248851
	.quad	0x1839028e5cf277c7, 0x1891ee8fe480d92c
	.quad	0x1831795e7e5c7cca, 0x188910e510c93fe1
	.quad	0x18286a303af6f699, 0x1881845d75e974c6
	.quad	0x18210dd8db9b7b20, 0x18787aeaea087811
	.quad	0x1817d27896d87b8e, 0x18711a7c823f5ff5
	.quad	0x1810a2d4d917179a, 0x1867e57540380a90
	.quad	0x18073b88d266bc5a, 0x1860b10543a01766
	.quad	0x18003869ae409b27, 0x185750a5d3814d59
	.quad	0x17f6a58134129f18, 0x1850480f391c14fc
	.quad	0x17ef9d5b8ddde221, 0x1846bc9d56645be6
	.quad	0x17e61080de06bfb0, 0x183fbf623f3bedba
	.quad	0x17decb6d7acd34f7, 0x1836297b642274f2
	.quad	0x17d57ca5c62d05dd, 0x182ef001d6eb49df
	.quad	0x17cdfb32aa129cc6, 0x1825975e7810e700
	.quad	0x17c4ea0caf213789, 0x181e222785106b16
	.quad	0x17bd2cd2eb59de4c, 0x18150663e5d53392
	.quad	0x17b458d1220fa79d, 0x180d55fbee497e00
	.quad	0x17ac60744f31e198, 0x180476a7d28a437b
	.quad	0x17a3c90d697e5b5d, 0x17fc8ba606fb6833
	.quad	0x179b963b20518321, 0x17f3e8452ecdbe84
	.quad	0x17933ada8cfe418f, 0x17ebc34b0b8bbc60
	.quad	0x178ace49de2283ae, 0x17e35b55b1b3d652
	.quad	0x1782ae504dc15f24, 0x17dafd0e79df00eb
	.quad	0x177a08c1388db34f, 0x17d2cff1d49f192c
	.quad	0x1772238524122580, 0x17ca39120c175c51
	.quad	0x176945c00d028182, 0x17c24630cff92d39
	.quad	0x17619a8e3da77fbe, 0x17b97775b48ec1aa
	.quad	0x1758856364b336c5, 0x17b1be2898c8a8a4
	.quad	0x1751137f7cd08642, 0x17a8b8579b06ca2c
	.quad	0x1747c7c673fe436e, 0x17a137eddf1f97ae
	.quad	0x17408e6b787233ba, 0x1797fbd41b078795
	.quad	0x17370d029afc4472, 0x1790b3940d5da6fc
	.quad	0x17300b637cd0ec0b, 0x17874205c365c73e
	.quad	0x1726552f6729a259, 0x1780312d48405757
	.quad	0x171f14ef1a3e4ac2, 0x17768b0556e87723
	.quad	0x1715a06296220023, 0x176f6194df7630e5
	.quad	0x170e176ccb941b53, 0x1765d6e9ce0425a7
	.quad	0x1704eeb0196310cd, 0x175e64f64121563e
	.quad	0x16fd1e5afef936da, 0x175525c859a2ea9a
	.quad	0x16f4402a1b0bd9df, 0x174d6c9b6d4d6fc5
	.quad	0x16ec29d225a230e3, 0x174477b466ee6cc1
	.quad	0x16e394e1038ce88e, 0x173c789ea0183d02
	.quad	0x16db39e83951bdaa, 0x1733ccbfa4112a58
	.quad	0x16d2ece3803d8d68, 0x172b8917a154498b
	.quad	0x16ca4eb0c6436cf4, 0x172324fa05e3adc4
	.quad	0x16c2483e8ac9d061, 0x171a9e1bcd30af1f
	.quad	0x16b9683cf6400112, 0x17128071ce79e917
	.quad	0x16b1a6fd716c7c18, 0x1709b7be1e1550cb
	.quad	0x16a8869b9cc95345, 0x1701df33948493fa
	.quad	0x16a10929dfe85b79, 0x16f8d60f37a227b9
	.quad	0x1697a9d9444b613e, 0x16f1414a4b7a1729
	.quad	0x16906ecbe9338feb, 0x16e7f91d72bfd333
	.quad	0x1686d2003c3fdf54, 0x16e0a6bf4c7a4f95
	.quad	0x167fafd4238f8063, 0x16d720f4eaaf4bbb
	.quad	0x1675ff18a8317f0a, 0x16d00f9a5fe04069
	.quad	0x166e8912b5139031, 0x16c64d9f8b065b73
	.quad	0x166531288f8c01c7, 0x16bef7c38ee94e41
	.quad	0x165d695a98770e4b, 0x16b57f251e86550e
	.quad	0x16546833ee262b10, 0x16add73492689d20
	.quad	0x164c50b006d4e015, 0x16a4b58b5eba6cc7
	.quad	0x1643a43cc572b3d3, 0x169cbd8e7539eac7
	.quad	0x163b3f14799b1616, 0x1693f0d6044b145d
	.quad	0x1632e5432e458097, 0x168baad518e7426e
	.quad	0x162a3486c40b74f1, 0x16833106d7f3cac9
	.quad	0x16222b456b1a8db7, 0x167a9f09adee91e3
	.quad	0x161931032d667261, 0x1672761dc408f1ef
	.quad	0x1611763ffacc46ac, 0x16699a2acce5bd7f
	.quad	0x160834838ba6fe3d, 0x1661c018e67b6eae
	.quad	0x1600c62daba74e7c, 0x16589c349043d67e
	.quad	0x15f73eff5eb5eca5, 0x16510ef4a3481a29
	.quad	0x15f01b07aeca1f42, 0x1647a520aeb63fae
	.quad	0x15e6506bebfc67bd, 0x164062abb7415c63
	.quad	0x15dee98b577ea7ca, 0x1636b4e695e9099f
	.quad	0x15d568bc5a3d72ee, 0x162f766e96435041
	.quad	0x15cda6bba883d22a, 0x1625cb7b85aa6067
	.quad	0x15c487e1cd9f3e43, 0x161e311e0dabf963
	.quad	0x15bc6d89f0368fc1, 0x1614e8d2ab5187d6
	.quad	0x15b3adcb83cdccc3, 0x160cf55249e0172a
	.quad	0x15ab3ddd3216f86e, 0x16040cdd3d52967c
	.quad	0x15a2da66f0214306, 0x15fbc2f50c60488e
	.quad	0x159a1799fd5925f4, 0x15f3378a96e8e29a
	.quad	0x15920d9fd7b31257, 0x15ea99ed8a2f2e6b
	.quad	0x1588faa294857a39, 0x15e268c853c2e48d
	.quad	0x158147606d4e1ee3, 0x15d97a2092e9b19d
	.quad	0x1577e6d714d6fce7, 0x15d1a0826b9b2f1e
	.quad	0x157087916d26f37c, 0x15c86370b7b69b46
	.quad	0x1566dc159d3dbce3, 0x15c0dea34dab05c3
	.quad	0x155f9c3470942341, 0x15b755be71f29fea
	.quad	0x1555da3a74ec8bc7, 0x15b02313fbe40a01
	.quad	0x154e35c1df5edf07, 0x15a650e8497f58cd
	.quad	0x1544e120315adc06, 0x159edb784bbee452
	.quad	0x153cdb951dc67cbf, 0x159554cafa9d0c34
	.quad	0x1533f09fdba5037e, 0x158d7d0486e476cc
	.quad	0x152b8d760c6a3faa, 0x158461419b3892c2
	.quad	0x152308911536a23d, 0x157c2a975dad9be0
	.quad	0x151a4b2aa8c000ca, 0x15737625bf981bdb
	.quad	0x151228ca3bac6e07, 0x156ae3f97cbb25ce
	.quad	0x150914773f3bbbac, 0x1562934f9e530bad
	.quad	0x150151208bdc254e, 0x1559a8f1bb2e0d78
	.quad	0x14f7e91e9c37a26b, 0x1551b8963382a860
	.quad	0x14f0816843f2edd8, 0x154879454bd5bf1a
	.quad	0x14e6c8e23b87885f, 0x1540e5cf631ac83b
	.quad	0x14df72e98937c4f8, 0x153754b7ed21d736
	.quad	0x14d5b38276a48ea0, 0x15301ad01a5b2dd0
	.quad	0x14cdf23162441e8b, 0x15263b0c17c2af00
	.quad	0x14c4a8beb16012ed, 0x151eaed8e09770ed
	.quad	0x14bc804c1d0522eb, 0x15152c032be62aab
	.quad	0x14b3a855850eeeea, 0x150d36ef8a6e08fa
	.quad	0x14ab1cdcc2ca0214, 0x1504275d9d00481d
	.quad	0x14a2b204ea20186e, 0x14fbcd89c2310d59
	.quad	0x1499c78595e362ce, 0x14f32cdb1c10f0ee
	.quad	0x1491c58a6013aaee, 0x14ea724c21e93002
	.quad	0x14887fe848fd6bff, 0x14e23c3ac05a8c19
	.quad	0x1480e2a313c94bb5, 0x14d924da86249080
	.quad	0x147745a6341bd9d3, 0x14d1553b2e7eba16
	.quad	0x1470090c041eb55f, 0x14c7e4d844204d5f
	.quad	0x14661860872f36c7, 0x14c0779abdf88654
	.quad	0x145e710449b20327, 0x14b6b1e85d9cfdc3
	.quad	0x1454f7b87a3ccd22, 0x14af462f39da55f5
	.quad	0x144ce184ffaa0275, 0x14a58badb2559681
	.quad	0x1443e34f7b15484d, 0x149daedfe49c8a9f
	.quad	0x143b6314a8f93441, 0x149471cb2f12adec
	.quad	0x1432dac758984610, 0x148c28c3fc94131b
	.quad	0x1429f52e6b0168fb, 0x148363e3fa566830
	.quad	0x1421ddc26b854422, 0x147ab358720f461f
	.quad	0x1418974e49b18481, 0x1472619b9e9f9276
	.quad	0x1410ebe3bcdc6652, 0x14694e1adf5ef17a
	.quad	0x140748f15c14a990, 0x14616a96324493c1
	.quad	0x140004cf29d383af, 0x1457f889bf8109c7
	.quad	0x13f60995fd7916b4, 0x14507e787ce8decb
	.quad	0x13ee50530acb7a2b, 0x1446b224a16aa4e0
	.quad	0x13e4d8bbfb38c980, 0x143f39d03522ee6e
	.quad	0x13dcab316f0b29de, 0x14357a6c57f8fed2
	.quad	0x13d3b5e4bf3051bb, 0x142d8b1738bdcb74
	.quad	0x13cb1987b3f62cd2, 0x142450e32693ba8d
	.quad	0x13c2a09376f26716, 0x141bf0154de94403
	.quad	0x13b99aa6a5f22416, 0x1413350cea8cd61a
	.quad	0x13b1984d37c8d151, 0x140a681c1d2f0b94
	.quad	0x13a82de1daeb9c47, 0x1402266f414ce57b
	.quad	0x13a09c991f950457, 0x13f8f27fe21c9591
	.quad	0x1396d28fdea9871a, 0x13f12491ab5c17d9
	.quad	0x138f5a00e548f085, 0x13e78e979aa0c9be
	.quad	0x1385880a5ae03598, 0x13e02efdac5a4ff4
	.quad	0x137d921d6d1c821b, 0x13d63bbd32217718
	.quad	0x13744dae3b23367b, 0x13ce8a7dcff4677c
	.quad	0x136be0a394617721, 0x13c4f94da865b2a3
	.quad	0x136322dbccd73cab, 0x13bccdc67829105b
	.quad	0x135a44b3f5ce9c8b, 0x13b3c6a934743c05
	.quad	0x135206f6db46b930, 0x13ab26f5afd4ebc9
	.quad	0x1348bd742e227a38, 0x13a2a3336386b4d7
	.quad	0x1340f966c7fd2396, 0x13999530a15ce61a
	.quad	0x13374a0efc06d36e, 0x13918e533433f227
	.quad	0x132ff32d3f1c0a49, 0x138817a166d90dbd
	.quad	0x1325e9b45aff1be0, 0x138087732df4f3ab
	.quad	0x131e0dea55db81c4, 0x1376ad7728d6db01
	.quad	0x13149b9999981d6c, 0x136f1c02ea5235f3
	.quad	0x130c41e9fb058b1e, 0x136555e63841a093
	.quad	0x13035ef96b0fe655, 0x135d42dfb77e321e
	.quad	0x12fa8e19002cb47f, 0x1354102823a6a0a2
	.quad	0x12f23313f4adb099, 0x134b8267dd51660d
	.quad	0x12e8f16bf19917ac, 0x1342db7bc80b123e
	.quad	0x12e1172ed701cd40, 0x1339d98e007ff597
	.quad	0x12d76adf2095d808, 0x1331b7255d8af1ce
	.quad	0x12d00a953345bce4, 0x1328474c5f89cf1f
	.quad	0x12c5f976a86ba7a3, 0x1320a26e7ff7c8a0
	.quad	0x12be192f5a290a0d, 0x1316caa4dc34bcc6
	.quad	0x12b49c3e6e576cf8, 0x130f394c675d5da1
	.quad	0x12ac3918d16606af, 0x130562a0ffd36fef
	.quad	0x12a3524a1ccb90ce, 0x12fd4a41cdb95576
	.quad	0x129a739e0c3f00b3, 0x12f40e51faa74ee4
	.quad	0x12921ab51a49a640, 0x12eb7670ded07be7
	.quad	0x1288c781323e2b8b, 0x12e2ccd09eaa3410
	.quad	0x1280f4a27c210b83, 0x12d9bc980b6cd88b
	.quad	0x1277338f3cfd4b18, 0x12d19d3d560c7458
	.quad	0x126fbe79eabbab8b, 0x12c81b807901b2dd
	.quad	0x1265b69fdd784131, 0x12c07ec015b26bbf
	.quad	0x125db36d8463b3e1, 0x12b691fdebe382be
	.quad	0x12544f955c9776f6, 0x12aee11097f70374
	.quad	0x124bc693203fe92c, 0x12a51eeeac7320be
	.quad	0x1242fd5c7756dd24, 0x129ce39998362bf9
	.quad	0x1239f66cc65fb2cb, 0x1293c13b67a17ff2
	.quad	0x1231beec36eb8502, 0x128b03976c943068
	.quad	0x1228418af0dd65ed, 0x128277d70b2ebc6f
	.quad	0x12209345c546e7cd, 0x12793f94ba2c6b6a
	.quad	0x1216a68c4bfd764b, 0x127141be9e049453
	.quad	0x120ef2e87ca7b717, 0x1267962a50231832
	.quad	0x1205241d71eb6e19, 0x12601df915097b64
	.quad	0x11fce118fc8beeea, 0x125605fee84767f0
	.quad	0x11f3b8f8a28fd848, 0x124e172e498cd2fc
	.quad	0x11eaef59daa19c93, 0x12448dc6e3757e71
	.quad	0x11e263e577f574d0, 0x123c1366206ca036
	.quad	0x11d91bfa9231de5c, 0x12332c440230ef3a
	.quad	0x11d123b897af1af4, 0x122a2ee0ea25a216
	.quad	0x11c7655cd85a2773, 0x1221e04519eb8f87
	.quad	0x11bfeea6c3554149, 0x121867f82bdccb8f
	.quad	0x11b5c9f427a491a4, 0x1210a8a5c7678dff
	.quad	0x11adbb4739afff2e, 0x1206bd1744d1513e
	.quad	0x11a4484548d479a3, 0x11ff089c3d3d8b6f
	.quad	0x119bab46440d8e4b, 0x11f52cbafb8bc99f
	.quad	0x1192dee5d96e696e, 0x11ece464b1286c0d
	.quad	0x1189bcaf0aad775c, 0x11e3b571085ef9db
	.quad	0x11818c7bd07b007f, 0x11dae2a4fedee59c
	.quad	0x1177eda37d26ae66, 0x11d255d79dbe3905
	.quad	0x11704fbd01fd3b9a, 0x11c9017432798e26
	.quad	0x11663c5ba199716f, 0x11c10c9ceee61d28
	.quad	0x115e4edd431a7a40, 0x11b73effa34f57ab
	.quad	0x1154a724e2f6eade, 0x11afb0fd6a99ec28
	.quad	0x114c24c9890314cd, 0x11a5998a4600495b
	.quad	0x11432c615eef6a3d, 0x119d70936a92f04a
	.quad	0x113a1f03c81340fd, 0x11940f6bfdad1f14
	.quad	0x1131ca87340e1c39, 0x118b55b284add8c1
	.quad	0x11283b6cbf2ba29f, 0x11829f10ece9036e
	.quad	0x1120801fd07f7284, 0x11795e2d86ae92c8
	.quad	0x111677ffffc31b92, 0x117146f8c6e8dc57
	.quad	0x110e978e83ebd95d, 0x116787f26e598ebb
	.quad	0x1104d2d2f5dd4096, 0x116005b6216a17ea
	.quad	0x10fc58570e2f641d, 0x1155d10973fbab06
	.quad	0x10f34a13f272cdfa, 0x114db3db8f832a58
	.quad	0x10ea4017c5ace0de, 0x1144379416dfac63
	.quad	0x10e1dc0938cfb932, 0x113b84ac1ef46255
	.quad	0x10d84c7064147f81, 0x1132b9cc2c3d6738
	.quad	0x10d087100f5e6429, 0x11297b6c5dc3637a
	.quad	0x10c67b20873fc995, 0x11215602f1227af8
	.quad	0x10be9337a8979da0, 0x111795cb2bb480b6
	.quad	0x10b4ca0667456eb8, 0x11100aa01fc8a73e
	.quad	0x10ac446a2ccade1c, 0x1105d196927cdacc
	.quad	0x10a3371d92c55c69, 0x10fdac421184af19
	.quad	0x109a1ef1650d3562, 0x10f42cba823b93cb
	.quad	0x1091c07db1df4cf6, 0x10eb6e2f60b615c1
	.quad	0x1088202debc2593c, 0x10e2a53f94211ba9
	.quad	0x108064595037ce7b, 0x10d95853e0fd75ad
	.quad	0x107645a58ac6913c, 0x10d13949d3b2fbd2
	.quad	0x106e41f95cc492ce, 0x10c768213ee2ba9c
	.quad	0x10648d0194e5b153, 0x10bfce2f1e195a7a
	.quad	0x105be99935f38c42, 0x10b59b2d772c1b04
	.quad	0x1052f40d4a5d2870, 0x10ad5a005ce1b15d
	.quad	0x1049bc8aa74c3805, 0x10a3ef3138f8ae58
	.quad	0x104178b448b82b16, 0x109b12e626e3c8a1
	.quad	0x1037b7f2dc7fa066, 0x1092620652c3102c
	.quad	0x1030190106456396, 0x1088f5ecffd9c995
	.quad	0x1025d92194746ef2, 0x1080f1a62a97a48e
	.quad	0x101da636b2add63a, 0x1077004d0a0dd3fc
	.quad	0x10141d8f14e2d235, 0x106f38508375a815
	.quad	0x100b4a8e16df3a2e, 0x10652f67f4a45dbd
	.quad	0x100282da2ee06e9f, 0x105cbf8187da9700
	.quad	0x0ff91bc4f0e82a10, 0x105380c6fa6ddd1b
	.quad	0x0ff106c65473611b, 0x104a757e44dde4fb
	.quad	0x0fe716ca73d3a1dc, 0x1041f218f165083c
	.quad	0x0fdf4e737e667fe6, 0x1038571975a9ba0c
	.quad	0x0fd538bdbc880350, 0x103081306aee058b
	.quad	0x0fccc4774fe05a13, 0x102661571375ee31
	.quad	0x0fc37eeb586702af, 0x101e5803c9b677c0
	.quad	0x0fba6be51e94d2c3, 0x10149169d29f057f
	.quad	0x0fb1e6cae3cc5ce4, 0x100be144165bfdad
	.quad	0x0fa841452e30c6ec, 0x1002e4b0b7596d86
	.quad	0x0fa06dfcc0330324, 0x0ff99a8814f82396
	.quad	0x0f964157d8dbcaa1, 0x0ff158b4c1d7aa61
	.quad	0x0f8e248fc3725278, 0x0fe7806fe5adc0de
	.quad	0x0f84691284199248, 0x0fdfd64d63539ac4
	.quad	0x0f7ba32f675bcca1, 0x0fd58fd2560c98e3
	.quad	0x0f72b59cb5fcd070, 0x0fcd33b9c01b8858
	.quad	0x0f6953f4278d9771, 0x0fc3c5b9e7be019e
	.quad	0x0f61244d4a198783, 0x0fbac5a261b57bd2
	.quad	0x0f57333ac721d353, 0x0fb21f61f6e6a3a5
	.quad	0x0f4f654f8b2c9938, 0x0fa8883e334bf813
	.quad	0x0f453d9d5f4e3889, 0x0fa09a33ffab8174
	.quad	0x0f3cbcb3935e8707, 0x0f9678037d69a88a
	.quad	0x0f336fefd85e37f7, 0x0f8e678a0474dd4d
	.quad	0x0f2a4a7147e53789, 0x0f8491a44a8cc267
	.quad	0x0f21c73c8c2f3143, 0x0f7bd3a60953bab8
	.quad	0x0f180a7df6e9e4ab, 0x0f72d20af56e98e4
	.quad	0x0f1040c111171b21, 0x0f69748563f2a02c
	.quad	0x0f05f9153468350d, 0x0f613656dff66048
	.quad	0x0efdb3d65827b6f1, 0x0f57463a2ae57157
	.quad	0x0ef412b4a3b0b6bb, 0x0f4f77b2a384d071
	.quad	0x0eeb20abd232bd72, 0x0f45451ae34b02ae
	.quad	0x0ee25417f5fe18aa, 0x0f3cc024fa52d21e
	.quad	0x0ed8c38db09c3d68, 0x0f336dbe645ba702
	.quad	0x0ed0ba351c6b2c44, 0x0f2a415d531b6e85
	.quad	0x0ec69856de023170, 0x0f21bcf7eeeba2f5
	.quad	0x0ebe847157246bfc, 0x0f17f70703ac5558
	.quad	0x0eb49b2d16422141, 0x0f102fd377359b10
	.quad	0x0eabd304de355d85, 0x0f05dd1b0bb84b26
	.quad	0x0ea2c87c2ff697dc, 0x0efd87243e77ecad
	.quad	0x0e995b4456f24a66, 0x0ef3efdb3b369292
	.quad	0x0e911cf1a60f1d84, 0x0eeaeb4dc01a4631
	.quad	0x0e8718a9184a8678, 0x0ee22bcd99dbdb06
	.quad	0x0e7f2af0be1fde49, 0x0ed88766c06b0833
	.quad	0x0e7507007917e3d9, 0x0ed08db80d427d79
	.quad	0x0e6c5e695f15072b, 0x0ec65709eb54bf5e
	.quad	0x0e632266540e08c2, 0x0ebe253876b38ace
	.quad	0x0e59cf012acb820b, 0x0eb45623a2f6a451
	.quad	0x0e51673fda512b46, 0x0eab6f674d703273
	.quad	0x0e4777d05328bd26, 0x0ea280eca736b4b1
	.quad	0x0e3fa46d62b8e57d, 0x0e98f4d804e3ad6f
	.quad	0x0e35544c8bc23e1c, 0x0e90d3e50a2eecdc
	.quad	0x0e2cc068b1dc8ab2, 0x0e86b0c7763ce52b
	.quad	0x0e236042b9065710, 0x0e7e979edc5b3767
	.quad	0x0e1a1cbbab815b4c, 0x0e749ecd657d5dd6
	.quad	0x0e1197d0fe71564c, 0x0e6bcb59141dc715
	.quad	0x0e07b41f3bcb1869, 0x0e62bad65a82bb23
	.quad	0x0dffeec24eca8006, 0x0e593d6de18ac6bf
	.quad	0x0df581b387627669, 0x0e51011dd6dfecf6
	.quad	0x0decf746ccaba032, 0x0e46e8be31f2fe24
	.quad	0x0de380f8b864e1ac, 0x0e3edc51c8649aaa
	.quad	0x0dda4312cc2f816a, 0x0e34c88f43732a10
	.quad	0x0dd1adc83c96accf, 0x0e2bfd81ed74f1cd
	.quad	0x0dc7cc835281bbf3, 0x0e22d883a292df3b
	.quad	0x0dc0044e6f2b903f, 0x0e195fde403b5724
	.quad	0x0db58e66674c0f82, 0x0e111494966870b7
	.quad	0x0dad0209514d613d, 0x0e06fdef1ca550b3
	.quad	0x0da383f2f4495aed, 0x0dfef217eb67d36d
	.quad	0x0d9a41575f0363d6, 0x0df4d2aaa5b8e28a
	.quad	0x0d91a8c12a0cae91, 0x0dec04fcbf1fddd8
	.quad	0x0d87c08d08f2ccbb, 0x0de2d96cdd2a30b8
	.quad	0x0d7ff186c5b90604, 0x0dd95b8ba50a2687
	.quad	0x0d757a2b0b1c4c86, 0x0dd10df03cd711e3
	.quad	0x0d6ce07ef98af2ae, 0x0dc6eff939f51c8f
	.quad	0x0d636923c5eb270b, 0x0dbed88d96607fb4
	.quad	0x0d5a1791489717bf, 0x0db4bcf1445c1d61
	.quad	0x0d5188d2c2d680a3, 0x0dabe1a747b458c8
	.quad	0x0d47907312c7e255, 0x0da2bd8dde16ba8a
	.quad	0x0d3fa9e995f4c414, 0x0d993089dc23e417
	.quad	0x0d35455df149c7b5, 0x0d90ed4f34d6e965
	.quad	0x0d2c93410e8142f8, 0x0d86bf1c754a3325
	.quad	0x0d233105a5b594f7, 0x0d7e9027b1c5a4ab
	.quad	0x0d19c67f441e11b3, 0x0d7487c687197597
	.quad	0x0d114e8ebae7496e, 0x0d6b942323a72767
	.quad	0x0d073d10c597b774, 0x0d6285660efb3e9a
	.quad	0x0cff330b99c7f9e7, 0x0d58df9d62fb9c5e
	.quad	0x0cf4f0ef77c81a6f, 0x0d50b34677fe9486
	.quad	0x0cec1baedb5f2e65, 0x0d466c37bb05de1e
	.quad	0x0ce2dc9788ad9864, 0x0d3e1a30436bcde5
	.quad	0x0cd94f913add4907, 0x0d34341c90c553e7
	.quad	0x0cd0fafd2c40ba27, 0x0d2b1dd0ffc5d04b
	.quad	0x0cc6c7df995241d1, 0x0d2231f4a6757469
	.quad	0x0cbe8f062cc963ce, 0x0d186a35930ed5e1
	.quad	0x0cb47e5cbff0d92e, 0x0d1060dd236f49a3
	.quad	0x0cab7be34be4e18d, 0x0d05f8c25cd122d7
	.quad	0x0ca26d5559b935e7, 0x0cfd78bca82e9f37
	.quad	0x0c98b4dd6af9c05d, 0x0cf3c36d15093021
	.quad	0x0c908f94cfc79158, 0x0cea80c62c44a65b
	.quad	0x0c8632ec0e0d009c, 0x0ce1c4b11ed6627a
	.quad	0x0c7dc0b5f2e40ea4, 0x0cd7d261cc2edf72
	.quad	0x0c73efa480ea698b, 0x0ccfef096f5252f0
	.quad	0x0c6ab6a5245de9e5, 0x0cc566c107178d1f
	.quad	0x0c61e52cde409267, 0x0cbcae9de8f00c0b
	.quad	0x0c57f910d0084829, 0x0cb337ae444bd293
	.quad	0x0c500e3012bd4171, 0x0ca9bfbcfe9dc1e8
	.quad	0x0c4580c66bfc7cf5, 0x0ca13f803c0631d9
	.quad	0x0c3ccba595fe34b5, 0x0c971ac2109d33c9
	.quad	0x0c3347383dcf4a9b, 0x0c8ef21caa7d80c3
	.quad	0x0c29cf52785fcd1f, 0x0c84b8b6bbdb7a4f
	.quad	0x0c21466f7a4ba4b3, 0x0c7bbf4bcf8ca0c3
	.quad	0x0c171f5b701cb667, 0x0c72934441fdae8b
	.quad	0x0c0ef1fef5338f87, 0x0c68de00a5d4cff3
	.quad	0x0c04b46ffc2e70cc, 0x0c60a4a61359d63a
	.quad	0x0bfbb3f3e667d5e5, 0x0c564673b39bdd54
	.quad	0x0bf287ea78b8278f, 0x0c4dcf3acd0cc1f4
	.quad	0x0be8c9c8347a2863, 0x0c43f1926f0c2aa4
	.quad	0x0be093c166d47d90, 0x0c3aaecb94ca24e1
	.quad	0x0bd62b5957e6b822, 0x0c31d8efbbc88d6c
	.quad	0x0bcda4f3c5b8c56f, 0x0c27df554174928c
	.quad	0x0bc3d1457a1afdae, 0x0c1fed6b4a9440a8
	.quad	0x0bba7e3665ffae25, 0x0c1558fae0fed7aa
	.quad	0x0bb1b4da97b89113, 0x0c0c8b307e047613
	.quad	0x0ba7aa46b2ec675c, 0x0c03149a005e5984
	.quad	0x0b9fa00e080e5360, 0x0bf9819329634547
	.quad	0x0b9520f92dcad4a2, 0x0bf10bba52994e8e
	.quad	0x0b8c3a9666328faa, 0x0be6c7dd2d93c0f9
	.quad	0x0b82dae795ce73b6, 0x0bde70fd5d6d806d
	.quad	0x0b792f5963d343cf, 0x0bd45629dffe1fa7
	.quad	0x0b70d15f439254be, 0x0bcb2b2e959996b0
	.quad	0x0b6675546ac2c967, 0x0bc2255364dfcfd7
	.quad	0x0b5dfca1ff236f02, 0x0bb83c6a3841fcca
	.quad	0x0b54046155930cfb, 0x0bb02ee197efc99d
	.quad	0x0b4ab8846c89a496, 0x0ba59bfc8bdbfffe
	.quad	0x0b41d5226b496f7e, 0x0b9cd9f4c9733040
	.quad	0x0b37cc7edd2bedd1, 0x0b93420703d360ea
	.quad	0x0b2fc1e021531b11, 0x0b89b4a6e4580455
	.quad	0x0b252f9fd29afa7b, 0x0b81276cde31355e
	.quad	0x0b1c439018f9e7b0, 0x0b76e44a0da72ded
	.quad	0x0b12d9d4a3bfacfa, 0x0b6e8b82d35e9882
	.quad	0x0b09247c7d6b7109, 0x0b64603c1a2de688
	.quad	0x0b00c3d4d5746632, 0x0b5b2e6fa531d555
	.quad	0x0af65add59367765, 0x0b5220b241172407
	.quad	0x0aedce1e8301e6ef, 0x0b482d28ae825549
	.quad	0x0ae3dde18cb97a8d, 0x0b401ea51e3f541c
	.quad	0x0ada7b31ccb0b2f4, 0x0b357e3d8e31e749
	.quad	0x0ad1a59798dd7aa2, 0x0b2ca77ce984ce61
	.quad	0x0ac7843a7981f8e3, 0x0b23192c63185ef2
	.quad	0x0abf55b0f3ffe463, 0x0b1974911a73b1a7
	.quad	0x0ab4df9fe655b0fb, 0x0b10f64b579273f6
	.quad	0x0aabce68ce6bcfed, 0x0b069a3e1bad13da
	.quad	0x0aa284bfe1cdea24, 0x0afe1d6859c11527
	.quad	0x0a98a9c29acbf47d, 0x0af40f425a16dca3
	.quad	0x0a906bd70b72892b, 0x0aeab8633790b1e2
	.quad	0x0a85dd55c1a48477, 0x0ae1cb4a43b9229f
	.quad	0x0a7d1bd6b173b9f2, 0x0ad7b25cc6523c3b
	.quad	0x0a735fc8451ff49e, 0x0acf8db2dc70232b
	.quad	0x0a69c9712232f548, 0x0ac5014bc06e7f91
	.quad	0x0a6128b47439dcd5, 0x0abbf66ba3b9066c
	.quad	0x0a56d53d2be0a0b6, 0x0ab29c2c1dc958db
	.quad	0x0a4e6122171333df, 0x0aa8c4a9d76af90f
	.quad	0x0a4435229d0cc681, 0x0aa07ae5a7347d0b
	.quad	0x0a3ae1371b74ea2d, 0x0a95ed9539dfd0c9
	.quad	0x0a31e01427183001, 0x0a8d2c69c7599edc
	.quad	0x0a27c589442700ec, 0x0a83677341a98a13
	.quad	0x0a1f9be9e1d7b4e4, 0x0a79cf2c5625685e
	.quad	0x0a15033c96eb7570, 0x0a71298aebe8af0f
	.quad	0x0a0bef014f36ffa9, 0x0a66d2655c8560eb
	.quad	0x0a0290979be09b3b, 0x0a5e58166789d0bc
	.quad	0x09f8ac6ba86dcc3c, 0x0a542b9e90b536b6
	.quad	0x09f064e638fb2517, 0x0a4acfe7e64002b1
	.quad	0x09e5c884857d8ade, 0x0a41d179e12ade6e
	.quad	0x09dcf0beaeb1b319, 0x0a37ae01eb0f55cb
	.quad	0x09d338e29511ffcd, 0x0a2f772a9e0423a1
	.quad	0x09c9881a23b2ff9b, 0x0a24e72e15f0f016
	.quad	0x09c0f43798c4f845, 0x0a1bc4e2f5a8c9af
	.quad	0x09b6836e63bd7d88, 0x0a127165d875ec78
	.quad	0x09ade466f9c32fda, 0x0a087eb54ae1860d
	.quad	0x09a3d79f883687bf, 0x0a0043b38d103ec9
	.quad	0x099a56d48500b8a3, 0x09f598a7d65e3b67
	.quad	0x09917ac327f9b5e5, 0x09ecac2d1ee89db1
	.quad	0x09873278f241bb95, 0x09e308090afcd9f3
	.quad	0x097ec801820c3f3d, 0x09d942d41e7bf2a3
	.quad	0x09746b841565ab3e, 0x09d0c34dc595f4bf
	.quad	0x096b16ea850bfa34, 0x09c63e9cb83e74b2
	.quad	0x0961f76e44abf0ec, 0x09bd83e5a3ffd7ad
	.quad	0x0957d432d7dd0ca1, 0x09b39428e0fd00c5
	.quad	0x094f99abec00b682, 0x09a9f8c2eadfb109
	.quad	0x0944f35579392d4b, 0x09a13957092e7741
	.quad	0x093bc6c19eee10e8, 0x0996d7ad6ac744f9
	.quad	0x0932692d6adc530f, 0x098e4a41e3c393c2
	.quad	0x0928673fad41c337, 0x0984149a31665d1e
	.quad	0x09202bd066e6e446, 0x097a9efbad7c9909
	.quad	0x09156dece3f159c3, 0x0971a4d14ca40e60
	.quad	0x090c64dabfd6babd, 0x0967628f37011dc7
	.quad	0x0902cf07ed3ac7ca, 0x095efd93aae49244
	.quad	0x08f8ea5cdb1b77f8, 0x0954884565714d83
	.quad	0x08f0801f05da3bab, 0x094b341347ab9d2e
	.quad	0x08e5da3ba0723cbc, 0x094204d0f497ca7d
	.quad	0x08dcefd7b19fc691, 0x0937de10a24a9be3
	.quad	0x08d3281b7ca3d771, 0x092f9c4f419d97b9
	.quad	0x08c95c663259c5d8, 0x0924ee2a6bb63f1d
	.quad	0x08c0c90568fe453b, 0x091bb6bea4d790c6
	.quad	0x08b6374ef6370a23, 0x091258802fee3a1b
	.quad	0x08ad668024e6e773, 0x0908491dcb50d650
	.quad	0x08a3739f6c74a992, 0x090012888bcf5e1b
	.quad	0x0899bc5a27482390, 0x08f5456466d99824
	.quad	0x089105de86fb726e, 0x08ec25d7813e5a28
	.quad	0x08868453b252f9af, 0x08e29f220ff323bd
	.quad	0x087dc7c640bf856f, 0x08d8a2c46b36447d
	.quad	0x0873b0e7a2d8004d, 0x08d04b5178932d9e
	.quad	0x086a095d99893bea, 0x08c58d2d04dcdef9
	.quad	0x0861361f24d04a1e, 0x08bc8060b8a624d8
	.quad	0x0856c0994513d45b, 0x08b2d8154e3020f5
	.quad	0x084e12caa0268707, 0x08a8ea37661d565f
	.quad	0x0843df6725a60cf5, 0x08a078003d294269
	.quad	0x083a42bf15180a09, 0x0895c4df6da1a5f0
	.quad	0x08315957e82800c6, 0x088cc58a0676d26e
	.quad	0x0826eb9463d29a0d, 0x088302d6b1661ef0
	.quad	0x081e46dfa81a2018, 0x08791ed1d851d1dd
	.quad	0x0813feb236502138, 0x0870982d94421652
	.quad	0x080a67f97b02e026, 0x0865ebfab91b4a2b
	.quad	0x08016f37032d6085, 0x085cf4b3235443f5
	.quad	0x07f704e120e656fd, 0x08531f0304f01ddb
	.quad	0x07ee638c247f445d, 0x084940198fd0e1c2
	.quad	0x07e40e7ff18c854c, 0x0840ab8eaa8fae67
	.quad	0x07da78b6039c7039, 0x08360223e0067b2c
	.quad	0x07d1778970df4481, 0x082d0d6e2f89dd66
	.quad	0x07c70c446e7535cc, 0x08232c589802b4ba
	.quad	0x07be688d1dc06742, 0x08194dc0e4e3bd62
	.quad	0x07b40eab69ffb357, 0x0810b1f64079cf15
	.quad	0x07aa74cd8f49285b, 0x080607271cb1c230
	.quad	0x07a1723bbb37e710, 0x07fd0f815d3e30e4
	.quad	0x079701ad03f5aba2, 0x07f32ab83cb1b9aa
	.quad	0x078e55d6dd34aeb5, 0x07e947a7e7d08e62
	.quad	0x0783ff3437e5e592, 0x07e0ab555a059592
	.quad	0x077a5c493ec4b75b, 0x07d5faf8b45ee11c
	.quad	0x07715f5a46f2a8c5, 0x07ccfae7d166a387
	.quad	0x0766e533a1804da5, 0x07c31a25c153692f
	.quad	0x075e2b951ac76b4b, 0x07b92ddcdd3a585a
	.quad	0x0753e03e7aaf4a23, 0x07b097bb793410b5
	.quad	0x074a2f624fa2da41, 0x07a5ddb524f58124
	.quad	0x07413f112353b2e2, 0x079ccfd1b6b2b0d1
	.quad	0x0736b71aaf8395ac, 0x0792fac7e1ac1a55
	.quad	0x072dea2a52e6f8d6, 0x0789009c068a7447
	.quad	0x0723b2124c85eb7d, 0x078077566199da13
	.quad	0x0719ee813dcc82f4, 0x0775afa0b60e30ad
	.quad	0x071111ab5ef7d9ce, 0x076c8ea38207b48c
	.quad	0x070677cd3ce598a2, 0x0762cce7b0334e93
	.quad	0x06fd922e485849df, 0x0758c04eb792831b
	.quad	0x06f3751aaab95803, 0x07504a716678c7d9
	.quad	0x06e99a3c2eb312df, 0x074571266fb205e7
	.quad	0x06e0d791e54efc95, 0x073c37f46c8a36ce
	.quad	0x06d627dd610c1f2f, 0x073290ef7aa6784e
	.quad	0x06cd246bba093ddd, 0x07286d89be61c44f
	.quad	0x06c329e3d8fc35e5, 0x072011744722e8f8
	.quad	0x06b93354aecb0f91, 0x071522d67c700dd9
	.quad	0x06b09149eae599f4, 0x070bcc8c2b79e5e6
	.quad	0x06a5c8020a89d6a7, 0x070247692feaf7c7
	.quad	0x069ca1dd59404578, 0x06f8090b25f1fb1c
	.quad	0x0692d1194826d1d9, 0x06ef99c33fa36826
	.quad	0x0688bab4cd7bc185, 0x06e4c563ff8738ed
	.quad	0x06803f72f0fa181c, 0x06db4d5ff233ee8b
	.quad	0x067559144638d7d2, 0x06d1f0fc4fe41aef
	.quad	0x066c0baa10766979, 0x06c793b75fbd2367
	.quad	0x06626b830bbc4f33, 0x06befaa9eeaa4992
	.quad	0x0658316ba6f8ef74, 0x06b459a26ac43fcf
	.quad	0x064fc588d5eeb300, 0x06aabb8ece685efe
	.quad	0x0644dc0c0d42f863, 0x06a18e6b704952c1
	.quad	0x063b6320aea7077a, 0x06970e95e366ca95
	.quad	0x0631fa02ebad6485, 0x068e4700e7fab75e
	.quad	0x062798a96e59845b, 0x0683e0826243926d
	.quad	0x061ef81624855ca5, 0x067a185d71d9ae78
	.quad	0x061451fcaaed5e70, 0x0671209163a43d8a
	.quad	0x060aa9b30dd7b333, 0x06667acd56555624
	.quad	0x06017d9121b4ff43, 0x065d805487b20ec2
	.quad	0x05f6f1bb0c9eff18, 0x06535b0e3e76f72a
	.quad	0x05ee184bec96bcc5, 0x064965317fc3f8eb
	.quad	0x05e3bc10ccdff1d7, 0x0640a85e11600392
	.quad	0x05d9e0f0cdf83a76, 0x0635d99f4f4fa7a2
	.quad	0x05d0f738d3253e75, 0x062ca8538b911cc2
	.quad	0x05c63e056b37b486, 0x0622ca663e8f6c6e
	.quad	0x05bd2806afda0512, 0x0618a38c763ae500
	.quad	0x05b31b865207923b, 0x061026d30f31261e
	.quad	0x05a90a81bef15367, 0x06052c63cbe5201d
	.quad	0x05a068145905badd, 0x05fbc0c903e2dd51
	.quad	0x05957f0081c7461b, 0x05f22fbc7eb40c8e
	.quad	0x058c293abfeb81c1, 0x05e7d5064d5d2e6a
	.quad	0x058271a9ed146425, 0x05df3a001a1da12a
	.quad	0x0578282015bfd093, 0x05d474846e880b80
	.quad	0x056fa292d1f4b615, 0x05cacb96019278e3
	.quad	0x0564b6323fa7fafc, 0x05c18c50c637e437
	.quad	0x055b1ded81f6cf48, 0x05b6fb47e7243b10
	.quad	0x0551bfd2aff12d23, 0x05ae17fe4af1cdcd
	.quad	0x05473b9288cf980b, 0x05a3b3779cd081bc
	.quad	0x053e680a6315c8f9, 0x0599caab20737c4b
	.quad	0x0533e52969a46a03, 0x0590e16c42489121
	.quad	0x052a082ea93d471f, 0x058618056ad2fa0d
	.quad	0x0521075d9566cab2, 0x057ce9e247afa7ef
	.quad	0x051646a66f6fb197, 0x0572eabb9557e4c3
	.quad	0x050d22f0f82317a8, 0x0568c0020c90fd02
	.quad	0x05030d7883df3e07, 0x0560305d4157bdec
	.quad	0x04f8ea1187daf8b3, 0x05552cf8a69cbdee
	.quad	0x04f049a91d747c02, 0x054bb1f3a4ce848c
	.quad	0x04e54b29ff375e83, 0x05421bd19407d3a8
	.quad	0x04dbd5a7cbaf896d, 0x0537ad97206eb3e9
	.quad	0x04d230b0dec754da, 0x052ef4e6059f1fe4
	.quad	0x04c7c5a693980a40, 0x05243bdb9112e65b
	.quad	0x04bf10221f87a1ca, 0x051a7278c0b2c815
	.quad	0x04b44ae6c097e3b8, 0x051148391a9b5b70
	.quad	0x0000000000000000, 0x0000000000000000
	.align	16
	.quad	0x7fffffffffffffff, 0x7fffffffffffffff /* _AbsMask */
	.align	16
	.quad	0x403b3e0000000000, 0x403b3e0000000000 /* _MaxThreshold=3487.0/128.0 */
	.align	16
	.quad	0x8000000000000000, 0x8000000000000000 /* sign mask */
	.align	16
	.quad	0x37f0000000000000, 0x37f0000000000000 /* 2^(-128) */
	.align	16
	.quad	0x42c0000000000000, 0x42c0000000000000 /* SRound */
	// polynomial coefficients
	.align	16
	.quad	0xbf2282c89a04c65f, 0xbf2282c89a04c65f // poly1[0]
	.align	16
	.quad	0x3f472360bac04e70, 0x3f472360bac04e70 // poly1[1]
	.align	16
	.quad	0xbf8441df86900a46, 0xbf8441df86900a46 // poly3[0]
	.align	16
	.quad	0x3fa117abf1fea28c, 0x3fa117abf1fea28c // poly3[1]
	.align	16
	.quad	0xbfb56433674ba5c2, 0xbfb56433674ba5c2 // poly5[0]
	.align	16
	.quad	0x3fc256e8e6045cdf, 0x3fc256e8e6045cdf // poly5[1]
	.align	16
	.quad	0xbf6a019f4f234617, 0xbf6a019f4f234617 // poly1[2]
	.align	16
	.quad	0xbfb8618412bc79ec, 0xbfb8618412bc79ec // poly3[2]
	.align	16
	.quad	0xbfc5554e249ff4a7, 0xbfc5554e249ff4a7 // poly5[2]
	.align	16
	.quad	0x3f8a019f5aeed25f, 0x3f8a019f5aeed25f // poly1[3]
	.align	16
	.quad	0x3fcc71c4b73b20b6, 0x3fcc71c4b73b20b6 // poly3[3]
	.align	16
	.quad	0x3fb9998f9d0729da, 0x3fb9998f9d0729da // poly5[3]
	.align	16
	.quad	0xbfa6c16c16d06420, 0xbfa6c16c16d06420 // poly1[4]
	.align	16
	.quad	0xbfd9999999f3d838, 0xbfd9999999f3d838 // poly3[4]
	.align	16
	.quad	0x3fc11111111ab082, 0x3fc11111111ab082 // poly1[5]
	.align	16
	.quad	0x3fe0000000379730, 0x3fe0000000379730 // poly3[5]
	.align	16
	.quad	0xbfd5555555554add, 0xbfd5555555554add // poly3[6]
	.align	16
	.quad	0xbfd555555555548a, 0xbfd555555555548a // poly1[6]
	.align	16
	.quad	0x3fe55555555554cf, 0x3fe55555555554cf // poly1[7]
	.align	16
	.quad	0x403B39DC41E48BFD, 0x403B39DC41E48BFD /* UF_Threshold */
	.align	16
	.quad	0x47f0000000000000, 0x47f0000000000000 /* 2^128 */
	.align	16
	.type	__svml_derfc_data_internal, @object
	.size	__svml_derfc_data_internal, .-__svml_derfc_data_internal
